<?xml version="1.0" encoding="UTF-8"?>
<#-- Import common macros and functions -->
<#import "macros_common_general.ftl" as com>
<#import "macros_common_studies_and_summaries.ftl" as studyandsummaryCom>
<#import "common_module_pnec_assessment.ftl" as pnec>
<#-- Import common macros and functions for CSR Chapter One -->
<#import "common_module_substance_basic_information.ftl" as keySubstanceInformation>
<#import "common_module_substance_composition.ftl" as keyCompositionInformation>
<#import "common_module_nanoforms.ftl" as keyNanoformInformation>
<#import "common_module_assessment_entities.ftl" as keyAssessmentInformation>
<#import "common_module_physical_chemical_summary_properties.ftl" as keyPhysChemInformation>
<#-- Import common macros and functions for CSR Chapter Three -->
<#import "common_module_classification_and_labelling.ftl" as keyClassifcationAndLabellingInformation>
<#-- Import common macros and functions for CSR Chapter Four -->
<#import "common_module_environmental_fate_properties.ftl" as keyEnvironmentalFateAndProperties>
<#-- Import common macros and functions for CSR Chapter Five -->
<#import "common_module_human_health_hazard_assessment.ftl" as keyHumanHealthHazardAssessmentInformation>
<#-- Import common macros and functions for CSR Chapter Six -->
<#import "common_module_human_health_hazard_assessment_of_physicochemical_properties.ftl" as keyHumanHealthHazardAssessmentOfPhysChemPropInformation>
<#-- Import common macros and functions for CSR Chapter Seven -->
<#import "common_module_environmental_hazard_assessment.ftl" as keyEnvironmentalHazardAssessment>
<#-- Import common macros and functions for CSR Chapter Eight -->
<#import "common_module_pbt_and_vpvb_assessment.ftl" as keyPbtandvPvBassessment>

<!-- SVHC main template file -->
<#assign locale = "en" />
<#assign sysDateTime = .now>

<book version="5.0" xmlns="http://docbook.org/ns/docbook" xmlns:xi="http://www.w3.org/2001/XInclude">

	<#assign substance = com.getReportSubject(rootDocument) />
		
	<#assign left_header_text = ''/> 
	<#assign central_header_text = 'ANNEX XV – IDENTIFICATION OF ' + com.getReportSubject(rootDocument).name?html + ' AS SVHC' />
	<#assign right_header_text = ''/> 
	
	<#assign left_footer_text = sysDateTime?string["dd/MM/yyyy"] + " - IUCLID 6 " + iuclid6Version!/> 
	<#assign central_footer_text = '' />
	<#assign right_footer_text = ''/> 
		
	<!-- Initialize common variables -->
	<@com.initializeMainVariables/>	

	<!-- Initialize svhc relevance -->
	<@com.initiateRelevanceSVHC relevance />	
	
	<!-- Create variables for simple entities -->
	<#assign ownerLegalEntity = iuclid.getDocumentForKey(_subject.OwnerLegalEntity) />
	<#assign referenceSubstance = iuclid.getDocumentForKey(_subject.ReferenceSubstance.ReferenceSubstance) />
		
	<info>
        <title><para>Annex XV report</para></title>
		<para>PROPOSAL FOR IDENTIFICATION OF A SUBSTANCE OF VERY HIGH CONCERN ON THE BASIS OF THE CRITERIA SET OUT IN REACH ARTICLE 57</para>

		<cover>
		<@com.emptyLine/>            
			<para>				
				<para><emphasis role="bold">Substance Name:</emphasis> <@com.substanceName _subject/></para>
				
					<#if referenceSubstance?has_content>
						<#if referenceSubstance.Inventory.InventoryEntry?has_content>
							<para>		
								<emphasis role="bold">EC Number:</emphasis>
								<@com.inventoryECNumber com.getReferenceSubstanceKey(_subject.ReferenceSubstance.ReferenceSubstance)
								 />						
							</para>
						</#if>
							
						<para>
							<emphasis role="bold">CAS Number:</emphasis>
							<#assign casNumberInv>					
								<@com.inventoryECCasNumber com.getReferenceSubstanceKey(_subject.ReferenceSubstance.ReferenceSubstance) />
							</#assign>
							
							<#if casNumberInv?has_content>
								${casNumberInv}
								
								<#else>
									<@com.casNumber com.getReferenceSubstanceKey(_subject.ReferenceSubstance.ReferenceSubstance) />
								
							</#if>
						</para>
					</#if>	
					
				<para>
					<emphasis role="bold">Submitted by: [Name of the Member State/s]</emphasis>
				</para>
				<para>
					<emphasis role="bold">Date:</emphasis>
				</para>
			</para>
			 
        </cover>
        <@com.metadataBlock left_header_text central_header_text right_header_text left_footer_text central_footer_text right_footer_text />
    
	</info>
	
	<preface><title>Foreward</title>
			<para>
			The aim of this template is to provide support to the authorities involved in the development of Annex XV dossiers for the identification of substances of very high concern (SVHC) with regard to the structure and content of the Annex XV report. This support is complementary to the provisions of the legal text and the information already available in the Guidance for the preparation of an Annex XV dossier on the identification of substances of very high concern and the information and support available at http://echa.europa.eu/web/guest/support/authorisation/substances-of-very-high-concern-identification.
			This annotated template provides instructions on how to structure and present information in the Annex XV SVHC report. The aim of this structure is to provide clarity and avoid duplication, without requiring any further information than laid down in the REACH Regulation. Furthermore, this template includes some standard phrases, which may be useful in the preparation of the “Supporting Documents” for the meetings of the Member State Committee. 
			Authorities should use this template when preparing an Annex XV SVHC report, proposing the identification of a substance: in the hazard classes carcinogenicity, germ cell mutagenicity or reproductive toxicity (CMR) category 1A or 1B; as persistent, bioaccumulative and toxic (PBT) and/or very persistent and very bioaccumulative (vPvB) in accordance with the criteria set out in Annex XIII to the REACH Regulation; as a substance of equivalent concern, in accordance with Article 57(f) REACH. Sub-headings which are not relevant for the substance in question should be deleted, but please maintain the Section headings (in blue) as part of the overall final structure. Items highlighted in green should be replaced with the specific substance information. All annotations in italics should also be deleted before finalisation.
			The proposal should provide the identity of the substance as it is proposed to be included in the Candidate List and a summary of how the substance meets the criteria set out in Article 57. Furthermore, the registration status of the substance should also be provided here. All information from the registration dossiers must be taken into account in the Annex XV SVHC dossier and the dossier must respect the relevant confidentiality and intellectual property aspects. 

			Part I (“Justification”) should provide the information that is relevant to identify the substance(s) addressed as meeting one or more of the criteria of Article 57 REACH. Therefore, only information that is of immediate relevance for the identification of the SVHC properties should be included in this part.
			Valid information on properties that is not of immediate relevance for the conclusion as to whether the substance concerned meets the Article 57 criteria, but could be useful for exposure and hazard assessment or in the context of prioritisation for inclusion in Annex XIV to REACH should still be provided, but in Annexes to the report.
			The formats for Sections 3 to 5 of Part I follow the chemical safety report (CSR) template which is based on the required standard headings of Annex I of REACH. 
			Part II (“Information on use, exposure, alternatives and risks”) can be used to report available information in order to serve the next step of the authorisation procedure, namely, priority setting in the context of recommending substances for inclusion in Annex XIV and development of draft Annex XIV entries (transitional arrangements, review periods, exemptions of (categories of) uses). The registration dossiers (and other REACH or CLP dossiers) are the main source of information for this part of the Annex XV report. It should be noted that the aim of Part II is not to provide an exposure assessment or to conduct an assessment of possible alternatives, but to support the priority setting process.			
			</para>
	</preface>
	
	<part>
	<title>PROPOSAL FOR IDENTIFICATION OF A SUBSTANCE OF VERY HIGH CONCERN ON THE BASIS OF THE CRITERIA SET OUT IN REACH ARTICLE 57</title>
	
	<partintro>
		<@com.emptyLine/>
		<para>			
			The substance name, CAS and EC numbers listed below should be those foreseen to be included in the Candidate List.
		</para>
		<@com.emptyLine/>

			<para><emphasis role="bold">Substance Name:</emphasis> <@com.substanceName _subject/></para>
			<#if referenceSubstance?has_content>
				<#if referenceSubstance.Inventory.InventoryEntry?has_content>
					<para>		
						<emphasis role="bold">EC Number:</emphasis>
						<@com.inventoryECNumber com.getReferenceSubstanceKey(_subject.ReferenceSubstance.ReferenceSubstance)
						 />						
					</para>
				</#if>
					
				<para>
					<emphasis role="bold">CAS Number:</emphasis>
					<#assign casNumberInv>					
						<@com.inventoryECCasNumber com.getReferenceSubstanceKey(_subject.ReferenceSubstance.ReferenceSubstance) />
					</#assign>
					
					<#if casNumberInv?has_content>
						${casNumberInv}
						
						<#else>
							<@com.casNumber com.getReferenceSubstanceKey(_subject.ReferenceSubstance.ReferenceSubstance) />
						
					</#if>
				</para>
			</#if>
		
		<@com.emptyLine/>
		<para>
		Please delete what is not relevant. If your substance is a CMR, please maintain the footnote.
		•	The substance(s) is/are proposed to be identified as a substance meeting the criteria of Article 57 (a) of Regulation (EC) No 1907/2006 (REACH) owing to its classification in the hazard class carcinogenicity category 1A or 1B .

		•	The substance(s) is/are proposed to be identified as a substance meeting the criteria of Article 57 (b) of Regulation (EC) No 1907/2006 (REACH) owing to its classification in the hazard class germ cell mutagenicity category 1A or 1B2.

		•	The substance(s) is/are proposed to be identified as a substance meeting the criteria of Article 57 (c) of Regulation (EC) No 1907/2006 (REACH) owing to its classification in the hazard class reproductive toxicity category 1A or 1B2.

		•	It is proposed to identify the substance(s) as persistent, bioaccumulative and toxic (PBT) according to Article 57 (d) of Regulation (EC) No 1907/2006 (REACH).

		•	It is proposed to identify the substance(s) as very persistent and very bioaccumulative (vPvB) according to Article 57 (e) of Regulation (EC) No 1907/2006 (REACH).

		•	It is proposed to identify the substance(s) as a substance(s) of equivalent level of concern to those of other substances listed in points (a) to (e) of Article 57 of Regulation (EC) No 1907/2006 (REACH) according to Article 57(f) of REACH Regulation. 
		
		<emphasis role="bold">Summary of how the substance meets the criteria set out in Article 57 of the REACH Regulation</emphasis>
		
		The aim of this section is to provide a summary of the information supporting the identification of the substance as meeting the criteria set out in Article 57 REACH. The summary needs to address and reflect the main conclusions of the assessment (from Section 6: Conclusions on the SVHC properties, in addition to a description of the basis on which the assessment was made (e.g. use of weight-of-evidence, read across) as well as a clear statement on which Article 57 criterion/criteria is/are met. Consistency with Section 6 (Conclusions on the SVHC Properties) of the Annex XV report should be ensured while drafting the summary. It is important to keep in mind that this summary is used later in the process to document the agreement of the Member State Committee. 
		For substances meeting the criteria set out in points (a) to (c) of Article 57 REACH, please use one of the paragraphs provided below. Delete what is not relevant.
		<@com.substanceName _subject/> is covered by index number xxx-xxx-xx-x of Regulation (EC) No 1272/2008 in Annex VI, part 3, Table 3.1 (the list of harmonised classification and labelling of hazardous substances) and it is classified in the hazard class carcinogenicity category 1A or 1B (hazard statement H350: “May cause cancer”). 
		<@com.substanceName _subject/> is covered by index number xxx-xxx-xx-x of Regulation (EC) No 1272/2008 in Annex VI, part 3, Table 3.1 (the list of harmonised classification and labelling of hazardous substances) and it is classified in the hazard class germ cell mutagenicity category  1A or 1B (hazard statement H340: “May cause genetic defects”). 
		<@com.substanceName _subject/> is covered by index number xxx-xxx-xx-x of Regulation (EC) No 1272/2008 in Annex VI, part 3, Table 3.1 (the list of harmonised classification and labelling of hazardous substances) and it is classified in the hazard class reproductive toxicity category 1A or 1B (hazard statement ). 
		Therefore, this classification of the substance in Regulation (EC) No 1272/2008 shows that it meets the criteria for classification in the hazard class: (please delete what is not relevant)

		•	Carcinogenicity category 1A or 1B in accordance with Article 57 (a) of REACH.
		•	Germ cell mutagenicity category 1A or 1B in accordance with Article 57 (b) of REACH.
		•	Reproductive toxicity category 1A or 1B in accordance with Article 57 (c) of REACH.


		For substances meeting the criteria of Articles 57 (d) and/or (e) REACH:

		A summary of the assessment of each property (persistence, bioaccumulation and where relevant, toxicity) must be provided, including a clear comparison with the criteria in Annex XIII of REACH, in addition to a concluding statement on whether the substance is identified as an SVHC based on Articles 57 (d) and/or (e) REACH. The identification as an SVHC can be based on the PBT/vPvB properties of relevant constituents (including impurities and additives) of a substance and/or relevant transformation and/or degradation products. In such cases, a summary of PBT and/or vPvB properties for relevant constituents of a substance and/or for its relevant transformation products must also be provided. This section should be entirely consistent with the contents of Section 6.2.2 (Summary and overall conclusions on the PBT and vPvB properties, i.e. the text from Section 6.2.2 should be copied here). 

		Please use the following paragraph (modified as necessary) to reflect the weight-of-evidence you have used:

		A weight-of-evidence determination according to the provisions of Annex XIII of REACH is used to identify the substance as PBT/vPvB. All available relevant information (such as the results of standard tests, monitoring and modelling, information from the application of the category and analogue approach (grouping, read-across) and (Q)SAR results) was considered together in a weight-of-evidence approach. 

		The following structure should be used to report the outcome of the assessment of substances meeting the criteria of Articles 57 (d) and/or (e) REACH. This structure could also be the starting point in cases where substances meet the criteria of Article 57 (f) as substances of equivalent level of concern to PBT/vPvB substances.


		Persistence

		Bioaccumulation

		Toxicity (only relevant for PBT substances)

		Conclusion

		In conclusion, <@com.substanceName _subject/> meets the criteria for a PBT and/or vPvB substance according to Article 57 (d) and/or (e) REACH.


		For substances meeting the criteria of Article 57 (f) REACH:

		(i) Where the basis for the proposal is a harmonised classification and where the equivalent level of concern relates to a hazard class relevant for human health (e.g. respiratory sensitisation) the following text can be used: (please amend as appropriate).

		<@com.substanceName _subject/> is covered by index number xxx-xxx-xx-x of Regulation (EC) No 1272/2008 in Annex VI, part 3, Table 3.1 (the list of harmonised classification and labelling of hazardous substances) and it is classified as a [respiratory sensitiser]. <@com.substanceName _subject/> is identified as a substance of very high concern in accordance with Article 57(f) of Regulation (EC) 1907/2006 (REACH) because it is a substance with [respiratory sensitising properties] for which there is scientific evidence of probable serious effects to human health which gives rise to an equivalent level of concern to those substances listed in points (a) to (e) of Article 57 REACH.


		(ii) Where the basis for the proposal is an adverse effect for which no hazard class has been defined in Regulation (EC) No 1272/2008 (CLP Regulation) and where the equivalent level of concern relates to an environmental effect (e.g. caused by the endocrine disrupting properties of the substance), the following text can be used: (please amend as appropriate).

		<@com.substanceName _subject/> is identified as a substance of very high concern in accordance with Article 57(f) of Regulation (EC) 1907/2006 (REACH) because [through its degradation to (name(s) of degradation product(s))] it is a substance with [endocrine disrupting properties] for which there is scientific evidence of probable serious effects to the environment which gives rise to an equivalent level of concern to those of other substances listed in points (d) to (e) of Article 57 REACH.

		In addition, summary information must be provided on the basis of which the above conclusion has been drawn. Ideally, this should include a brief summary of the evidence from high quality studies.

		Based on the above conclusion, evidence that the substance is of an equivalent level of concern includes: 

		Where the equivalent level of concern relates to an environmental effect, the key information in the report should be summarised taking into account the relevant discussion points in section 6.3.2 (non-exhaustive). The conclusions of the assessment (from section 6.3.3) must also be included here.


		Registration dossiers submitted for the substance? Yes/No
		</para>
	</partintro>
	</part>
	
	<part>
	<title>PART I</title>
	<partintro>
		<para>
		The purpose of this first part of the report is to provide a concise and scientifically sound justification that the substance(s) addressed by the dossier has properties that meet one or more of the criteria of REACH Article 57.
		Any information or data not relevant for the identification of the substance(s) as SVHC in accordance with Article 57 REACH should not be provided in Part I of the report. 
		This is to render the SVHC identification process stipulated by Article 59 REACH as efficient as possible. This means avoiding as much as possible, discussion and comments on (i) already agreed information (e.g. harmonised classification and labelling) and (ii) on information that is not relevant for the conclusion on the SVHC properties. 
		Valid information on properties that is not of immediate relevance for the conclusion on the SVHC properties, but could be useful in the context of prioritisation for inclusion in Annex XIV to REACH, should be provided in Annexes to the report (where this is considered useful, a reference to this option is made in the section-specific instructions). 
		The format and the headings proposed for the justification follow the CSR template, based on the required standard headings of Annex I of REACH. All relevant information from the registration dossiers must be included in the Annex XV report (whilst respecting the relevant confidentiality and intellectual property aspects). 
		</para>
	</partintro>
	</part>
	
	<part>
	<title>JUSTIFICATION</title>
		<partintro>
			<para>
			Justification
			In general, only valid data (i.e. reliable data relevant for the conclusion on the properties / endpoints) should be reported. This helps to avoid discussion about irrelevant data in the SVHC identification process. Documentation of data validity is foreseen to be provided in the Annex XV technical dossier (IUCLID file), which is supplementary to the Annex XV report. The submitting authorities should evaluate the validity of the data used in the assessment and not rely solely on the assessment made by registrants in their registration dossier. It should be indicated which studies are considered as the key studies for the conclusions drawn on each physicochemical, environmental fate, human health or ecotoxicological endpoint and which studies are included as supporting information. The reliability of each study should be discussed and reported (e.g. Klimisch code).
			In case a read-across or weight-of-evidence approach is used in the assessment, please report the rationale in detail according to the available guidance . Where a weight-of-evidence approach is used in the assessment, all available relevant information should be used even if the individual pieces of information may not be regarded as information sufficient to conclude on the properties/endpoints. A justification should be provided for each piece of information used in the weight-of-evidence approach. Please note that pursuant to Annex XIII to REACH, for the identification of PBT and vPvB substances a weight-of-evidence determination using expert judgement must always be applied.

			(Sub)headings or tables not relevant or for which no information is provided should be deleted.
			</para>
		</partintro>
	
		<chapter label="1">
			<title role="HEAD-1">Identity of the substance and physical and chemical properties</title>
			
			<para>
			The principal requirements for identification and naming of mono- or multi-constituent substances and UVCBs  are laid down in the Guidance for Identification and Naming of Substances under REACH and CLP . 
			Constituents (including impurities and additives) or degradation/transformation products that are relevant for classification and/or the PBT/vPvB properties (i.e. SVHC properties in accordance with REACH Art. 57) of the substance shall be specified independently from their concentration (in Section 1.3 “Identity and composition of degradation products/metabolites relevant for the SVHC assessment” below). In practice, this means constituents (including impurities and additives) or degradation/transformation products (that are relevant for classification) for which a (harmonised) classification is available, the generic concentration limits (GCL) given in Annex I of Regulation (EC) No 1272/2008 (CLP Regulation)  or specific concentration limits, where such are warranted, should be specified in this section. For certain hazard classes, constituents present below the generic or, where relevant, specific concentration limits (S or GCL) but above generic cut off value (CLP table 1.1), should be taken into account. 
			In the case of constituents (including impurities and additives) or degradation/transformation products with PBT or vPvB properties a concentration limit of 0.1% w/w applies. This limit of 0.1 % w/w is set based on a well-established practice recognised in European Union legislation . However, there may be particular cases of PBT constituents (including impurities and additives) where it is necessary to specify a concentration limit below 0.1% w/w (i.e. when based on the toxicity criterion of the PBT constituent where a specific concentration limit lower than 0.1 % w/w has been assigned). 

			For complex (groups of) substances with unclear substance identities, it is recommended to contact ECHA (annex-xv@echa.europa.eu) at the earliest opportunity to allow the SVHC team and the substance identity experts to support you in specifying the substance information in the best possible way in your proposal. 
			</para>
			
			<@com.emptyLine/><section>
			<title role="HEAD-2">Name and other identifiers of the substance</title>
			The name and other identifiers of the substance should designate the actual substance proposed to be identified as SVHC.
			For substances identified as SVHC based on the PBT/vPvB properties of their transformation and/or degradation products, the information on the name or other identifiers of the substance should still designate the substance proposed to be identified as SVHC. In addition, information on transformation products having PBT/vPvB properties should be provided in Section 1.3 below.
			
			<para>
				<@keySubstanceInformation.substanceIdentity _subject />
			</para>
			</section>
			
			<@com.emptyLine/><section>
			<title role="HEAD-2">Composition of the substance</title>
			<para>
			This information is particularly important for the main constituent(s) and for the constituents (including impurities) which influence the outcome of the SVHC identification. The information should be tailored as far as possible to profile the requirements on the composition for the substance to present the SVHC property.
			Please note that the identification of a mono- or multi-constituent substance as an SVHC in its own right is based on the identity of its main constituent(s). In this case, the composition expected to be reported should be limited to the identity and typical concentration of the main constituent(s). The identification of the main constituent(s) is based on the rules established in the Guidance for Identification and Naming of Substances under REACH and CLP . Accordingly, the main constituent of a mono-constituent substance normally has a typical concentration level ≥80% w/w while main constituents in a multi-constituent substance are typically present at a concentration 10% w/w and 80% w/w.

			Other constituents (i.e. impurities or additives) which are not relevant for the identification of the substances as SVHC should not be mentioned. Indeed, indicating the identity and concentration of further constituents may confuse suppliers (manufacturers, importers or downstream users) supplying/using these substances, but having different compositions. In such cases, they may wrongly conclude that their substance is not covered by the proposal. However, impurities and additives must be mentioned whenever they are relevant for the identification of the substance as SVHC.
			</para>
				<para>
				<@keyCompositionInformation.substanceComposition _subject />
				</para>
			</section>
			
			<@com.emptyLine/><section>
			<title role="HEAD-2">Identity and composition of degradation products/metabolites relevant for the SVHC assessment</title>
			<para>
			Degradation/transformation products and/or metabolites that are relevant for the SVHC properties of the substance shall always be specified, independently from their concentration. It is recommended to document the identity of the degradation (transformation) product(s) or metabolite(s) of relevance for the SVHC properties in the following table and to report in addition the structural formula as well as some information regarding the transformation process. Such a comprehensive table should be filled in for each relevant degradation product and/or metabolite.
			</para>
			</section>
			
			<@com.emptyLine/><section>
			<title role="HEAD-2">Identity and composition of structurally related substances (used in a grouping or read-across approach)</title>
			<para>
			For each structurally related substance of relevance for the SVHC properties, the following tables should be filled in. 
			</para>
			</section>
			
			<@com.emptyLine/><section>
			<title role="HEAD-2">Physicochemical properties</title>
				<para>
				Physicochemical properties should be provided here if they are relevant for the assessment of the SVHC criteria. 
				If the objective of the Annex XV dossier is to identify an SVHC because it has been classified as a CMR in accordance with Article 57 points (a) to (c), it is not necessary to provide data in this section. If this section is not relevant, the following phrase can be used:
				Not relevant for the identification of the substance as SVHC in accordance with Article 57 points (a) to (f) REACH.
				For substances identified as SVHC based on the PBT/vPvB-properties, physicochemical data are necessary for the assessment and should be provided here, particularly the vapour pressure, water solubility, partition coefficient n-octanol/water and dissociation constants (ionising substances). 
				If the Annex XV dossier aims to identify a substance as having properties giving rise to an equivalent level of concern, in accordance with Article 57 (f) REACH, other physicochemical properties might be important and the relevancy of such endpoints should be assessed on a case-by-case basis.
				When reporting the physicochemical properties in the following table, please specify, when relevant the test conditions (e.g. temperature, pH, including the correct units of measurement). 
				Where the source of the physicochemical data is ECHA’s dissemination website, please note that information published on ECHA’s dissemination site is not necessarily checked for its’ correctness. Therefore, in order to ensure that the information included in your Annex XV SVHC report is accurate, it is recommended that you assess the original data accordingly or base the information on other, reliable sources. 

				</para>
				<para>
				<@keyPhysChemInformation.physicalChemicalPropertiesTable _subject />
				</para>
			</section>			
			
		</chapter>
		
		<chapter label="2">
			<title role="HEAD-1">Harmonised classification and labelling</title>
			<para>
			In this section, only harmonised classification and labelling should be reported as included in Part 3 of Annex VI of Regulation (EC) No 1272/2008 (CLP Regulation). 
			The harmonised classification reported in this section provides the basis for the conclusion that the substance(s) addressed fulfil(s) the criteria for being considered as carcinogenic, mutagenic or toxic to reproduction (category 1A or 1B) in accordance with Article 57 points (a) to (c) REACH.
			Reference to Annex VI of the CLP Regulation may be necessary to provide evidence that the T-criterion of REACH Annex XIII (with regard to human health effects) is met. Reference to Annex VI of the CLP Regulation may also be necessary for cases in accordance with Article 57(f) REACH which are based on harmonised classification and labelling (e.g. respiratory sensitisers). 
			In cases where the classification is based on the presence of a constituent or an impurity (and if relevant, additives), this should be stated clearly, along with the identity of the constituent/impurity and the concentration of the constituent/impurity in the substance leading to the classification.
			The information provided should include the index number, specific concentration limits/M-factors and the notes listed in Annex VI of the CLP Regulation. ECHA would therefore recommend reproducing in this section the entry as given in Annex VI of the CLP Regulation. 

			<@com.substanceName _subject/> is covered by Index number xxx-xxx-xx-x in part 3 of Annex VI to the CLP Regulation as follows:
			</para>
			
			<para>
				<@keyClassifcationAndLabellingInformation.classificationAndLabellingTable _subject/>
			</para>
			
		</chapter>	
			
		<chapter label="3">
			<title role="HEAD-1">Environmental fate properties</title>
			<para>
			If the Annex XV SVHC dossier aims to identify a substance as having PBT or vPvB properties or, as having properties giving rise to an equivalent level of concern (environment), in accordance with Article 57 points (d) to (f) REACH, Sections 3.1 and 3.4 including the relevant sub-sections, need to be filled in, as a minimum. It is necessary to document the data and considerations that result in the conclusions in Section 6 “Conclusions on the SVHC Properties” as to whether the substance meets the P/vP and B/vB criteria of Annex XIII to REACH or, as to whether it has properties leading to an equivalent level of concern. It should be noted that a comparison with Annex XIII criteria is not foreseen for Section 3 (Environmental fate properties) but in Section 6.2.2.
			For substances identified as SVHC based on the PBT/vPvB-properties of relevant transformation and/or degradation products, the environmental fate properties of each relevant transformation product need to be provided here (or as part of an Annex to the Annex XV report). The environmental fate properties of the parent substance (respectively its relevant constituents, impurities and additives) should be reported in this section also (or as part of an annex to the Annex XV report). The relevance of the degradation and/or transformation products in question also needs to be described and discussed in this section in a quantitative and/or qualitative way (e.g., reflecting the probability and rate of formation of the degradation and/or transformation products in question).
			Sub-headings which are not relevant for the substance in question should be deleted.

			If the objective of the Annex XV dossier is to identify an SVHC because it has been classified as a CMR in accordance with Article 57 points (a) to (c) REACH, it is not necessary to provide data in this section. If this section is not relevant, the following phrase can be used:
			Not relevant for the identification of the substance as SVHC in accordance with Article 57 points (a) to (f) REACH.
			</para>
			
			<@com.emptyLine/><section>
			<title role="HEAD-2">Degradation</title>
			<para>
			In this section, information relevant for assessing the degradation potential of the substance can be included. The information needs to be presented in such a level of detail that the reader is able to make their own basic judgement about the reliability of the information. The dossier submitter should also provide their conclusions on the reliability of the information. Furthermore, relevance and adequacy of the presented information for the purpose of the assessment need to be described. This information will form the basis for the conclusion whether the substance is considered to fulfil the P or vP criteria according to Annex XIII to REACH. A summary and discussion on the main conclusions on both abiotic and biotic degradation should be included in the following sections. This section may also be relevant for substances proposed to be identified in accordance with Article 57 (f) REACH.
			When using a weight-of-evidence approach, please consider also in that case reporting in the different sub-sections of Section 3.1 “Degradation”  detailed information on the studies and describing in accordance with “Practical Guide 2: How to report weight of evidence”   the necessary details of the weight-of-evidence approach. 

			In Section “3.1.4 Summary and discussion of degradation” the relevant information on degradation (having relevant weight as part of the weight-of-evidence) must be summarised. 

			In addition, conclusions regarding the overall degradation potential of the substance must be drawn and reported in Section 3.1.4. This information will form the basis for the conclusion whether the substance fulfils the P or vP criteria according to Annex XIII to REACH and as documented in Section 6 of the Annex XV report. The comparison with Annex XIII criteria is not foreseen in Section 3.1, but needs to be carried out in Section 6.2.2 and copied to the proposal section: “Summary of how the substance meets the criteria set out in Article 57 of the REACH Regulation".

			The same applies when concluding on substances proposed to be identified in accordance with Article 57(f) REACH.
			</para>

			<!-- Assign an array of column headers to the variable 'columnHeaders'. -->
			<#assign columnHeaders = ["Method", "Results", "Remarks"]> 

			<!-- Assign an array of column widths to the variable 'columnWidths'. -->
			<#assign columnWidths=[ "39%", "48%", "13%" ]>

			<!-- Calculate the number of columns based on the size of the 'columnHeaders' array and assign it to the variable 'numberOfColumns' -->
			<#assign numberOfColumns = columnHeaders?size>

			<#-- list human health studies -->
			<#assign humanHealthDocs = ["ENDPOINT_STUDY_RECORD.HealthSurveillanceData", "ENDPOINT_STUDY_RECORD.EpidemiologicalData", "ENDPOINT_STUDY_RECORD.DirectObservationsClinicalCases", "ENDPOINT_STUDY_RECORD.ExposureRelatedObservationsOther"] />
			<#assign humanHealthDocsPlus = ["ENDPOINT_STUDY_RECORD.HealthSurveillanceData", "ENDPOINT_STUDY_RECORD.EpidemiologicalData", "ENDPOINT_STUDY_RECORD.DirectObservationsClinicalCases", "ENDPOINT_STUDY_RECORD.ExposureRelatedObservationsOther", "ENDPOINT_STUDY_RECORD.SensitisationData"] />


			<@com.emptyLine/><section>
			<title role="HEAD-3">Abiotic degradation</title>
			
				<@com.emptyLine/><section>
				<title role="HEAD-4">Hydrolysis</title>
				<para>
					<@keyEnvironmentalFateAndProperties.studyTable _subject "ENDPOINT_STUDY_RECORD" "Hydrolysis" columnHeaders  numberOfColumns columnWidths />
					<@keyEnvironmentalFateAndProperties.summaryTable _subject "ENDPOINT_SUMMARY" "Hydrolysis" "" "Discussion"/>>
				</para>
				</section>
				
				<@com.emptyLine/><section>
				<title role="HEAD-4">Oxidation</title>
				<para>
				</para>
				</section>
				
				<@com.emptyLine/><section>
				<title role="HEAD-4">Phototransformation/photolysis</title>
				
					<@com.emptyLine/><section>
					<title role="HEAD-5">Phototransformation in air</title>						
					<@keyEnvironmentalFateAndProperties.studyTable _subject "ENDPOINT_STUDY_RECORD" "PhototransformationInAir" columnHeaders  numberOfColumns columnWidths/>
				<@keyEnvironmentalFateAndProperties.summaryTable _subject "ENDPOINT_SUMMARY" "PhototransformationInAir" "" "Discussion"/>	
					</section>
					<@com.emptyLine/><section>
					<title role="HEAD-5">Phototransformation in water</title>						
					<@keyEnvironmentalFateAndProperties.studyTable _subject "ENDPOINT_STUDY_RECORD" "Phototransformation" columnHeaders  numberOfColumns columnWidths/>
				<@keyEnvironmentalFateAndProperties.summaryTable _subject "ENDPOINT_SUMMARY" "PhototransformationInWater" "" "Discussion"/>		
					</section>
					<@com.emptyLine/><section>
					<title role="HEAD-5">Phototransformation in soil</title>						
					<@keyEnvironmentalFateAndProperties.studyTable _subject "ENDPOINT_STUDY_RECORD" "PhotoTransformationInSoil" columnHeaders  numberOfColumns columnWidths/>
				<@keyEnvironmentalFateAndProperties.summaryTable _subject "ENDPOINT_SUMMARY" "PhototransformationInSoil" "" "Discussion"/>			
					</section>						
				</section>
				
				<@com.emptyLine/><section>
				<title role="HEAD-4">Summary on abiotic degradation</title>	
					<para></para>
				</section>					
			</section>
			
			<@com.emptyLine/><section>
			<title role="HEAD-3">Biodegradation</title>
				<@com.emptyLine/><section>
				<title role="HEAD-4">Biodegradation in water</title>
				
					<@com.emptyLine/><section>
					<title role="HEAD-5">Estimated data</title>
					<para>
					</para>
					</section>
					
					<@com.emptyLine/><section>
					<title role="HEAD-5">Screening tests</title>
					<para><@keyEnvironmentalFateAndProperties.studyTable _subject "ENDPOINT_STUDY_RECORD" "BiodegradationInWaterScreeningTests" columnHeaders  numberOfColumns columnWidths/>
					</para>
					</section>
					
					<@com.emptyLine/><section>
					<title role="HEAD-5">Simulation tests (water and sediments)</title>
					<para><@keyEnvironmentalFateAndProperties.studyTable _subject "ENDPOINT_STUDY_RECORD" "BiodegradationInWaterAndSedimentSimulationTests" columnHeaders  numberOfColumns columnWidths/>
					</para>
					</section>
											
				</section>
				
				<@com.emptyLine/><section>
				<title role="HEAD-4">Biodegradation in soil</title>
				<para>
				<@keyEnvironmentalFateAndProperties.studyTable _subject "ENDPOINT_STUDY_RECORD" "BiodegradationInSoil" columnHeaders  numberOfColumns columnWidths/>
			<@keyEnvironmentalFateAndProperties.summaryTable _subject "ENDPOINT_SUMMARY" "BiodegradationInSoil" "" "Discussion"/>
				</para>
				</section>
				
				<@com.emptyLine/><section>
				<title role="HEAD-4">Summary and discussion on biodegradation</title>
				<para>
				<@keyEnvironmentalFateAndProperties.summaryTable _subject "ENDPOINT_SUMMARY" "BiodegradationInWaterScreeningTests" "" "Discussion (screening testing)"/>
				<@keyEnvironmentalFateAndProperties.summaryTable _subject "ENDPOINT_SUMMARY" "BiodegradationInWaterAndSedimentSimulationTests" "" "Discussion (simulation testing)"/>
				<@keyEnvironmentalFateAndProperties.summaryTable _subject "ENDPOINT_SUMMARY" "Stability" "Abiotic degradation" "Discussion"/>			
		<@keyEnvironmentalFateAndProperties.summaryTable _subject "ENDPOINT_SUMMARY" "Biodegradation" "Biotic degradation" "Discussion"/>
				</para>
				</section>
				
			</section>
		
			<@com.emptyLine/><section>
				<title role="HEAD-3">Field data</title>
			<para></para>
			</section>
		
			<@com.emptyLine/><section>
				<title role="HEAD-3">Summary and discussion of degradation</title>
			<para></para>
			</section>
				
		</section>
			
		<@com.emptyLine/><section>
			<title role="HEAD-2">Environmental distribution</title>
			
			<@com.emptyLine/><section>
				<title role="HEAD-3">Adsorption/desorption</title>
			<para><@keyEnvironmentalFateAndProperties.studyTable _subject "ENDPOINT_STUDY_RECORD" "AdsorptionDesorption" columnHeaders  numberOfColumns columnWidths/>
		<@keyEnvironmentalFateAndProperties.summaryTable _subject "ENDPOINT_SUMMARY" "AdsorptionDesorption" "" "Discussion"/></para>
			</section>
			
			<@com.emptyLine/><section>
				<title role="HEAD-3">Volatilisation</title>
			<para><@keyEnvironmentalFateAndProperties.studyTable _subject "ENDPOINT_STUDY_RECORD" "HenrysLawConstant" columnHeaders  numberOfColumns columnWidths/>
		<@keyEnvironmentalFateAndProperties.summaryTable _subject "ENDPOINT_SUMMARY" "HenrysLawConstant" "" "Discussion"/></para>
			</section>
			
			<@com.emptyLine/><section>
				<title role="HEAD-3">Distribution modelling </title>
			<para><@keyEnvironmentalFateAndProperties.studyTable _subject "ENDPOINT_STUDY_RECORD" "DistributionModelling" columnHeaders  numberOfColumns columnWidths/></para>
			</section>
			
			<@com.emptyLine/><section>
				<title role="HEAD-3">Field data</title>
			<para></para>
			</section>
			
			<@com.emptyLine/><section>
				<title role="HEAD-3">Summary and discussion of environmental distribution</title>
			<para><@keyEnvironmentalFateAndProperties.summaryTable _subject "ENDPOINT_SUMMARY" "TransportAndDistribution" "" "Discussion"/></para>
			</section>
		</section>
		
		<@com.emptyLine/><section>
			<title role="HEAD-2">Data indicating potential for long-range transport </title>
			<para>Regarding the long-range transport potential of the substance, relevant information such as screening information as set out in the Stockholm Convention on Persistent Organic Pollutants (POPs) can be reported in this section (cf. screening criteria for potential for long-range environmental transport in Annex D, Section 1 (d) of the Stockholm Convention). </para>
		</section>
		
		<@com.emptyLine/><section>
			<title role="HEAD-2">Bioaccumulation</title>
			<para>
			In this section, information relevant for identifying the bioaccumulation potential of the substance can be included. The information needs to be presented in such a level of detail that the reader is able to make their own basic judgement about the reliability of the information. The dossier submitter also should provide their conclusions on the reliability of the information. Furthermore, relevance and adequacy of the presented information for the purpose of the assessment need to be described. This information will be the basis for the conclusion whether the substance is considered to fulfil the B or vB criteria according to Annex XIII. The information to be used in support of the assessment of the bioaccumulation potential is listed under Annex XIII to REACH, Sections 3.1.2 and 3.2.2. Please note that information related to bioaccumulation in humans and toxicokinetics should be reported under Section 4 of the Annex XV report, as Section 3.4 is intended to describe the environmental bioaccumulation potential. This section may also be relevant for substances proposed to be identified in accordance with Article 57(f) REACH. 
			When using a weight-of-evidence approach, please consider reporting in the different sub-sections of Section 3.4 (Bioaccumulation) detailed information on the studies and describing in accordance with “Practical Guide 2: How to report weight of evidence” the necessary details of the weight-of-evidence approach. 
			In Section 3.4.4 (Summary and discussion of bioaccumulation) the relevant information on bioaccumulation (having relevant weight as part of the weight-of-evidence) must be summarised. A summary and discussion on the main conclusions on aquatic and terrestrial bioaccumulation should be included in the following sections. 
			In addition, conclusions regarding the overall bioaccumulation potential of the substance should be drawn and reported in Section 3.4.4. This information will be the basis for the conclusions whether the substance fulfils the B or vB criteria according to Annex XIII to REACH and as documented in Section 6 of the Annex XV report. The comparison with Annex XIII criteria is not foreseen in Section 3.1, but needs to be carried out in Section 6.2.2 and copied to the proposal section: “Summary of how the substance meets the criteria set out in Article 57 of the REACH Regulation".
			The same applies when concluding on substances proposed to be identified in accordance with Article 57(f) REACH.
			</para>
			
				<@com.emptyLine/><section>
				<title role="HEAD-3">Bioaccumulation in aquatic organisms (pelagic and sediment organisms)</title>
				<para>
					<@keyEnvironmentalFateAndProperties.studyTable _subject "ENDPOINT_STUDY_RECORD" "BioaccumulationAquaticSediment" columnHeaders  numberOfColumns columnWidths/>
				</para>
				</section>
			
				<@com.emptyLine/><section>
				<title role="HEAD-3">Bioaccumulation in terrestrial organisms (soil dwelling organisms, vertebrates)</title>
				<para>
				<@keyEnvironmentalFateAndProperties.studyTable _subject "ENDPOINT_STUDY_RECORD" "BioaccumulationTerrestrial" columnHeaders  numberOfColumns columnWidths/>
				</para>
				</section>
				
				<@com.emptyLine/><section>
				<title role="HEAD-3">Field data</title>
				<para></para>
				</section>
				
				<section>
				<title role="HEAD-3">Summary and discussion of bioaccumulation</title>
				<para>
					<@keyEnvironmentalFateAndProperties.summaryTable _subject "ENDPOINT_SUMMARY" "Bioaccumulation" "" "Discussion"/>
		<@keyEnvironmentalFateAndProperties.summaryTable _subject "ENDPOINT_SUMMARY" "BioaccumulationAquaticSediment" "Aquatic bioaccumulation" "Discussion"/>
		<@keyEnvironmentalFateAndProperties.summaryTable _subject "ENDPOINT_SUMMARY" "BioaccumulationTerrestrial" "Terrestrial bioaccumulation" "Discussion"/>		
				</para>
				</section>			
			
		</section>
		
	</chapter>

	<chapter label="4">
	<title role="HEAD-1">Human health hazard assessment</title>
		<para>
		If the dossier aims to identify the substance addressed in the hazard classes carcinogenicity, germ cell mutagenicity or reproductive toxicity, category 1 A/B based on Annex VI of the CLP Regulation, in accordance with REACH Article 57 points (a) to (c), the section on human health hazard assessment is not relevant and therefore does not need to be filled in. It is sufficient to provide the respective harmonised classification and labelling in Section 2. The same applies in the context of a proposal to identify a substance as giving rise to an equivalent level of concern in accordance with Article 57 (f) REACH if the relevant effects relate only to environmental endpoints.
		If this section is not relevant, the following phrase can be used:
		Not relevant for the identification of the substance as SVHC in accordance with Article 57 points (a) to (c) or (f) REACH.
		If a harmonised classification for the respective effect(s) is not available, it is strongly recommended to first submit to the Agency a proposal for harmonised classification and labelling in accordance with Annex VI of Regulation (EC) No 1272/2008 (CLP Regulation) and wait for a decision taken in accordance with the procedure set out in Article 37 of the CLP Regulation.
		In case a harmonised classification has been established, supplementary information on the leading health effect(s), toxicodynamics (i.e. threshold or non-threshold MoA) and potency, if available/relevant, should not be reported in this section but in an Annex to the report (using the structure and relevant headings proposed for this section). These data may be useful to further assess the hazard potential of the substance and could be useful in the application for authorisation (AfA) phase. 
		This section also provides the basis for reporting information in the context of a proposal to identify a substance as giving rise to an equivalent level of concern in accordance with Article 57(f) REACH if the relevant effects relate to toxicological endpoints. 

		PBT considerations regarding human health hazard assessment:
		The information provided in this section can form the basis for the conclusion as to whether the substance addressed fulfils the T-criterion in accordance with Annex XIII to REACH (on the basis of toxicological effects). If the dossier proposes to conclude on the T-criterion in accordance with Section 1.1.3 (b) or (c) of Annex XIII and a harmonised classification for the respective effect(s) is not available, it is strongly recommended that a proposal for harmonised classification and labelling in accordance with Annex VI of Regulation (EC) No 1272/2008 (CLP Regulation) is first submitted to the Agency and a decision taken in accordance with the procedure set out in Article 37 of the CLP Regulation is awaited.
		This section can also be relevant for reporting information relevant for the assessment of the bioaccumulation potential of the substance, such as the toxicokinetic behaviour or data from scientific analysis in human body fluids. In such case, the information needs to be presented in such a level of detail that the reader is able to make their own basic judgement about the reliability of the information. The dossier submitter should also provide their conclusions on the reliability of the information. Furthermore, the relevance and adequacy of the presented information for the purpose of the assessment need to be described. A summary and discussion on the main conclusions regarding the toxicokinetic behaviour of the substance and the bioaccumulation potential of the substance in humans should be reported in the relevant sections below. Please note that information related to bioaccumulation in aquatic and terrestrial species should be reported under Section 3.4.
		This information will be the basis for the conclusions whether the substance fulfils the B or vB criteria according to Annex XIII to REACH and as documented in Section 6 of the Annex XV report. The comparison with Annex XIII criteria is not foreseen here, but needs to be carried out in Section 6.2 and copied to the proposal section: “Summary of how the substance meets the criteria set out in Article 57 of the REACH Regulation".
		Sub-headings which are not relevant for the substance in question should be deleted.
		</para>
		
			<@com.emptyLine/><section>
				<title role="HEAD-2">Toxicokinetics (absorption, metabolism, distribution and elimination)</title>
				<para>
				For guidance on the information to be provided in support of the bioaccumulation assessment under PBT assessment, please refer to the R.11 guidance on PBT assessment.
				</para>
				
				<@com.emptyLine/><section>
				<title role="HEAD-3">Non-human information</title>
				<@keyHumanHealthHazardAssessmentInformation.studyTable _subject "ENDPOINT_STUDY_RECORD" "BasicToxicokinetics" columnHeaders  numberOfColumns columnWidths "" />
				<@keyHumanHealthHazardAssessmentInformation.studyTable _subject "ENDPOINT_STUDY_RECORD" "DermalAbsorption" columnHeaders  numberOfColumns columnWidths "" />
	
				</section>
				
				<@com.emptyLine/><section>
				<title role="HEAD-3">Human information (including bioaccumulation in humans)</title>
					<@keyHumanHealthHazardAssessmentInformation.studyTable _subject "" "" columnHeaders numberOfColumns columnWidths humanHealthDocs "Exposure-related observations on basic toxicokinetics and/or dermal absorption in humans" "toxicokinetics"  />	
					
				</section>
				
				<@com.emptyLine/><section>
				<title role="HEAD-3">Conclusion on toxicokinetics (and bioaccumulation in humans) </title>
							<@keyHumanHealthHazardAssessmentInformation.summaryTable _subject "ENDPOINT_SUMMARY" "Toxicokinetics" "" ""/>					
				</section>				
			</section>
			
			
			<@com.emptyLine/><section>
				<title role="HEAD-2">Acute toxicity</title>
				
				<@com.emptyLine/><section>
				<title role="HEAD-3">Non-human information</title>

					<@com.emptyLine/><section>
					<title role="HEAD-3">Acute toxicity: oral</title>
					<@keyHumanHealthHazardAssessmentInformation.studyTable _subject "ENDPOINT_STUDY_RECORD" "AcuteToxicityOral" columnHeaders  numberOfColumns columnWidths "" />
		
					</section>
					<@com.emptyLine/><section>
					<title role="HEAD-3">Acute toxicity: inhalation</title>
						<@keyHumanHealthHazardAssessmentInformation.studyTable _subject "ENDPOINT_STUDY_RECORD" "AcuteToxicityInhalation" columnHeaders  numberOfColumns columnWidths "" />
		
					</section>
					<@com.emptyLine/><section>
					<title role="HEAD-3">Acute toxicity: dermal</title>
						<@keyHumanHealthHazardAssessmentInformation.studyTable _subject "ENDPOINT_STUDY_RECORD" "AcuteToxicityDermal" columnHeaders  numberOfColumns columnWidths "" />
		
					</section>
					<@com.emptyLine/>
					<section>
					<title role="HEAD-3">Acute toxicity: other routes</title>
						<@keyHumanHealthHazardAssessmentInformation.studyTable _subject "ENDPOINT_STUDY_RECORD" "AcuteToxicityOtherRoutes" columnHeaders  numberOfColumns columnWidths "" />
					</section>
				
				</section>
				
				<@com.emptyLine/><section>
				<title role="HEAD-3">Human information</title>
				<@keyHumanHealthHazardAssessmentInformation.studyTable _subject "" "" columnHeaders numberOfColumns columnWidths humanHealthDocs "" "acuteToxicity"  />
		
				</section>
				
				<@com.emptyLine/><section>
				<title role="HEAD-3">Summary and discussion of acute toxicity</title>
				<@keyHumanHealthHazardAssessmentInformation.summaryTable _subject "ENDPOINT_SUMMARY", "AcuteToxicity" "" ""/>
				</section>				
			
			</section>
			
			<@com.emptyLine/><section>
				<title role="HEAD-2">Irritation</title>
				
				<@com.emptyLine/><section>
					<title role="HEAD-3">Skin</title>

					<@com.emptyLine/><section>
						<title role="HEAD-4">Non-human information</title>
						<@keyHumanHealthHazardAssessmentInformation.studyTable _subject "ENDPOINT_STUDY_RECORD" "SkinIrritationCorrosion" columnHeaders numberOfColumns columnWidths "irritationSkin" "The results of studies on skin irritation are summarised in the following table:"  />
			
					</section>

					<@com.emptyLine/>
					<section>
						<title role="HEAD-4">Human information</title>
						<@keyHumanHealthHazardAssessmentInformation.studyTable _subject "" "" columnHeaders numberOfColumns columnWidths humanHealthDocs "Exposure related observations on skin irritation in humans" "skinIrritation" />
					</section>
				</section>
			</section>
				
			<@com.emptyLine/><section>
				<title role="HEAD-2">Corrosivity</title>
				
				<@com.emptyLine/><section>
					<title role="HEAD-3">Non-human information</title>
					<@keyHumanHealthHazardAssessmentInformation.studyTable _subject "ENDPOINT_STUDY_RECORD" "SkinIrritationCorrosion" columnHeaders numberOfColumns columnWidths "irritationCorrosion" "Studies on skin irritation related to corrosivity"  />
		
				</section>

				<@com.emptyLine/><section>
					<title role="HEAD-3">Human information</title>
					<@keyHumanHealthHazardAssessmentInformation.studyTable _subject "" "" columnHeaders numberOfColumns columnWidths humanHealthDocs "Exposure related observations on corrosivity in humans" "corrosivity" />
	
				</section>

				<@com.emptyLine/>
				<section>
					<title role="HEAD-3">Summary and discussion of corrosion</title>
						<@keyHumanHealthHazardAssessmentInformation.corrosivitySummary _subject />
				</section>
			</section>
			
			<@com.emptyLine/><section>
				<title role="HEAD-2">Sensitisation</title>
				
				<@com.emptyLine/><section>
				<title role="HEAD-3">Skin</title>

					<@com.emptyLine/><section>
						<title role="HEAD-4">Non-human information</title>
						<@keyHumanHealthHazardAssessmentInformation.studyTable _subject "ENDPOINT_STUDY_RECORD" "SkinSensitisation" columnHeaders numberOfColumns columnWidths "" />
						
						</section>

					<@com.emptyLine/>
					<section>
						<title role="HEAD-4">Human information</title>
						<@keyHumanHealthHazardAssessmentInformation.studyTable _subject "" "" columnHeaders numberOfColumns columnWidths humanHealthDocsPlus "Exposure related observations on skin sensitisation in humans" "skinSensitisation" />
			
					</section>

				</section>
				
				
				<@com.emptyLine/><section>
				<title role="HEAD-3">Respiratory system</title>

					<@com.emptyLine/><section>
						<title role="HEAD-4">Non-human information</title>
						<@keyHumanHealthHazardAssessmentInformation.studyTable _subject "ENDPOINT_STUDY_RECORD" "RespiratorySensitisation" columnHeaders numberOfColumns columnWidths "The results of studies on respiratory sensitisation are summarised in the following table:" "" />
			
					</section>
					
					<@com.emptyLine/><section>
						<title role="HEAD-4">Human information</title>
						<@keyHumanHealthHazardAssessmentInformation.studyTable _subject "" "" columnHeaders numberOfColumns columnWidths humanHealthDocsPlus "Exposure related observations on respiratory sensitisation in humans" "respiratorySystem" />
			
					</section>
				</section>
				
				<@com.emptyLine/><section>
				<title role="HEAD-3">Summary and discussion of sensitisation</title>
					<@keyHumanHealthHazardAssessmentInformation.summaryTable _subject "ENDPOINT_SUMMARY" "Sensitisation" "" ""/>
				</section>
				
			</section>
			
			<@com.emptyLine/><section>
				<title role="HEAD-2">Repeated dose toxicity</title>
				
					<@com.emptyLine/><section>
					<title role="HEAD-3">Non-human information</title>

						<@com.emptyLine/><section>
						<title role="HEAD-4">Repeated dose toxicity: oral</title>
						<para>
						<@keyHumanHealthHazardAssessmentInformation.studyTable _subject "ENDPOINT_STUDY_RECORD" "RepeatedDoseToxicityOral" columnHeaders numberOfColumns columnWidths "" "" />
			
						</para>						
						</section>
						
						<@com.emptyLine/><section>
						<title role="HEAD-4">Repeated dose toxicity: inhalation</title>
						<para>
						<@keyHumanHealthHazardAssessmentInformation.studyTable _subject "ENDPOINT_STUDY_RECORD" "RepeatedDoseToxicityInhalation" columnHeaders numberOfColumns columnWidths "" "" />
			
						</para>						
						</section>
						
						<@com.emptyLine/><section>
						<title role="HEAD-4">Repeated dose toxicity: dermal</title>
						<para>
						<@keyHumanHealthHazardAssessmentInformation.studyTable _subject "ENDPOINT_STUDY_RECORD" "RepeatedDoseToxicityDermal" columnHeaders numberOfColumns columnWidths "" "" />
			
						</para>						
						</section>
						
						<@com.emptyLine/><section>
						<title role="HEAD-4">peated dose toxicity: other routes</title>
						<para>
						<@keyHumanHealthHazardAssessmentInformation.studyTable _subject "ENDPOINT_STUDY_RECORD" "RepeatedDoseToxicityOther" columnHeaders numberOfColumns columnWidths "The results of studies on repeated dose toxicity (other routes) are summarised in the following table:" "" />
				
						</para>						
						</section>
			
					</section>
					
					<@com.emptyLine/><section>
					<title role="HEAD-3">Human information</title>
					<@keyHumanHealthHazardAssessmentInformation.studyTable _subject "" "" columnHeaders numberOfColumns columnWidths humanHealthDocs "Exposure related observations on repeated dose toxicity in humans" "repeatedDose" />
		
					</section>
					
					<@com.emptyLine/><section>
					<title role="HEAD-3">Summary and discussion of repeated dose toxicity</title>
						<@keyHumanHealthHazardAssessmentInformation.summaryTable _subject "ENDPOINT_SUMMARY" "RepeatedDoseToxicity" "" ""/>
					</section>
					
			</section>
			
			<@com.emptyLine/><section>
				<title role="HEAD-2">Mutagenicity</title>
				
					<@com.emptyLine/><section>
					<title role="HEAD-3">Non-human information</title>

						<@com.emptyLine/><section>
						<title role="HEAD-4">In vitro data</title>
						<para>	<@keyHumanHealthHazardAssessmentInformation.studyTable _subject "ENDPOINT_STUDY_RECORD" "GeneticToxicityVitro" columnHeaders numberOfColumns columnWidths "The results of in vitro genotoxicity studies are summarised in the following table:" "" />
			
						</para>
						</section>
						
						<@com.emptyLine/><section>
						<title role="HEAD-4">In vivo data</title>
						<para><@keyHumanHealthHazardAssessmentInformation.studyTable _subject "ENDPOINT_STUDY_RECORD" "GeneticToxicityVivo" columnHeaders numberOfColumns columnWidths "The results of in vivo genotoxicity studies are summarised in the following table:" "" />
			
						</para>
						</section>
						
					</section>
					
					<@com.emptyLine/><section>
					<title role="HEAD-3">Human information</title>
					<@keyHumanHealthHazardAssessmentInformation.studyTable _subject "" "" columnHeaders numberOfColumns columnWidths humanHealthDocs "Exposure-related observations genetic toxicity in humans" "mutagenicity" />
		
					</section>
					
					<@com.emptyLine/><section>
					<title role="HEAD-3">Summary and discussion of repeated dose toxicity</title>
						<@keyHumanHealthHazardAssessmentInformation.summaryTable _subject "ENDPOINT_SUMMARY" "GeneticToxicity" "The following information is taken into account for any hazard / risk assessment" ""/>
		
					</section>
						
			</section>
			
			<@com.emptyLine/><section>
				<title role="HEAD-2">Carcinogenicity</title>
				
					<@com.emptyLine/><section>
					<title role="HEAD-3">Non-human information</title>

						<@com.emptyLine/><section>
						<title role="HEAD-4">Carcinogenicity: oral</title>
						<para><@keyHumanHealthHazardAssessmentInformation.studyTable _subject "ENDPOINT_STUDY_RECORD" "Carcinogenicity" columnHeaders numberOfColumns columnWidths "carcinogenicityOral" "The results of studies on carcinogenicity after oral administration are summarised in the following table:"  />
			
						</para>
						</section>
						
						<@com.emptyLine/><section>
						<title role="HEAD-4">Carcinogenicity: inhalation</title>
						<para><@keyHumanHealthHazardAssessmentInformation.studyTable _subject "ENDPOINT_STUDY_RECORD" "Carcinogenicity" columnHeaders numberOfColumns columnWidths "carcinogenicityInhalation" "The results of studies on carcinogenicity after inhalation exposure are summarised in the following table:"  />
			
						</para>
						</section>
						
						<@com.emptyLine/><section>
						<title role="HEAD-4">Carcinogenicity: dermal</title>
						<para><@keyHumanHealthHazardAssessmentInformation.studyTable _subject "ENDPOINT_STUDY_RECORD" "Carcinogenicity" columnHeaders numberOfColumns columnWidths "carcinogenicityDermal" "The results of studies on carcinogenicity after dermal administration are summarised in the following table:"  />
					
						</para>
						</section>
						
						<@com.emptyLine/><section>
						<title role="HEAD-4">Carcinogenicity: other routes</title>
						<para><@keyHumanHealthHazardAssessmentInformation.studyTable _subject "ENDPOINT_STUDY_RECORD" "Carcinogenicity" columnHeaders numberOfColumns columnWidths "carcinogenicityOtherRoutes" "The results of studies on carcinogenicity (other routes) are summarised in the following table::"  />
			
						</para>
						</section>
						
					</section>
					
					<@com.emptyLine/><section>
					<title role="HEAD-3">Human information</title>
						<@keyHumanHealthHazardAssessmentInformation.studyTable _subject "" "" columnHeaders numberOfColumns columnWidths humanHealthDocs "Exposure related observations on carcinogenicity in humans" "carcinogenicity" />
			
					</section>
					
					<@com.emptyLine/><section>
					<title role="HEAD-3">Summary and discussion of carcinogenicity</title>
						<@keyHumanHealthHazardAssessmentInformation.summaryTable _subject "ENDPOINT_SUMMARY" "Carcinogenicity" "The following information is taken into account for any hazard / risk assessment" ""/>
		
					</section>
						
			</section>
			
			<@com.emptyLine/><section>
				<title role="HEAD-2">Toxicity for reproduction </title>
				
					<@com.emptyLine/><section>
					<title role="HEAD-3">Effects on fertility</title>

						<@com.emptyLine/><section>
						<title role="HEAD-4">Non-human information</title>
						<para><@keyHumanHealthHazardAssessmentInformation.studyTable _subject "ENDPOINT_STUDY_RECORD" "ToxicityReproduction" columnHeaders numberOfColumns columnWidths "The results of studies on fertility are summarised in the following table:" "" />
			<@keyHumanHealthHazardAssessmentInformation.studyTable _subject "ENDPOINT_STUDY_RECORD" "ToxicityReproductionOther" columnHeaders numberOfColumns columnWidths "The results of studies on the toxicity to reproduction (other studies) are summarised in the following table:" "" />
					
						</para>
						</section>
						
						<@com.emptyLine/><section>
						<title role="HEAD-4">Human information</title>
						<para><@keyHumanHealthHazardAssessmentInformation.studyTable _subject "" "" columnHeaders numberOfColumns columnWidths humanHealthDocs "Exposure-related observations on toxicity to reproduction / fertility in humans" "toxicityToReproduction" />
				
						</para>
						</section>
						
					</section>
					
					<@com.emptyLine/><section>
					<title role="HEAD-3">Developmental toxicity</title>

						<@com.emptyLine/><section>
						<title role="HEAD-4">Non-human information</title>
						<para><@keyHumanHealthHazardAssessmentInformation.studyTable _subject "ENDPOINT_STUDY_RECORD" "DevelopmentalToxicityTeratogenicity" columnHeaders numberOfColumns columnWidths "The results of studies on developmental toxicity are summarised in the following table:" "" />
					
						</para>
						</section>
						
						<@com.emptyLine/><section>
						<title role="HEAD-4">Human information</title>
						<para><@keyHumanHealthHazardAssessmentInformation.studyTable _subject "" "" columnHeaders numberOfColumns columnWidths humanHealthDocs "Exposure-related observations on the developmental toxicity in humans" "developmentalToxicity" />
					
						</para>
						</section>
						
					</section>
					
					<@com.emptyLine/><section>
					<title role="HEAD-3">Summary and discussion of reproductive toxicity</title>
						<@keyHumanHealthHazardAssessmentInformation.summaryTable _subject "ENDPOINT_SUMMARY" "ToxicityToReproduction" "The following information is taken into account for any hazard / risk assessment" ""/>
		
					</section>
						
			</section>
			
			<@com.emptyLine/><section>
				<title role="HEAD-2">Other effects</title>
				
					<@com.emptyLine/><section>
					<title role="HEAD-3">Non-human information</title>

						<@com.emptyLine/><section>
						<title role="HEAD-4">Neurotoxicity</title>
						<para><@keyHumanHealthHazardAssessmentInformation.studyTable _subject "ENDPOINT_STUDY_RECORD" "Neurotoxicity" columnHeaders numberOfColumns columnWidths "The results of studies on neurotoxicity are summarised in the following table:" "" />
				
						</para>
						</section>
						
						<@com.emptyLine/><section>
						<title role="HEAD-4">Immunotoxicity</title>
						<para><@keyHumanHealthHazardAssessmentInformation.studyTable _subject "ENDPOINT_STUDY_RECORD" "Immunotoxicity" columnHeaders numberOfColumns columnWidths "The results of studies on immunotoxicity are summarised in the following table:" "" />
			
						</para>
						</section>
						
						<@com.emptyLine/><section>
						<title role="HEAD-4">Specific investigations: other studies</title>
						<para><@keyHumanHealthHazardAssessmentInformation.studyTable _subject "ENDPOINT_STUDY_RECORD" "SpecificInvestigations" columnHeaders numberOfColumns columnWidths "The results of specific investigations (other studies) are summarised in the following table:" "" />
				
						</para>
						</section>
						
					</section>
					
					<@com.emptyLine/><section>
					<title role="HEAD-3">Human information</title>
					<@keyHumanHealthHazardAssessmentInformation.studyTable _subject "" "" columnHeaders numberOfColumns columnWidths humanHealthDocs "Exposure-related observations on neurotoxicity" "otherEffectsNeurotoxicity" />
		<@keyHumanHealthHazardAssessmentInformation.studyTable _subject "" "" columnHeaders numberOfColumns columnWidths humanHealthDocs "Exposure-related observations on immunotoxicity" "otherEffectsImmunotoxicity" />
		<@keyHumanHealthHazardAssessmentInformation.studyTable _subject "" "" columnHeaders numberOfColumns columnWidths humanHealthDocs "Exposure-related observations: endpoint not specified" "otherEffectsNotSpecified" />
		

						<@com.emptyLine/><section>
						<title role="HEAD-4">Non-human information</title>
						<para><@keyHumanHealthHazardAssessmentInformation.studyTable _subject "ENDPOINT_STUDY_RECORD" "AdditionalToxicologicalInformation" columnHeaders numberOfColumns columnWidths "The results of specific investigations (other studies) are summarised in the following table:" "" />
			
						</para>
						</section>
						
					</section>
					
					<@com.emptyLine/><section>
					<title role="HEAD-3">Endocrine disruption</title>						
					</section>
					
					<@com.emptyLine/><section>
					<title role="HEAD-3">Summary and discussion of other effects – human health</title>	
					<@keyHumanHealthHazardAssessmentInformation.summaryTable _subject "ENDPOINT_SUMMARY" "Neurotoxicity" "The following information is taken into account for any hazard / risk assessment" ""/>
		<@keyHumanHealthHazardAssessmentInformation.summaryTable _subject "ENDPOINT_SUMMARY" "Immunotoxicity" "The following information is taken into account for any hazard / risk assessment" ""/>
		<@keyHumanHealthHazardAssessmentInformation.summaryTable _subject "ENDPOINT_SUMMARY" "SpecificInvestigationsOtherStudies" "The following information is taken into account for any hazard / risk assessment" ""/>
		<@keyHumanHealthHazardAssessmentInformation.summaryTable _subject "ENDPOINT_SUMMARY" "AdditionalToxicologicalInformation" "The following information is taken into account for any hazard / risk assessment" ""/>

					</section>
			</section>
			
			<@com.emptyLine/><section>
				<title role="HEAD-2">Summary and discussion of human health hazard assessment</title>
				<para></para>
			</section>
	</chapter>		
	
	<chapter label="5">
		<title role="HEAD-1">Environmental hazard assessment</title>
		<para>
		If the dossier aims to identify the substance addressed in the hazard classes carcinogenicity, germ cell mutagenicity or reproductive toxicity, category 1 A/B, in accordance with Article 57 points (a) to (c) REACH, the section on environmental hazard assessment is not relevant and therefore does not need to be filled in. The same applies in the context of a proposal to identify a substance as giving rise to an equivalent level of concern in accordance with Article 57 (f) REACH if the relevant effects relate only to human health endpoints. If this section is not relevant, the following phrase can be used:
		Not relevant for the identification of the substance as SVHC in accordance with Article 57 points (a) to (c) or (f) REACH.
		The information provided in this section forms the basis for the conclusion as to whether the substance addressed fulfils the T-criterion in accordance with Annex XIII to REACH (on the basis of ecotoxicological effects). This section also provides the basis for reporting information in the context of a proposal to identify a substance as giving rise to an equivalent level of concern in accordance with Article 57(f) REACH if the relevant effects relate to ecotoxicological endpoints. For these purposes, the information needs to be presented in such a level of detail that the reader is able to make their own basic judgement about the reliability of the information. The dossier submitter should also provide their conclusions on the reliability of the information. Furthermore, relevance and adequacy of the presented information for the purpose of the assessment need to be described. 
		When using a weight-of-evidence approach, please consider reporting in the different sub-sections detailed information on the studies and describing in accordance with “Practical Guide 2: How to report weight of evidence” the necessary details of the weight-of-evidence approach. 
		In Section 5.6 (Summary and discussion of toxic effects) the relevant information (having relevant weight as part of the weight-of-evidence) must be summarised. 
		For substances identified as SVHC based on the PBT/vPvB-properties of relevant transformation and/or degradation products, the environmental toxicity properties of each relevant transformation and/or degradation product needs to be provided here (or as part of an Annex to the Annex XV report). The environmental toxicity properties of the parent substance and constituents (including impurities and additives) should be reported in this section also (or as part of an Annex to the Annex XV report). 
		A summary and discussion on the main conclusions of the specific toxicity of the substance to organisms in the different environmental compartments should be included in the compartment specific (sub)-sections (i.e. sub-sections 5.1 – 5.6, as relevant). 
		In addition, conclusions regarding the overall toxicity of the substance to organisms living in the different environmental compartments should be reported in Section 5.7 (Summary and discussion of the environmental hazard assessment). This information will form the basis for the conclusion whether the substance fulfils the T criteria according to Annex XIII as needs to be documented in Section 6 (Conclusions on the SVHC Properties) of the Annex XV report. The comparison with Annex XIII criteria is not foreseen to be included in Section 5.7, but needs to be carried out in Section 6.2.2 and copied to the proposal section: “Summary of how the substance meets the criteria set out in Article 57 of the REACH Regulation".
		The same applies when concluding on substances proposed to be identified in accordance with Article 57(f) REACH.

		Sub-headings which are not relevant for the substance in question should be deleted.
		</para>
			
			<@com.emptyLine/><section>
				<title role="HEAD-2">Aquatic compartment (including sediment)</title>
				
				<@com.emptyLine/><section>
				<title role="HEAD-3">Fish</title>
				
					<@com.emptyLine/><section>
					<title role="HEAD-4">Short-term toxicity to fish</title>
					<@keyEnvironmentalHazardAssessment.studyTable _subject "ENDPOINT_STUDY_RECORD" "ShortTermToxicityToFish" columnHeaders  numberOfColumns columnWidths/>
		
					<@keyEnvironmentalHazardAssessment.endpointSummary _subject "ENDPOINT_SUMMARY" "ShortTermToxicityToFish"/>		
					</section>
					<@com.emptyLine/><section>
					<title role="HEAD-4">Long-term toxicity to fish</title>
					<@keyEnvironmentalHazardAssessment.studyTable _subject "ENDPOINT_STUDY_RECORD" "LongTermToxToFish" columnHeaders  numberOfColumns columnWidths/>			
		
					<@keyEnvironmentalHazardAssessment.endpointSummary _subject "ENDPOINT_SUMMARY" "LongTermToxicityToFish"/>
					</section>
				</section>
				
				<@com.emptyLine/><section>
				<title role="HEAD-3">Aquatic invertebrates</title>
				
					<@com.emptyLine/><section>
					<title role="HEAD-4">Short-term toxicity to aquatic invertebrates</title>
						<@keyEnvironmentalHazardAssessment.studyTable _subject "ENDPOINT_STUDY_RECORD" "ShortTermToxicityToAquaInv" columnHeaders  numberOfColumns columnWidths/>
						
						<!-- Discussion -->
						<@keyEnvironmentalHazardAssessment.endpointSummary _subject "ENDPOINT_SUMMARY" "ShortTermToxicityToAquaticInvertebrates"/>	
					</section>
					<@com.emptyLine/>
					<section>
					<title role="HEAD-4">Long-term toxicity to aquatic invertebrates</title>
						<@keyEnvironmentalHazardAssessment.studyTable _subject "ENDPOINT_STUDY_RECORD" "LongTermToxicityToAquaInv" columnHeaders  numberOfColumns columnWidths/>			
					
						<!-- Discussion -->
						<@keyEnvironmentalHazardAssessment.endpointSummary _subject "ENDPOINT_SUMMARY" "LongTermToxicityToAquaticInvertebrates"/>	
					</section>
				</section>
				
				<@com.emptyLine/><section>
				<title role="HEAD-3">Algae and aquatic plants</title>
				
					<@com.emptyLine/><section>
						<title role="HEAD-4">Algae and aquatic plants</title>
							<@keyEnvironmentalHazardAssessment.studyTable _subject "ENDPOINT_STUDY_RECORD" "ToxicityToAquaticAlgae" columnHeaders  numberOfColumns columnWidths/><!--STILL TO DO -->
							<@keyEnvironmentalHazardAssessment.studyTable _subject "ENDPOINT_STUDY_RECORD" "ToxicityToAquaticPlant" columnHeaders  numberOfColumns columnWidths/><!--STILL TO DO -->

						<!-- Discussion -->		
							<@keyEnvironmentalHazardAssessment.endpointSummary _subject "ENDPOINT_SUMMARY" "ToxicityToAquaticAlgae"/>	
							<@keyEnvironmentalHazardAssessment.endpointSummary _subject "ENDPOINT_SUMMARY" "ToxicityPlants"/>		
					</section>
				</section>
				
				<@com.emptyLine/><section>
				<title role="HEAD-3">Sediment organisms</title>
				
					<@com.emptyLine/><section>
						<title role="HEAD-4">Sediment organisms</title>
						<@keyEnvironmentalHazardAssessment.studyTable _subject "ENDPOINT_STUDY_RECORD" "SedimentToxicity" columnHeaders  numberOfColumns columnWidths/>
		
									
						<!-- Discussion -->
						<@keyEnvironmentalHazardAssessment.endpointSummary _subject "ENDPOINT_SUMMARY" "SedimentToxicity"/>			
						
					</section>
				</section>
				
				<@com.emptyLine/><section>
				<title role="HEAD-3">Other aquatic organisms</title>
				
					<@com.emptyLine/><section>
						<title role="HEAD-3">Other aquatic organisms</title>
						<@keyEnvironmentalHazardAssessment.studyTable _subject "ENDPOINT_STUDY_RECORD" "ShortTermToxicityToAquaInv" columnHeaders  numberOfColumns columnWidths/>
						<@keyEnvironmentalHazardAssessment.studyTable _subject "ENDPOINT_STUDY_RECORD" "LongTermToxicityToAquaInv" columnHeaders  numberOfColumns columnWidths/>			
						<@keyEnvironmentalHazardAssessment.studyTable _subject "ENDPOINT_STUDY_RECORD" "EndocrineDisrupterTestingInAqua" columnHeaders  numberOfColumns columnWidths/>
		
							
						<!-- Discussion -->
							<@keyEnvironmentalHazardAssessment.endpointSummary _subject "ENDPOINT_SUMMARY" "ShortTermToxicityToAquaticInvertebrates"/>
						<@keyEnvironmentalHazardAssessment.endpointSummary _subject "ENDPOINT_SUMMARY" "LongTermToxicityToAquaticInvertebrates"/>	
													
					</section>
				</section>
					
			</section>
			
			<@com.emptyLine/><section>
				<title role="HEAD-2">Terrestrial compartment</title>
					
					<@com.emptyLine/><section>
					<title role="HEAD-3">Toxicity to soil macro-organisms</title>
					<para>
					<@keyEnvironmentalHazardAssessment.studyTable _subject "ENDPOINT_STUDY_RECORD" "ToxicityToSoilMacroorganismsExceptArthropods" columnHeaders  numberOfColumns columnWidths/><!--STILL TO DO -->
					<@keyEnvironmentalHazardAssessment.studyTable _subject "ENDPOINT_STUDY_RECORD" "ToxicityToTerrestrialArthropodsOtherThanBees" columnHeaders  numberOfColumns columnWidths/>

					</para>
							<@keyEnvironmentalHazardAssessment.endpointSummary _subject "ENDPOINT_SUMMARY" "ToxicityToSoilMacroorganismsExceptArthropods"/>	
		<@keyEnvironmentalHazardAssessment.endpointSummary _subject "ENDPOINT_SUMMARY" "ToxicityToTerrestrialArthropods"/>						
					</section>
					
					<@com.emptyLine/><section>
					<title role="HEAD-3">Toxicity to terrestrial plants</title>
					<para>
						<@keyEnvironmentalHazardAssessment.studyTable _subject "ENDPOINT_STUDY_RECORD" "ToxicityToTerrestrialPlants" columnHeaders  numberOfColumns columnWidths/>
		
						<@keyEnvironmentalHazardAssessment.endpointSummary _subject "ENDPOINT_SUMMARY" "ToxicityToTerrestrialPlants"/>		
					</para>					
					</section>
					
					<@com.emptyLine/><section>
					<title role="HEAD-3">Toxicity to soil micro-organisms</title>
					<para>
					<@keyEnvironmentalHazardAssessment.studyTable _subject "ENDPOINT_STUDY_RECORD" "ToxicityToSoilMicroorganisms" columnHeaders  numberOfColumns columnWidths/>
					<@keyEnvironmentalHazardAssessment.endpointSummary _subject "ENDPOINT_SUMMARY" "ToxicityToSoilMicroorganisms"/>	
					</para>					
					</section>
					
					<@com.emptyLine/><section>
					<title role="HEAD-3">Toxicity to other terrestrial organisms</title>
					<para>
					<@keyEnvironmentalHazardAssessment.studyTable _subject "ENDPOINT_STUDY_RECORD" "ToxicityToTerrestrialArthropodsOtherThanBees" columnHeaders  numberOfColumns columnWidths/>
					<!-- Toxicity to bees -->
					<@keyEnvironmentalHazardAssessment.studyTable _subject "ENDPOINT_STUDY_RECORD" "ToxicityToBees" columnHeaders numberOfColumns columnWidths/>
					
					<!-- Discussion -->
					<!-- summary for terrestrial arthropods other than bees -->
					<@keyEnvironmentalHazardAssessment.endpointSummary _subject "ENDPOINT_SUMMARY" "ToxicityToTerrestrialArthropodsOtherThanBees"/>	
					
					<!-- summary for toxicity to bees -->
					<@keyEnvironmentalHazardAssessment.endpointSummary _subject "ENDPOINT_SUMMARY" "ToxicityToBees"/>	
					</para>					
					</section>
					
			</section>
			
			<@com.emptyLine/><section>
				<title role="HEAD-2">Atmospheric compartment</title>					
			</section>
			
			<@com.emptyLine/><section>
				<title role="HEAD-2">Microbiological activity in sewage treatment systems</title>
				<para>	
					<@keyEnvironmentalHazardAssessment.studyTable _subject "ENDPOINT_STUDY_RECORD" "ToxicityToMicroorganisms" columnHeaders  numberOfColumns columnWidths/>
	
					<!-- Discussion -->
					<@keyEnvironmentalHazardAssessment.endpointSummary _subject "ENDPOINT_SUMMARY" "ToxicityMicroorganisms"/>	
				</para>
			</section>
			
			<@com.emptyLine/><section>
				<title role="HEAD-2">Toxicity to birds</title>
				<para>
					<@keyEnvironmentalHazardAssessment.studyTable _subject "ENDPOINT_STUDY_RECORD" "ToxicityToBirds" columnHeaders  numberOfColumns columnWidths/>
				
					<!-- Discussion -->
					<@keyEnvironmentalHazardAssessment.endpointSummary _subject "ENDPOINT_SUMMARY" "ToxicityToBirds"/>
				</para>
			</section>
			
			<@com.emptyLine/><section>
				<title role="HEAD-2">Other effects</title>
				<para><@keyEnvironmentalHazardAssessment.studyTable _subject "ENDPOINT_STUDY_RECORD" "ToxicityToOtherAboveGroundOrganisms" columnHeaders  numberOfColumns columnWidths/>		
				
		<!-- Discussion -->
		<@keyEnvironmentalHazardAssessment.endpointSummary _subject "ENDPOINT_SUMMARY" "ToxicityToOtherAboveGroundOrganisms"/>	
		</para>
			</section>
			
			<@com.emptyLine/><section>
				<title role="HEAD-2">Summary and discussion of the environmental hazard assessment</title>
				<para></para>
			</section>
			
	</chapter>	
	
	<chapter label="6">
		<title role="HEAD-1">Conclusions on the SVHC Properties</title>
			<@com.emptyLine/><section>
				<title role="HEAD-2">CMR assessment</title>
				
				<para>
				This section is only relevant if the intention of the Annex XV (SVHC) dossier is to identify the substance as a CMR in accordance with Article 57 points (a) to (c) REACH. A reference to the respective harmonised classification as included in Annex VI of Regulation (EC) No 1272/2008 (CLP Regulation) and provided for in Section 2 of the dossier is sufficient. Therefore, for substances meeting the criteria of Articles 57 points (a) to (c) please use one of the paragraphs provided below. Delete what is not relevant.
				<@com.substanceName _subject/> is covered by index number xxx-xxx-xx-x of Regulation (EC) No 1272/2008 in Annex VI, part 3, Table 3.1 (the list of harmonised classification and labelling of hazardous substances) and it is classified in the hazard class carcinogenicity category 1A or 1B (hazard statement H350: “May cause cancer”). 
				<@com.substanceName _subject/> is covered by index number xxx-xxx-xx-x of Regulation (EC) No 1272/2008 in Annex VI, part 3, Table 3.1 (the list of harmonised classification and labelling of hazardous substances) and it is classified in the hazard class germ cell mutagenicity category  1A or 1B (hazard statement H340: “May cause genetic defects”). 
				<@com.substanceName _subject/> is covered by index number xxx-xxx-xx-x of Regulation (EC) No 1272/2008 in Annex VI, part 3, Table 3.1 (the list of harmonised classification and labelling of hazardous substances) and it is classified in the hazard class reproductive toxicity category 1A or 1B (hazard statement ). 
				Therefore, this classification of the substance in Regulation (EC) No 1272/2008 shows that it meets the criteria for classification in the hazard class: (please delete what is not relevant)

				•	carcinogenicity category 1A or 1B in accordance with Article 57 (a) of REACH.
				•	germ cell mutagenicity category 1A or 1B in accordance with Article 57 (b) of REACH. 
				•	reproductive toxicity category 1A or 1B in accordance with Article 57 (c) of REACH.

				If this section is not relevant the following text can be used:
				Not relevant for the identification of the substance as SVHC in accordance with Article 57 points (a) to (f) REACH.
				</para>
			</section>
			
			<@com.emptyLine/><section>
				<title role="HEAD-2">PBT and vPvB assessment</title>
				
				<para>
				This section is only relevant if the intention of the Annex XV (SVHC) dossier is to identify the substance as a PBT or a vPvB in accordance with Article 57 points (d) or (e). This section is not relevant for the identification of the substance as SVHC in accordance with Article 57 points (a) to (c) and point (f).
				The data provided in Sections 2 to 5 must be compared to the criteria of Annex XIII and an overall conclusion drawn on the PBT or vPvB properties of the substance. 
				The comparison with the Annex XIII criteria need not be done for the purpose of an Annex XV SVHC dossier for each constituent/impurity/additive of the substance or for each relevant transformation/degradation product formed, as it is sufficient to demonstrate the comparison for at least one constituent/impurity/additive present in concentration above 0.1% w/w or at least one degradation or transformation product formed.   

				For the purpose of comparison of the relevant information with the Annex XIII criteria a weight-of-evidence approach is necessary in accordance with the introductory section of Annex XIII to the REACH Regulation. Any description/justification for the approach taken which in particular serves the stage of comparison of the information with the Annex XIII criteria should be added under sub-sections of the Section 6.2.1. However, it should be noted, that the detailed discussion on relevance and weight of each piece of information among all the available relevant information should be presented in Section 3.
				For substances where it is concluded that they can be identified in accordance with Article 57 points (d) and/or (e): please copy the summary and overall conclusion contained in Section 6.2.2 to the proposal, section: “Summary of how the substance meets the criteria set out in Article 57 of the REACH Regulation".
				</para>
				
					<@com.emptyLine/><section>
					<title role="HEAD-3">Assessment of PBT/vPvB properties</title>
					<para>
						Please use the following paragraph (modified as necessary) to reflect the weight-of-evidence you have used:

						A weight-of-evidence determination according to the provisions of Annex XIII of REACH is used to identify the substance as PBT/vPvB. All available information (such as the results of standard tests, monitoring and modelling, information from the application of the category and analogue approach (grouping, read-across) and (Q)SAR results) was considered together in a weight-of-evidence approach.
						
							6.2.1.1 Persistence
							6.2.1.2 Bioaccumulation
							6.2.1.3 Toxicity
					</para>					
					</section>
					
					<@com.emptyLine/><section>
					<title role="HEAD-3">Summary and overall conclusions on the PBT and vPvB properties</title>
					<para>
					In this section information should be summarised as to why the substance meets the PBT, and/or the vPvP criteria. Additionally, the summary should address and reflect the relevant facts of the assessment.
					A summary of the assessment for each criterion (property), a comparison with the Annex XIII criteria and the overall conclusion should be included in this section. Please include the following text when concluding on the assessment:

					In conclusion, the [substance name] is identified as a PBT/vPvB substance according to Art. 57(d)/(e) of REACH by comparing all relevant and available information listed in Annex XIII of REACH with the criteria set out in the same Annex, in a weight-of-evidence determination.
					</para>
					<para>
					<@keyPbtandvPvBassessment.summaryAndOverallConclusionsOnPBTorvPvBproperties _subject/>
					</para>
					</section>
				
			</section>
			
			<@com.emptyLine/><section>
				<title role="HEAD-2">Assessment under Article 57(f)</title>
					<para>
					This section is only relevant if the intention of the Annex XV (SVHC) dossier is to identify the substance as a substance giving rise to an equivalent level of concern in accordance with Article 57(f) REACH, i.e. for which there is scientific evidence of probable serious effects to human health or the environment which gives rise to an equivalent level of concern to those of other substances listed in points (a) to (e) of Article 57 of REACH. 
					This section is not relevant for the identification of the substance as SVHC in accordance with Article 57 points (a) to (e).
					Please note that the (non-exhaustive) list of discussion topics provided in Section 6.3.2 below are intended as potential starting points.
					</para>
					
					<@com.emptyLine/><section>
					<title role="HEAD-3">Summary of the data on the hazardous properties</title>
					<para>
					Where the substance is proposed as an endocrine disruptor, please explain the scientific basis for this proposal (in particular, how it meets the World Health Organisation/IPCS definition of an endocrine disruptor). A summary of the data provided in Sections 2 to 5 (and a description of any further supporting information) which leads to the conclusion that the substance has properties of relevance to the environment and/or human health (i.e. demonstrating the substance is an endocrine disruptor, is classified as a respiratory sensitiser etc.) should be included here. 
					</para>
					</section>
					
					<@com.emptyLine/><section>
					<title role="HEAD-3">Equivalent level of concern assessment</title>
					<para>
					The assessment as to why the substance gives rise to an equivalent level of concern to the substances listed in Art 57 points (a) to (e) should be made here. The assessment should involve discussing the relevant data provided in Sections 2-5 according to the non-exhaustive list of discussion points (as relevant for the substance in question) provided below, depending on whether the concern relates to human health or the environment. 
					In case of substance(s) giving rise to an equivalent level of concern to a PBT or vPvB substance the conclusions should be provided following the structure given in Section 6.2 of this template. 
					6.3.2.1 Human health
					Where the equivalent level of concern relates to a human health effect, the key information in the report should be summarised taking into account, where relevant, the following (non-exhaustive) list of discussion points:

					•	Health effects:
					o	Type and potential severity of possible health effects
					o	Irreversibility of health effects
					o	Delay of health effects
					•	Other factors: 
					o	Quality of life affected
					o	Societal concern
					o	Is derivation of a ‘safe concentration’ possible?

					6.3.2.2 Environment
					Where the equivalent level of concern relates to an environmental effect, the key information in the dossier should be discussed and summarised as to why the information justifies an equivalent level of concern. This may, if relevant, take into account one or several of the following (non-exhaustive list of) discussion points:

					•	Possible adverse environmental effects related to:
					o	Severity, e.g.:
					-	Delay of effects
					-	Inter-generational effects
					-	Impact on migratory species (spatial effects)
					-	Impact of short-term exposure (long-term effects)
					-	Potential to impair population level structure and recruitment or ecosystem function and stability

					•	Other factors: 
					o	Is derivation of a ‘safe concentration’ possible?

					Where the equivalent level of concern relates to both a human health effect and an environmental effect, the key information in the report should be summarised taking into account the relevant discussion points in (i) and (ii) above.
					</para>
					</section>
					
					<@com.emptyLine/><section>
					<title role="HEAD-3">Conclusion on the hazard properties and equivalent level of concern assessment</title>
					<para>
					An overall conclusion on the substance properties leading to the conclusion that the substance gives rise to an equivalent level of concern should be provided here and copied to the proposal section “Summary of how the substance meets the criteria set out in Article 57 of the REACH Regulation".  
					</para>
					</section>
					
			</section>
			
		</chapter>
	
	</part>
	
	<part>
		<title>Part II</title>
		<partintro>
		<para>
			The purpose of this second part is to report information which will serve the next step of the authorisation procedure. This relates to priority setting in the context of the recommendation of substances to be included in Annex XIV and for the development of the draft Annex XIV entries (transitional arrangements, review periods, exemptions of (categories of) uses). It should be noted that the aim of Part II is not to provide an exposure assessment or to conduct an assessment of possible alternatives as this goes beyond the scope of the prioritisation setting step in the authorisation process.
			Article 58(3) of REACH sets out three criteria regarding the substances to which priority for inclusion in Annex XIV to REACH shall normally be given. These are substances with
			(a)	PBT or vPvB properties, or 
			(b)	wide dispersive use, or 
			(c)	high volumes. 
			The approach for prioritisation was agreed between the Member State Committee (MSC) and ECHA and can be accessed on ECHA’s web site .
			Combined with the information on intrinsic properties from Part I, the information on tonnage and uses based on registration data (e.g. industrial/professional/consumer) and volume of the substance used within the scope of the authorisation requirement will be used for prioritisation. The assessment of priority is performed in a substance-specific manner since the inclusion in Annex XIV is per substance. Information on the uses of the substance is necessary in order to conduct this assessment. The description of the uses and the actors involved in a supply chain are an essential source of information for the development of the draft Annex XIV entry, and in particular for deciding on the sunset and latest application dates to be set. 
			Information on existing EU legislation can be considered as supplementary information that might be relevant for possible exemptions. Information on the potential for other substances on the Candidate List (including Candidate List substances that are already recommended) to substitute, or be substituted by the substance in (some of) the uses is an additional factor to be considered when assessing the priority of a substance. Any information collected by way of consultation is also welcome and can be included in the relevant section. 
			The registration dossiers are the main source of information for this part of the Annex XV report. 
			Overall, information provided on uses should allow its’ reliability and representativeness to be assessed. Therefore, information should where possible be accompanied by a description which clarifies the source of the information, the time period covered, the sector(s) / the share of the market / the number of users it represents and any other description which is relevant for the assessment of the reliability and representativeness of the information. As for Part I, it would be useful to provide a systematic documentation of uncertainties in each section, as appropriate. 

			Please ensure that only publicly available information is included in the body of the Annex XV SVHC report. All confidential information should be included in an Annex to the report. For a general list of issues to check when generating documents for which information from REACH registration dossiers is used, a document named “Checklist of confidentiality aspects in using Registration data” is available at the S-CIRCABC Regulatory Risk Management Interest Group in the “General Information” folder. In the Annex XV SVHC report, please avoid using trade-marks/brand names under which certain substances are marketed, unless there is a real need or justification why they should appear here, instead of the chemical substance name. 

			Headings / sub-headings not relevant for the substance in question should be deleted.

			In summary, the information collected under this section will provide ECHA with:
			•	data needed for the prioritisation of substances to be recommended for inclusion in Annex XIV 
			•	data for defining the transitional arrangements to be recommended 
			•	data to be able to decide if exemption(s) of uses should be recommended based on existing EU legislation.
		</para>
		</partintro>
		<chapter label="7">
		<title role="HEAD-1">Registration and C&amp;L notification status </title>
			<@com.emptyLine/><section>
				<title role="HEAD-2">Registration status </title>
				<para>
				</para>
			</section>
		
			<@com.emptyLine/><section>
				<title role="HEAD-2">CLP notification status</title>
				<para>
				</para>
			</section>
		</chapter>
		
		<chapter label="8">
		<title role="HEAD-1">Total tonnage of the substance </title>
			<para>
			The total tonnage band for a substance displayed on ECHA’s dissemination website is compiled from all registration dossiers with two exceptions: (i) tonnages that are claimed confidential and (ii) any quantity that is used as an intermediate to manufacture another substance. Please do not include confidential tonnage information in this section, but rather in a confidential annex (e.g. information on the breakdown of import/export tonnage and/or tonnage/use information). 
			</para>
		</chapter>
		
		<chapter label="9">
		<title role="HEAD-1">Information on uses of the substance</title>
			<para>
			Please report the available information on the uses of the substance in the table below including:
			o	Whether it is (i) a registered use or (ii) a non-registered use likely to occur in the EU (including the source of the information and its’ reliability and representativeness);
			o	description of the different uses (plus tonnage per use if available) and  
			-	the function(s) of the substance (e.g. binding agent, plasticiser, flame-retardant); (please note - the technical function as listed in IUCLID is considered confidential information) 
			-	the type of applications in which the substance is used, e.g. types of mixtures in which it is formulated (e.g. adhesives, sealants, paints, textile dyes, polymer mixtures…), 
			-	the sector(s) of use (e.g. building and construction work, metal production and working, plastics industry, agriculture,  textile industry, aeronautics…), 
			-	the type of articles in which the substance is incorporated 
			o	whether the substance is used at industrial sites only, or whether it is also used by professionals outside industrial sites and/or consumers, and if yes, in which applications;
			o	whether the use appears to be in the scope of the authorisation requirement, e.g. in which concentration (range) is the substance present in the respective mixtures or, whether it falls under the generic exemptions  from authorisation;
			o	whether there are downstream user reports for the substance. 
			</para>
		</chapter>
		
		<chapter label="10">
		<title role="HEAD-1">Information on structure of the supply chain</title>
			<para>
			Information on the complexity of the supply chains can support the determination of the draft Annex XIV entries, in particular defining Latest Application Dates (LADs) and Sunset Dates (SDs)  . Where possible, please include a description of supply chain(s), e.g. an estimation of the number, diversity, and spatial distribution of the actors therein, such as manufacturers / importers, distributors, levels of downstream users (including industrial, professional, and consumers), recyclers etc.
			</para>
		</chapter>
		
		<chapter label="11">
		<title role="HEAD-1">Additional information </title>
			<para>
			The types of additional information to be considered for this section include:
			</para>
			
				<@com.emptyLine/><section>
				<title role="HEAD-2">Substances with similar hazard and use profiles on the Candidate List</title>
				<para>Information on substances with similar hazard and use profiles allows ECHA to take into account certain aspects that may affect regulatory coherence and effectiveness as well as practicality at the application for authorisation phase when prioritising substances and defining the transitional arrangements. 

				If available, please report information on substances with similar hazard and use profiles, i.e.:
				-	Information on whether the substance could potentially replace or be replaced by other substances on the Candidate List for (some of) their uses, and the basis for this assumption. The basis for such assumptions is normally either explicit information obtained from industry (or experts / literature) about the potential for using the two substances in the same type(s) of applications or, a combination of structural similarities and common uses. Please note that a thorough assessment is not required here.
				-	Any data which could illustrate wide dispersiveness of the uses, e.g. any significant monitoring/epidemiological data in the EU;
				-	Other Candidate List substances that together with the substance could potentially fulfil the definition of a group in Section 1.5 of Annex XI of REACH. As a joint application for authorisation can be submitted for substances that meet the above definition, therefore it can be meaningful to allocate them to the same latest application date slot.
				</para>
				</section>
				
				<@com.emptyLine/><section>
				<title role="HEAD-2">Alternatives</title>
				<para>The term “alternatives” refers to either the use of an alternative substance, or an alternative technique or technology, or a combination of both, including changes that make the process step involving the use of the substance redundant. Information on alternatives may be used when defining LADs and SDs (for further information see the general prioritisation approach . If available, the following type of information on alternatives is considered useful:

				-	information on the work already done by companies in seeking an alternative, including information on R&amp;D activities; 
				-	any information on practical experiences with alternatives and main conclusions.
				</para>
				</section>
			
				<@com.emptyLine/><section>
				<title role="HEAD-2">Existing EU legislation</title>
				<para>Please report any information on existing EU legislation, as it applies to the substance in question. This will be used particularly in the development of draft Annex XIV entries (exemptions of (categories of) uses).
				</para>
				</section>
				
				<@com.emptyLine/><section>
				<title role="HEAD-2">Previous assessments by other authorities</title>
				<para>Please report any information on existing EU legislation, as it applies to the substance in question. This will be used particularly in the development of draft Annex XIV entries (exemptions of (categories of) uses).
				</para>
				</section>
				
		</chapter>
		
	</part>
	
	<part>
		<title>REFERENCES</title><partintro>
		<#include "Annex1_literature_references.ftl" encoding="UTF-8" /></partintro>
	</part>
	
	<part>
		<title>TEST MATERIAL INFORMATION</title><partintro>
		<#include "Annex2_test_materials.ftl" encoding="UTF-8" /></partintro>
	</part>
	
	<part>
		<title>ANNEXES</title>			
		
		<chapter label="1">
			<title role="HEAD-1">Annex I - Additional information on read across approach</title>
		</chapter>
		<chapter label="2">
			<title role="HEAD-1">Annex II - Confidential data on substance identity</title>
		</chapter>
		<chapter label="3">
			<title role="HEAD-1">Annex III - Confidential data on tonnage, import and export</title>
		</chapter>
		<chapter label="4">
			<title role="HEAD-1">Annex IV - Confidential data on uses</title>
		</chapter>	
	</part>
	
</book>

<!-- Macros and functions -->



