<!-- 1. IDENTITY OF THE SUBSTANCE AND PHYSICAL AND CHEMICAL PROPERTIES template file -->
<!-- 1.1. Substance name and public name of the substance -->
<#if !isMixture(_subject)>
<section>
	<title role="HEAD-2">Name and other identifiers of the substance</title>
		
	<#if isOriginElement(_subject)>
		<para>
			The substance <@com.substanceName _subject/> is an element having the following characteristics and physical-chemical properties (see the IUCLID dataset for further details). 
		</para>
	<#elseif isTypeOfSubstanceOther(_subject)/>
		<para>
			Type of substance <@com.substanceName _subject/>: <@com.picklist _subject.TypeOfSubstance.Composition/> [<@com.picklist _subject.TypeOfSubstance.Origin/> (origin)]. The characteristics and physical-chemical properties are described below (see the IUCLID dataset for further details). 
		</para>
	<#else/>
		<para>
			The substance <@com.substanceName _subject/> is a <@com.picklist _subject.TypeOfSubstance.Composition/> (<@com.picklist _subject.TypeOfSubstance.Origin/>) having the following characteristics and physical-chemical properties (see the IUCLID dataset for further details).
		</para>
	</#if>
	
	<para>
		<#if _subject.PublicName?has_content>The following public name is used: <@com.text _subject.PublicName/></#if>
	</para>
	
	<!-- basic substance identity including other names -->
	<@keySubstanceInformation.substanceIdentity _subject />
	
</section>

<!-- 1.2. Composition of the substance -->
<@com.emptyLine/>
<section>
	<title role="HEAD-2">Composition of the substance</title>
		
	<!-- overall substance composition for common_macro_overall_substance_composition -->
	<@keyCompositionInformation.overallSubstanceComposition _subject />
	
	<!-- substance composition for common_macro_substance_composition -->
	<@keyCompositionInformation.substanceComposition _subject />			
					
	<!-- Characterisation of nanoforms for common_macro_nanoforms -->
	<@keyNanoformInformation.nanoforms _subject />
		
</section>

<!-- 1.3. Assessment entity -->
<#if studyandsummaryCom.assessmentEntitiesExist>
<@com.emptyLine/>
<section>
	<title role="HEAD-2">Assessment entity information</title>
	
	<!-- Assessment entity information for common_macro_assessment_entities -->
	<@keyAssessmentInformation.assessmentEntityTable _subject referenceSubstance />	
	<@com.emptyLine/>
	
</section>
</#if>
</#if>

<!-- 1.4. Linked Categories -->
<@com.emptyLine/>
<section>
	<title role="HEAD-2">Information on linked categories</title>

	<!-- Category related information -->
	<@keyCategoryInformation.categoryInformation _subject />		
	
</section>

<!-- 1.5. Physicochemical properties -->
<@com.emptyLine/>
<section>
	<title role="HEAD-2">Physicochemical properties</title>
	
	<!--TODO: alternative source for Physical state -->
	
	<!-- physical chemical property data from endpoint summaries for common_macro_physical_chemical_summary_properties -->
	<@keyPhysChemInformation.physicalChemicalPropertiesTable _subject />	
	
	<!-- Data waiving (csr only) -->
	<#assign allPropertyToDataMap = propertyToDataMap + additionalPropertyToDataMap />
	<#assign properties = allPropertyToDataMap?keys />
	
	<#assign existsDataWaivingContent = false />
	
	<#assign dataWaivingContent>
		<@com.emptyLine/><para><emphasis role="HEAD-WoutNo">Data waiving</emphasis></para>
		
		<#list properties as property>
			<#assign propertyData = allPropertyToDataMap[property] />
			
			<#if propertyData["infoReq"]?has_content>
			
				<#assign recordSubType = propertyData["subType"] />
				<#if propertyData["recordSubType"]?has_content>
					<#assign recordSubType = propertyData["recordSubType"] />
				</#if>
			
				<#assign recordList = iuclid.getSectionDocumentsForParentKey(_subject.documentKey, "ENDPOINT_STUDY_RECORD", recordSubType) />
				<#assign dataWaivingList = getDataWaivingList(recordList) />
				
				<#if dataWaivingList?has_content>
					<#assign existsDataWaivingContent = true />
					<#list dataWaivingList as study>
						<para><emphasis role="bold">Information requirement:</emphasis> ${propertyData["infoReq"]!}</para>
						<para role="indent">
							<emphasis role="bold">Reason: </emphasis>
							<@com.picklist study.AdministrativeData.DataWaiving/>
						</para>
						<para role="indent">
							<emphasis role="bold">Justification:</emphasis>
							<@com.picklistMultiple study.AdministrativeData.DataWaivingJustification/>
						</para>
						<@com.emptyLine/>
					</#list>
				</#if>
			</#if>		
		</#list>
	</#assign>
	
	<#if existsDataWaivingContent>
		${dataWaivingContent}
	</#if>
		
	<!-- Testing proposal (csr only) -->
	<#assign existsTestingProposalContent = false />
	
	<#assign testingProposaContent>
		<para><emphasis role="HEAD-WoutNo">Testing proposal</emphasis></para>
		
		<#list properties as property>
			<#assign propertyData = allPropertyToDataMap[property] />
			
			<#if propertyData["infoReq"]?has_content>		
			
				<#assign recordSubType = propertyData["subType"] />
				<#if propertyData["recordSubType"]?has_content>
					<#assign recordSubType = propertyData["recordSubType"] />
				</#if>
			
				<#assign recordList = iuclid.getSectionDocumentsForParentKey(_subject.documentKey, "ENDPOINT_STUDY_RECORD", recordSubType) />
				<#assign testingProposalList = getTestingProposalList(recordList) />
				
				<#if testingProposalList?has_content>
					<#assign existsTestingProposalContent = true />
					<#list testingProposalList as study>	
						<para><emphasis role="bold">Information requirement:</emphasis> ${propertyData["infoReq"]!}</para>
						<para role="indent">
							<emphasis role="bold">Proposed test guideline:</emphasis>
							<@studyandsummaryCom.guidelineList study.MaterialsAndMethods.Guideline/>
						</para>
						<para role="indent">
							<emphasis role="bold">Principles of method if other than guideline:</emphasis>
							<?linebreak?>
							<@com.text study.MaterialsAndMethods.MethodNoGuideline/>
						</para>
						<@com.richText study.MaterialsAndMethods.AnyOtherInformationOnMaterialsAndMethodsInclTables.OtherInformation/>
						<para role="indent">
							<emphasis role="bold">Planned study period:</emphasis>
							<@com.text study.AdministrativeData.StudyPeriod/>
						</para>
						<@com.emptyLine/>
					</#list>
				</#if>
			</#if>		
		</#list>
	</#assign>
	
	<#if existsTestingProposalContent>
		${testingProposaContent}
	</#if>
	
	<!-- Summary discussion of physicochemical properties -->
	<@keyPhysChemInformation.physicalChemicalPropertiesSummary _subject/>
</section>

<!-- Macros and functions -->
<#function isOriginElement substance>
	<#if !(substance?has_content)>
		<#return false>
	</#if>
	<#if com.picklistValueMatchesPhrases(substance.TypeOfSubstance.Origin, ["element"])>
		<#return true>
	</#if>
	<#return false>
</#function>

<#function isTypeOfSubstanceOther substance>
	<#if !(substance?has_content)>
		<#return false>
	</#if>
	<#if com.isPicklistEmptyOrOther(substance.TypeOfSubstance.Composition)>
		<#return true>
	</#if>
	<#return false>
</#function>

<#function getDataWaivingList studyList>
	<#local dataWaivingStudyList = [] />
	<#if studyList?has_content>
		<#list studyList as study>
			<#if isDataWaivingStudy(study)>
				<#local dataWaivingStudyList = dataWaivingStudyList + [study] />
			</#if>
		</#list>
	</#if>
	<#return dataWaivingStudyList />
</#function>

<#function getTestingProposalList studyList>
	<#local testingProposalStudyList = [] />
	<#if studyList?has_content>
		<#list studyList as study>
			<#if isTestingProposalStudy(study)>
				<#local testingProposalStudyList = testingProposalStudyList + [study] />
			</#if>
		</#list>
	</#if>
	<#return testingProposalStudyList />
</#function>

<#function isDataWaivingStudy study>
	<#if !(study?has_content)>
		<#return false>
	</#if>
	<#local PurposeFlag = study.AdministrativeData.PurposeFlag />
	<#local DataWaiving = study.AdministrativeData.DataWaiving />
    <#return !(PurposeFlag?has_content) && DataWaiving?has_content />
</#function>

<#function isTestingProposalStudy study>
	<#if !(study?has_content)>
		<#return false>
	</#if>
    <#return com.picklistValueMatchesPhrases(study.AdministrativeData.StudyResultType, ["experimental study planned.*"]) />
</#function>