<!-- 5.11. Derivation of DNEL(s) and other hazard conclusions -->

<!-- 5.11. Selection of the DNEL(s) or other hazard conclusions for critical health effects -->
<section>
		<title role="HEAD-3">Selection of the DNEL(s) or other hazard conclusions for critical health effects</title>

	<#if dnelReport??> 
		<@generateDNELReport rootDocument />
	<#else>
		<@generateDNELReportForCSR _subject />
	</#if>
</section>
		

<#macro generateDNELReportForCSR _subject>
	<#assign summaryList = iuclid.getSectionDocumentsForParentKey(_subject.documentKey, "ENDPOINT_SUMMARY", "DataTox") />
	<#assign printSummaryName = summaryList?size gt 1 />

	<#if !(summaryList?has_content)>
		No relevant information available.

	<#else/>
		<#list summaryList as summary>
			<#if printSummaryName>
				<@com.emptyLine/>
				<para><emphasis role="bold"><@com.text summary.name/></emphasis></para>
			</#if>

		<@generateDNELReport summary />
		</#list>
	</#if>
</#macro>

<#macro generateDNELReport summary>

				<#-- Hazard conclusions for workers -->
				<table border="1">
				<title>Hazard conclusions for workers</title>
				<col width="15%" />
				<col width="20%" />
				<col width="35%" />
				<col width="30%" />
				<tbody>
					<tr>
						<th><?dbfo bgcolor="#FBDDA6" ?><emphasis role="bold">Route</emphasis></th>
						<th><?dbfo bgcolor="#FBDDA6" ?><emphasis role="bold">Type of effect</emphasis></th>
						<th><?dbfo bgcolor="#FBDDA6" ?><emphasis role="bold">Hazard conclusion</emphasis></th>
						<th><?dbfo bgcolor="#FBDDA6" ?><emphasis role="bold">Most sensitive endpoint</emphasis></th>
					</tr>

						<!-- inhalation -->
						<#if !(@hazardAssessmentMacro?has_content) && !(summary.WorkersHazardViaInhalationRoute.SystemicEffects.LongTermStudy.HazardAssessment?has_content) && !(summary.WorkersHazardViaInhalationRoute.SystemicEffects.LongTermStudy.StDose?has_content) &&
							!(summary.WorkersHazardViaInhalationRoute.SystemicEffects.LongTermStudy.MostSensitiveEndpoint?has_content) &&
							!(summary.WorkersHazardViaInhalationRoute.SystemicEffects.LongTermStudy.OriginalStudy?has_content)>
						
						No relevant information available.
						<@com.emptyLine/>
	
						<#else/>
						<tr>
							<!-- Route -->
							<td>
								<para>
									Inhalation
								</para>
							</td>
							<!-- Type of effect -->
							<td>
								<para>
									Systemic effects - Long-term
								</para>
							</td>
							<!-- Hazard conclusion -->
							<td>
								<@hazardAssessmentMacro summary.WorkersHazardViaInhalationRoute.SystemicEffects.LongTermStudy.HazardAssessment summary.WorkersHazardViaInhalationRoute.SystemicEffects.LongTermStudy.StDose />
							</td>
							<!-- Most sensitive endpoint -->
							<td>
								<#if summary.WorkersHazardViaInhalationRoute.SystemicEffects.LongTermStudy.MostSensitiveEndpoint?has_content>
									<para>
										<@com.value summary.WorkersHazardViaInhalationRoute.SystemicEffects.LongTermStudy.MostSensitiveEndpoint/>
									</para>
								</#if>

								<#if summary.WorkersHazardViaInhalationRoute.SystemicEffects.LongTermStudy.OriginalStudy?has_content>
									<para>
										(<@com.value summary.WorkersHazardViaInhalationRoute.SystemicEffects.LongTermStudy.OriginalStudy/>)
									</para>
								</#if>
							</td>
						</tr>
						</#if>
						
						<#if @hazardAssessmentMacro?has_content || summary.WorkersHazardViaInhalationRoute.SystemicEffects.AcuteShortTermExposureStudy.HazardAssessment?has_content || summary.WorkersHazardViaInhalationRoute.SystemicEffects.AcuteShortTermExposureStudy.StDose?has_content ||
							summary.WorkersHazardViaInhalationRoute.SystemicEffects.AcuteShortTermExposureStudy.MostSensitiveEndpoint?has_content ||
							summary.WorkersHazardViaInhalationRoute.SystemicEffects.AcuteShortTermExposureStudy.OriginalStudy?has_content>
						<tr>
							<!-- Route -->
							<td>
								<para>
									Inhalation
								</para>
							</td>
							<!-- Type of effect -->
							<td>
								<para>
									Systemic effects  - Acute
								</para>
							</td>
							<!-- Hazard conclusion -->
							<td>
								<@hazardAssessmentMacro summary.WorkersHazardViaInhalationRoute.SystemicEffects.AcuteShortTermExposureStudy.HazardAssessment summary.WorkersHazardViaInhalationRoute.SystemicEffects.AcuteShortTermExposureStudy.StDose/>
							</td>
							<!-- Most sensitive endpoint -->
							<td>
								<#if summary.WorkersHazardViaInhalationRoute.SystemicEffects.AcuteShortTermExposureStudy.MostSensitiveEndpoint?has_content>
									<para>
										<@com.value summary.WorkersHazardViaInhalationRoute.SystemicEffects.AcuteShortTermExposureStudy.MostSensitiveEndpoint/>
									</para>
								</#if>

								<#if summary.WorkersHazardViaInhalationRoute.SystemicEffects.AcuteShortTermExposureStudy.OriginalStudy?has_content>
									<para>
										(<@com.value summary.WorkersHazardViaInhalationRoute.SystemicEffects.AcuteShortTermExposureStudy.OriginalStudy/>)
									</para>
								</#if>
							</td>
						</tr>
						</#if>
						
						<#if @hazardAssessmentMacro?has_content || summary.WorkersHazardViaInhalationRoute.LocalEffects.LongTermNoStudy.HazardAssessment?has_content || summary.WorkersHazardViaInhalationRoute.LocalEffects.LongTermNoStudy.StDose?has_content ||
							summary.WorkersHazardViaInhalationRoute.LocalEffects.LongTermNoStudy.MostSensitiveEndpoint?has_content>
						<tr>
							<!-- Route -->
							<td>
								<para>
									Inhalation
								</para>
							</td>
							<!-- Type of effect -->
							<td>
								<para>
									Local effects - Long-term
								</para>
							</td>
							<!-- Hazard conclusion -->
							<td>
								<@hazardAssessmentMacro summary.WorkersHazardViaInhalationRoute.LocalEffects.LongTermNoStudy.HazardAssessment summary.WorkersHazardViaInhalationRoute.LocalEffects.LongTermNoStudy.StDose/>
							</td>
							<!-- Most sensitive endpoint -->
							<td>
								<para>
									<@com.value summary.WorkersHazardViaInhalationRoute.LocalEffects.LongTermNoStudy.MostSensitiveEndpoint/>
								</para>
							</td>
						</tr>
						</#if>
						
						<#if @hazardAssessmentMacro?has_content || summary.WorkersHazardViaInhalationRoute.LocalEffects.AcuteShortTermExposureStudy.HazardAssessment?has_content || summary.WorkersHazardViaInhalationRoute.LocalEffects.AcuteShortTermExposureStudy.StDose?has_content ||
							summary.WorkersHazardViaInhalationRoute.LocalEffects.LongTermNoStudy.MostSensitiveEndpoint?has_content>
						<tr>
							<!-- Route -->
							<td>
								<para>
									Inhalation
								</para>
							</td>
							<!-- Type of effect -->
							<td>
								<para>
									Local effects - Acute
								</para>
							</td>
							<!-- Hazard conclusion -->
							<td>
								<@hazardAssessmentMacro summary.WorkersHazardViaInhalationRoute.LocalEffects.AcuteShortTermExposureStudy.HazardAssessment summary.WorkersHazardViaInhalationRoute.LocalEffects.AcuteShortTermExposureStudy.StDose/>
							</td>
							<!-- Most sensitive endpoint -->
							<td>
								<#if summary.WorkersHazardViaInhalationRoute.LocalEffects.AcuteShortTermExposureStudy.MostSensitiveEndpoint?has_content>
									<para>
										<@com.value summary.WorkersHazardViaInhalationRoute.LocalEffects.AcuteShortTermExposureStudy.MostSensitiveEndpoint/>
									</para>
								</#if>
							</td>
						</tr>
						</#if>

						<#if @hazardAssessmentMacro?has_content || summary.WorkersHazardViaDermalRoute.SystemicEffects.LongTermStudy.HazardAssessment?has_content || summary.WorkersHazardViaDermalRoute.SystemicEffects.LongTermStudy.StDose?has_content ||
							summary.WorkersHazardViaDermalRoute.SystemicEffects.LongTermStudy.MostSensitiveEndpoint?has_content || summary.WorkersHazardViaDermalRoute.SystemicEffects.LongTermStudy.OriginalStudy?has_content>
						<tr>
							<!-- Route -->
							<td>
								<para>
									Dermal
								</para>
							</td>
							<!-- Type of effect -->
							<td>
								<para>
									Systemic effects - Long-term
								</para>
							</td>
							<!-- Hazard conclusion -->
							<td>
								<@hazardAssessmentMacro summary.WorkersHazardViaDermalRoute.SystemicEffects.LongTermStudy.HazardAssessment summary.WorkersHazardViaDermalRoute.SystemicEffects.LongTermStudy.StDose/>
							</td>
							<!-- Most sensitive endpoint -->
							<td>
								<#if summary.WorkersHazardViaDermalRoute.SystemicEffects.LongTermStudy.MostSensitiveEndpoint?has_content> 
									<para>
										<@com.value summary.WorkersHazardViaDermalRoute.SystemicEffects.LongTermStudy.MostSensitiveEndpoint/>
									</para>
								</#if>

								<#if summary.WorkersHazardViaDermalRoute.SystemicEffects.LongTermStudy.OriginalStudy?has_content>
									<para>
										(<@com.value summary.WorkersHazardViaDermalRoute.SystemicEffects.LongTermStudy.OriginalStudy/>)
									</para>
								</#if>
							</td>
						</tr>
						</#if>

						<#if @hazardAssessmentMacro?has_content || summary.WorkersHazardViaDermalRoute.SystemicEffects.AcuteShortTermExposureStudy.HazardAssessment?has_content || summary.WorkersHazardViaDermalRoute.SystemicEffects.AcuteShortTermExposureStudy.StDose?has_content ||
							summary.WorkersHazardViaDermalRoute.SystemicEffects.AcuteShortTermExposureStudy.MostSensitiveEndpoint?has_content || summary.WorkersHazardViaDermalRoute.SystemicEffects.AcuteShortTermExposureStudy.OriginalStudy?has_content>
						
						<tr>
							<!-- Route -->
							<td>
								<para>
									Dermal
								</para>
							</td>
							<!-- Type of effect -->
							<td>
								<para>
									Systemic effects  - Acute
								</para>
							</td>
							<!-- Hazard conclusion -->
							<td>
								<@hazardAssessmentMacro summary.WorkersHazardViaDermalRoute.SystemicEffects.AcuteShortTermExposureStudy.HazardAssessment summary.WorkersHazardViaDermalRoute.SystemicEffects.AcuteShortTermExposureStudy.StDose/>
							</td>
							<!-- Most sensitive endpoint -->
							<td>
								<#if summary.WorkersHazardViaDermalRoute.SystemicEffects.AcuteShortTermExposureStudy.MostSensitiveEndpoint?has_content>
									<para>
										<@com.value summary.WorkersHazardViaDermalRoute.SystemicEffects.AcuteShortTermExposureStudy.MostSensitiveEndpoint/>
									</para>
								</#if>

								<#if summary.WorkersHazardViaDermalRoute.SystemicEffects.AcuteShortTermExposureStudy.OriginalStudy?has_content>
									<para>
										(<@com.value summary.WorkersHazardViaDermalRoute.SystemicEffects.AcuteShortTermExposureStudy.OriginalStudy/>)
									</para>
								</#if>
							</td>
						</tr>
						</#if>
						
						<#if @hazardAssessmentMacro?has_content || summary.WorkersHazardViaDermalRoute.LocalEffects.LongTermNoStudy.HazardAssessment?has_content || summary.WorkersHazardViaDermalRoute.LocalEffects.LongTermNoStudy.StDose?has_content ||
							summary.WorkersHazardViaDermalRoute.LocalEffects.LongTermNoStudy.MostSensitiveEndpoint?has_content>
						<tr>
							<!-- Route -->
							<td>
								<para>
									Dermal
								</para>
							</td>
							<!-- Type of effect -->
							<td>
								<para>
									Local effects - Long-term
								</para>
							</td>
							<!-- Hazard conclusion -->
							<td>
								<@hazardAssessmentMacro summary.WorkersHazardViaDermalRoute.LocalEffects.LongTermNoStudy.HazardAssessment summary.WorkersHazardViaDermalRoute.LocalEffects.LongTermNoStudy.StDose/>
							</td>
							<!-- Most sensitive endpoint -->
							<td>
								<#if summary.WorkersHazardViaDermalRoute.LocalEffects.LongTermNoStudy.MostSensitiveEndpoint?has_content>
									<para>
										<@com.value summary.WorkersHazardViaDermalRoute.LocalEffects.LongTermNoStudy.MostSensitiveEndpoint/>
									</para>
								</#if>
							</td>
						</tr>
						</#if>

						<#if @hazardAssessmentMacro?has_content || summary.WorkersHazardViaDermalRoute.LocalEffects.AcuteShortTermExposureStudy.HazardAssessment?has_content || summary.WorkersHazardViaDermalRoute.LocalEffects.AcuteShortTermExposureStudy.StDose?has_content ||
							summary.WorkersHazardViaDermalRoute.LocalEffects.AcuteShortTermExposureStudy.MostSensitiveEndpoint?has_content>
						<tr>
							<!-- Route -->
							<td>
								<para>
									Dermal
								</para>
							</td>
							<!-- Type of effect -->
							<td>
								<para>
									Local effects - Acute
								</para>
							</td>
							<!-- Hazard conclusion -->
							<td>
								<@hazardAssessmentMacro summary.WorkersHazardViaDermalRoute.LocalEffects.AcuteShortTermExposureStudy.HazardAssessment summary.WorkersHazardViaDermalRoute.LocalEffects.AcuteShortTermExposureStudy.StDose/>
							</td>
							<!-- Most sensitive endpoint -->
							<td>
								<#if summary.WorkersHazardViaDermalRoute.LocalEffects.AcuteShortTermExposureStudy.MostSensitiveEndpoint?has_content>
									<para>
										<@com.value summary.WorkersHazardViaDermalRoute.LocalEffects.AcuteShortTermExposureStudy.MostSensitiveEndpoint/>
									</para>
								</#if>
							</td>
						</tr>
						</#if>
						
						<#if summary.WorkersHazardForTheEyes.EyesLocalEffects.Conclusion?has_content>
						<tr>
							<!-- Route -->
							<td>
								<para>
									Eyes
								</para>
							</td>
							<!-- Type of effect -->
							<td>
								<para>
									Local effects
								</para>
							</td>
							<!-- Hazard conclusion -->
							<td>
								<#if summary.WorkersHazardForTheEyes.EyesLocalEffects.Conclusion?has_content>
									<para>
										<@com.value summary.WorkersHazardForTheEyes.EyesLocalEffects.Conclusion/>
									</para>
								</#if>
							</td>
							<!-- Most sensitive endpoint -->
							<td>
								<para>
									<!-- empty -->
								</para>
							</td>
						</tr>
						</#if>
				</tbody>
			    </table>
				<@com.emptyLine/>

                <@toxInfoEffectsWorkers summary />
                <#if summary.AdditionalInformationWorkers.DiscussionWorkers?has_content >
                    <para><emphasis role="bold">Discussion:</emphasis></para>
                    <para><@com.richText summary.AdditionalInformationWorkers.DiscussionWorkers/></para>
                </#if>

		    	<!-- Hazard conclusions for the general population -->
				<@com.emptyLine/>
				<table border="1">
				<title>Hazard conclusions for the general population</title>
				<col width="15%" />
				<col width="20%" />
				<col width="35%" />
				<col width="30%" />
				<tbody>
					<tr>
						<th><?dbfo bgcolor="#FBDDA6" ?><emphasis role="bold">Route</emphasis></th>
						<th><?dbfo bgcolor="#FBDDA6" ?><emphasis role="bold">Type of effect</emphasis></th>
						<th><?dbfo bgcolor="#FBDDA6" ?><emphasis role="bold">Hazard conclusion</emphasis></th>
						<th><?dbfo bgcolor="#FBDDA6" ?><emphasis role="bold">Most sensitive endpoint</emphasis></th>
					</tr>
					
					
						<!-- inhalation -->
						<#if summary.GeneralPopulationHazardViaInhalationRoute.SystemicEffects.LongTermStudy.HazardAssessment?has_content ||
							summary.GeneralPopulationHazardViaInhalationRoute.SystemicEffects.LongTermStudy.StDose?has_content ||
							summary.GeneralPopulationHazardViaInhalationRoute.SystemicEffects.LongTermStudy.MostSensitiveEndpoint?has_content ||
							summary.GeneralPopulationHazardViaInhalationRoute.SystemicEffects.LongTermStudy.OriginalStudy?has_content>
						<tr>							
							<!-- Route -->
							<td>
								<para>
									Inhalation
								</para>
							</td>
							<!-- Type of effect -->
							<td>
								<para>
									Systemic effects - Long-term
								</para>
							</td>
							<!-- Hazard conclusion -->
							<td>
								<#if summary.GeneralPopulationHazardViaInhalationRoute.SystemicEffects.LongTermStudy.HazardAssessment?has_content>										
									<para>
										<@com.value summary.GeneralPopulationHazardViaInhalationRoute.SystemicEffects.LongTermStudy.HazardAssessment/>
									</para>
								</#if>

								<#if summary.GeneralPopulationHazardViaInhalationRoute.SystemicEffects.LongTermStudy.StDose?has_content>
									<para>									
										<@com.quantity summary.GeneralPopulationHazardViaInhalationRoute.SystemicEffects.LongTermStudy.StDose/>
									</para>
								</#if>
							</td>
							<!-- Most sensitive endpoint -->
							<td>
								<#if summary.GeneralPopulationHazardViaInhalationRoute.SystemicEffects.LongTermStudy.MostSensitiveEndpoint?has_content>	
									<para>
										<@com.value summary.GeneralPopulationHazardViaInhalationRoute.SystemicEffects.LongTermStudy.MostSensitiveEndpoint/>
									</para>
								</#if>

								<#if summary.GeneralPopulationHazardViaInhalationRoute.SystemicEffects.LongTermStudy.OriginalStudy?has_content>
									<para>
										(<@com.value summary.GeneralPopulationHazardViaInhalationRoute.SystemicEffects.LongTermStudy.OriginalStudy/>)
									</para>
								</#if>
							</td>							
						</tr>
						</#if>
						
						<#if summary.GeneralPopulationHazardViaInhalationRoute.SystemicEffects.AcuteShortTermExposureStudy.HazardAssessment?has_content ||
							summary.GeneralPopulationHazardViaInhalationRoute.SystemicEffects.AcuteShortTermExposureStudy.HazardAssessment?has_content ||
							summary.GeneralPopulationHazardViaInhalationRoute.SystemicEffects.AcuteShortTermExposureStudy.MostSensitiveEndpoint?has_content ||
							summary.GeneralPopulationHazardViaInhalationRoute.SystemicEffects.AcuteShortTermExposureStudy.OriginalStudy?has_content>
						<tr>
							<!-- Route -->
							<td>
								<para>
									Inhalation
								</para>
							</td>
							<!-- Type of effect -->
							<td>
								<para>
									Systemic effects  - Acute
								</para>
							</td>
							<!-- Hazard conclusion -->
							<td>
								<#if summary.GeneralPopulationHazardViaInhalationRoute.SystemicEffects.AcuteShortTermExposureStudy.HazardAssessment?has_content>
									<para>
										<@com.value summary.GeneralPopulationHazardViaInhalationRoute.SystemicEffects.AcuteShortTermExposureStudy.HazardAssessment/>
									</para>
								</#if>
								
								<#if summary.GeneralPopulationHazardViaInhalationRoute.SystemicEffects.AcuteShortTermExposureStudy.HazardAssessment?has_content>
									<para>
										<@com.quantity summary.GeneralPopulationHazardViaInhalationRoute.SystemicEffects.AcuteShortTermExposureStudy.StDose/>
									</para>
								</#if>
							</td>
							<!-- Most sensitive endpoint -->
							<td>
								<#if summary.GeneralPopulationHazardViaInhalationRoute.SystemicEffects.AcuteShortTermExposureStudy.MostSensitiveEndpoint?has_content>
									<para>
										<@com.value summary.GeneralPopulationHazardViaInhalationRoute.SystemicEffects.AcuteShortTermExposureStudy.MostSensitiveEndpoint/>
									</para>
								</#if>

								<#if summary.GeneralPopulationHazardViaInhalationRoute.SystemicEffects.AcuteShortTermExposureStudy.OriginalStudy?has_content>
									<para>
										(<@com.value summary.GeneralPopulationHazardViaInhalationRoute.SystemicEffects.AcuteShortTermExposureStudy.OriginalStudy/>)
									</para>
								</#if>
							</td>
						</tr>
						</#if>
						
						<#if summary.GeneralPopulationHazardViaInhalationRoute.LocalEffects.LongTermNoStudy.HazardAssessment?has_content ||
							summary.GeneralPopulationHazardViaInhalationRoute.LocalEffects.LongTermNoStudy.StDose?has_content ||
							summary.GeneralPopulationHazardViaInhalationRoute.LocalEffects.LongTermNoStudy.MostSensitiveEndpoint?has_content>
						<tr>
							<!-- Route -->
							<td>
								<para>
									Inhalation
								</para>
							</td>
							<!-- Type of effect -->
							<td>
								<para>
									Local effects - Long-term
								</para>
							</td>
							<!-- Hazard conclusion -->
							<td>
								<#if summary.GeneralPopulationHazardViaInhalationRoute.LocalEffects.LongTermNoStudy.HazardAssessment?has_content>
									<para>
										<@com.value summary.GeneralPopulationHazardViaInhalationRoute.LocalEffects.LongTermNoStudy.HazardAssessment/>
									</para>
								</#if>
								
								<#if summary.GeneralPopulationHazardViaInhalationRoute.LocalEffects.LongTermNoStudy.StDose?has_content>
									<para>
										<@com.quantity summary.GeneralPopulationHazardViaInhalationRoute.LocalEffects.LongTermNoStudy.StDose/>
									</para>
								</#if>
							</td>
							<!-- Most sensitive endpoint -->
							<td>
								<#if summary.GeneralPopulationHazardViaInhalationRoute.LocalEffects.LongTermNoStudy.MostSensitiveEndpoint?has_content>
									<para>
										<@com.value summary.GeneralPopulationHazardViaInhalationRoute.LocalEffects.LongTermNoStudy.MostSensitiveEndpoint/>
									</para>
								</#if>
							</td>
						</tr>
						</#if>
						
						<#if summary.GeneralPopulationHazardViaInhalationRoute.LocalEffects.AcuteShortTermExposureStudy.HazardAssessment?has_content ||
							summary.GeneralPopulationHazardViaInhalationRoute.LocalEffects.AcuteShortTermExposureStudy.StDose?has_content ||
							summary.GeneralPopulationHazardViaInhalationRoute.LocalEffects.AcuteShortTermExposureStudy.MostSensitiveEndpoint?has_content>
						<tr>
							<!-- Route -->
							<td>
								<para>
									Inhalation
								</para>
							</td>
							<!-- Type of effect -->
							<td>
								<para>
									Local effects - Acute
								</para>
							</td>
							<!-- Hazard conclusion -->
							<td>
								<#if summary.GeneralPopulationHazardViaInhalationRoute.LocalEffects.AcuteShortTermExposureStudy.HazardAssessment?has_content>
									<para>
										<@com.value summary.GeneralPopulationHazardViaInhalationRoute.LocalEffects.AcuteShortTermExposureStudy.HazardAssessment/>
									</para>
								</#if>
								
								<#if summary.GeneralPopulationHazardViaInhalationRoute.LocalEffects.AcuteShortTermExposureStudy.StDose?has_content>
									<para>
										<@com.quantity summary.GeneralPopulationHazardViaInhalationRoute.LocalEffects.AcuteShortTermExposureStudy.StDose/>
									</para>
								</#if>
							</td>
							<!-- Most sensitive endpoint -->
							<td>
								<#if summary.GeneralPopulationHazardViaInhalationRoute.LocalEffects.AcuteShortTermExposureStudy.MostSensitiveEndpoint?has_content>
									<para>
										<@com.value summary.GeneralPopulationHazardViaInhalationRoute.LocalEffects.AcuteShortTermExposureStudy.MostSensitiveEndpoint/>
									</para>
								</#if>
							</td>
						</tr>
						</#if>
						
						<#if summary.GeneralPopulationHazardViaDermalRoute.SystemicEffects.LongTermStudy.HazardAssessment?has_content ||
							summary.GeneralPopulationHazardViaDermalRoute.SystemicEffects.LongTermStudy.StDose?has_content ||
							summary.GeneralPopulationHazardViaDermalRoute.SystemicEffects.LongTermStudy.MostSensitiveEndpoint?has_content ||
							summary.GeneralPopulationHazardViaDermalRoute.SystemicEffects.LongTermStudy.OriginalStudy?has_content>
						<tr>
							<!-- Route -->
							<td>
								<para>
									Dermal
								</para>
							</td>
							<!-- Type of effect -->
							<td>
								<para>
									Systemic effects - Long-term
								</para>
							</td>
							<!-- Hazard conclusion -->
							<td>
								<#if summary.GeneralPopulationHazardViaDermalRoute.SystemicEffects.LongTermStudy.HazardAssessment?has_content>
									<para>
										<@com.value summary.GeneralPopulationHazardViaDermalRoute.SystemicEffects.LongTermStudy.HazardAssessment/>
									</para>
								</#if>
								
								<#if summary.GeneralPopulationHazardViaDermalRoute.SystemicEffects.LongTermStudy.StDose?has_content>
									<para>
										<@com.quantity summary.GeneralPopulationHazardViaDermalRoute.SystemicEffects.LongTermStudy.StDose/>
									</para>
								</#if>
							</td>
							<!-- Most sensitive endpoint -->
							<td>
								<#if summary.GeneralPopulationHazardViaDermalRoute.SystemicEffects.LongTermStudy.MostSensitiveEndpoint?has_content>
									<para>
										<@com.value summary.GeneralPopulationHazardViaDermalRoute.SystemicEffects.LongTermStudy.MostSensitiveEndpoint/>
									</para>
								</#if>

								<#if summary.GeneralPopulationHazardViaDermalRoute.SystemicEffects.LongTermStudy.OriginalStudy?has_content>
									<para>
										(<@com.value summary.GeneralPopulationHazardViaDermalRoute.SystemicEffects.LongTermStudy.OriginalStudy/>)
									</para>
								</#if>
							</td>
						</tr>
						</#if>

						<#if summary.GeneralPopulationHazardViaDermalRoute.SystemicEffects.AcuteShortTermExposureStudy.HazardAssessment?has_content ||
							summary.GeneralPopulationHazardViaDermalRoute.SystemicEffects.AcuteShortTermExposureStudy.StDose?has_content ||
							summary.GeneralPopulationHazardViaDermalRoute.SystemicEffects.AcuteShortTermExposureStudy.MostSensitiveEndpoint?has_content ||
							summary.GeneralPopulationHazardViaDermalRoute.SystemicEffects.AcuteShortTermExposureStudy.OriginalStudy?has_content>
						<tr>
							<!-- Route -->
							<td>
								<para>
									Dermal
								</para>
							</td>
							<!-- Type of effect -->
							<td>
								<para>
									Systemic effects  - Acute
								</para>
							</td>
							<!-- Hazard conclusion -->
							<td>
								<#if summary.GeneralPopulationHazardViaDermalRoute.SystemicEffects.AcuteShortTermExposureStudy.HazardAssessment?has_content>
									<para>
										<@com.value summary.GeneralPopulationHazardViaDermalRoute.SystemicEffects.AcuteShortTermExposureStudy.HazardAssessment/>
									</para>
								</#if>
								
								<#if summary.GeneralPopulationHazardViaDermalRoute.SystemicEffects.AcuteShortTermExposureStudy.StDose?has_content>
									<para>
										<@com.quantity summary.GeneralPopulationHazardViaDermalRoute.SystemicEffects.AcuteShortTermExposureStudy.StDose/>
									</para>
								</#if>
							</td>
							<!-- Most sensitive endpoint -->
							<td>
								<#if summary.GeneralPopulationHazardViaDermalRoute.SystemicEffects.AcuteShortTermExposureStudy.MostSensitiveEndpoint?has_content>
									<para>
										<@com.value summary.GeneralPopulationHazardViaDermalRoute.SystemicEffects.AcuteShortTermExposureStudy.MostSensitiveEndpoint/>
									</para>
								</#if>

								<#if summary.GeneralPopulationHazardViaDermalRoute.SystemicEffects.AcuteShortTermExposureStudy.OriginalStudy?has_content>
									<para>
										(<@com.value summary.GeneralPopulationHazardViaDermalRoute.SystemicEffects.AcuteShortTermExposureStudy.OriginalStudy/>)
									</para>
								</#if>
							</td>
						</tr>
						</#if>
						
						<#if summary.GeneralPopulationHazardViaDermalRoute.LocalEffects.LongTermNoStudy.HazardAssessment?has_content ||
							summary.GeneralPopulationHazardViaDermalRoute.LocalEffects.LongTermNoStudy.StDose?has_content ||
							summary.GeneralPopulationHazardViaDermalRoute.LocalEffects.LongTermNoStudy.MostSensitiveEndpoint?has_content>
						<tr>
							<!-- Route -->
							<td>
								<para>
									Dermal
								</para>
							</td>
							<!-- Type of effect -->
							<td>
								<para>
									Local effects - Long-term
								</para>
							</td>
							<!-- Hazard conclusion -->
							<td>
								<#if summary.GeneralPopulationHazardViaDermalRoute.LocalEffects.LongTermNoStudy.HazardAssessment?has_content>
									<para>
										<@com.value summary.GeneralPopulationHazardViaDermalRoute.LocalEffects.LongTermNoStudy.HazardAssessment/>
									</para>
								</#if>
								
								<#if summary.GeneralPopulationHazardViaDermalRoute.LocalEffects.LongTermNoStudy.StDose?has_content>
									<para>
										<@com.quantity summary.GeneralPopulationHazardViaDermalRoute.LocalEffects.LongTermNoStudy.StDose/>
									</para>
								</#if>
							</td>
							<!-- Most sensitive endpoint -->
							<td>
								<#if summary.GeneralPopulationHazardViaDermalRoute.LocalEffects.LongTermNoStudy.MostSensitiveEndpoint?has_content>
									<para>
										<@com.value summary.GeneralPopulationHazardViaDermalRoute.LocalEffects.LongTermNoStudy.MostSensitiveEndpoint/>
									</para>
								</#if>
							</td>
						</tr>
						</#if>
						
						<#if summary.GeneralPopulationHazardViaDermalRoute.LocalEffects.AcuteShortTermExposureStudy.HazardAssessment?has_content ||
							summary.GeneralPopulationHazardViaDermalRoute.LocalEffects.AcuteShortTermExposureStudy.StDose?has_content ||
							summary.GeneralPopulationHazardViaDermalRoute.LocalEffects.AcuteShortTermExposureStudy.MostSensitiveEndpoint?has_content>
						<tr>
							<!-- Route -->
							<td>
								<para>
									Dermal
								</para>
							</td>
							<!-- Type of effect -->
							<td>
								<para>
									Local effects - Acute
								</para>
							</td>
							<!-- Hazard conclusion -->
							<td>
								<#if summary.GeneralPopulationHazardViaDermalRoute.LocalEffects.AcuteShortTermExposureStudy.HazardAssessment?has_content>
									<para>
										<@com.value summary.GeneralPopulationHazardViaDermalRoute.LocalEffects.AcuteShortTermExposureStudy.HazardAssessment/>
									</para>
								</#if>
								
								<#if summary.GeneralPopulationHazardViaDermalRoute.LocalEffects.AcuteShortTermExposureStudy.StDose?has_content>
									<para>
										<@com.quantity summary.GeneralPopulationHazardViaDermalRoute.LocalEffects.AcuteShortTermExposureStudy.StDose/>
									</para>
								</#if>
							</td>
							<!-- Most sensitive endpoint -->
							<td>
								<#if summary.GeneralPopulationHazardViaDermalRoute.LocalEffects.AcuteShortTermExposureStudy.MostSensitiveEndpoint?has_content>
									<para>
										<@com.value summary.GeneralPopulationHazardViaDermalRoute.LocalEffects.AcuteShortTermExposureStudy.MostSensitiveEndpoint/>
									</para>
								</#if>
							</td>
						</tr>
						</#if>
						
						<#if summary.GeneralPopulationHazardViaOralRoute.SystemicEffects.LongTermStudy.HazardAssessment?has_content ||
							summary.GeneralPopulationHazardViaOralRoute.SystemicEffects.LongTermStudy.StDose?has_content ||
							summary.GeneralPopulationHazardViaOralRoute.SystemicEffects.LongTermStudy.MostSensitiveEndpoint?has_content ||
							summary.GeneralPopulationHazardViaOralRoute.SystemicEffects.LongTermStudy.OriginalStudy?has_content>
						<tr>
							<!-- Route -->
							<td>
								<para>
									Oral
								</para>
							</td>
							<!-- Type of effect -->
							<td>
								<para>
									Systemic effects - Long-term
								</para>
							</td>
							<!-- Hazard conclusion -->
							<td>
								<#if summary.GeneralPopulationHazardViaOralRoute.SystemicEffects.LongTermStudy.HazardAssessment?has_content>
									<para>
										<@com.value summary.GeneralPopulationHazardViaOralRoute.SystemicEffects.LongTermStudy.HazardAssessment/>
									</para>
								</#if>

								<#if summary.GeneralPopulationHazardViaOralRoute.SystemicEffects.LongTermStudy.StDose?has_content>
									<para>
										<@com.quantity summary.GeneralPopulationHazardViaOralRoute.SystemicEffects.LongTermStudy.StDose/>
									</para>
								</#if>
							</td>
							<!-- Most sensitive endpoint -->
							<td>
								<#if summary.GeneralPopulationHazardViaOralRoute.SystemicEffects.LongTermStudy.MostSensitiveEndpoint?has_content>
									<para>
										<@com.value summary.GeneralPopulationHazardViaOralRoute.SystemicEffects.LongTermStudy.MostSensitiveEndpoint/>
									</para>
								</#if>

								<#if summary.GeneralPopulationHazardViaOralRoute.SystemicEffects.LongTermStudy.OriginalStudy?has_content>
									<para>
										(<@com.value summary.GeneralPopulationHazardViaOralRoute.SystemicEffects.LongTermStudy.OriginalStudy/>)
									</para>
								</#if>
							</td>
						</tr>
						</#if>
						
						<#if summary.GeneralPopulationHazardViaOralRoute.SystemicEffects.AcuteShortTermExposureStudy.HazardAssessment?has_content ||
							summary.GeneralPopulationHazardViaOralRoute.SystemicEffects.AcuteShortTermExposureStudy.StDose?has_content ||
							summary.GeneralPopulationHazardViaOralRoute.SystemicEffects.AcuteShortTermExposureStudy.MostSensitiveEndpoint?has_content ||
							summary.GeneralPopulationHazardViaOralRoute.SystemicEffects.AcuteShortTermExposureStudy.OriginalStudy?has_content>
						
						<tr>
							<!-- Route -->
							<td>
								<para>
									Oral
								</para>
							</td>
							<!-- Type of effect -->
							<td>
								<para>
									Systemic effects  - Acute
								</para>
							</td>
							<!-- Hazard conclusion -->
							<td>
								<#if summary.GeneralPopulationHazardViaOralRoute.SystemicEffects.AcuteShortTermExposureStudy.HazardAssessment?has_content>
									<para>
										<@com.value summary.GeneralPopulationHazardViaOralRoute.SystemicEffects.AcuteShortTermExposureStudy.HazardAssessment/>
									</para>
								</#if>
								
								<#if summary.GeneralPopulationHazardViaOralRoute.SystemicEffects.AcuteShortTermExposureStudy.StDose?has_content>
									<para>
										<@com.quantity summary.GeneralPopulationHazardViaOralRoute.SystemicEffects.AcuteShortTermExposureStudy.StDose/>
									</para>
								</#if>
							</td>
							<!-- Most sensitive endpoint -->
							<td>
								<#if summary.GeneralPopulationHazardViaOralRoute.SystemicEffects.AcuteShortTermExposureStudy.MostSensitiveEndpoint?has_content>
									<para>
										<@com.value summary.GeneralPopulationHazardViaOralRoute.SystemicEffects.AcuteShortTermExposureStudy.MostSensitiveEndpoint/>
									</para>
								</#if>

								<#if summary.GeneralPopulationHazardViaOralRoute.SystemicEffects.AcuteShortTermExposureStudy.OriginalStudy?has_content>
									<para>
										(<@com.value summary.GeneralPopulationHazardViaOralRoute.SystemicEffects.AcuteShortTermExposureStudy.OriginalStudy/>)
									</para>
								</#if>
							</td>
						</tr>
						</#if>
						
						<#if summary.WorkersHazardForTheEyes.EyesLocalEffects.Conclusion?has_content>
						<tr>
							<!-- Route -->
							<td>
								<para>
									Eyes
								</para>
							</td>
							<!-- Type of effect -->
							<td>
								<para>
									Local effects
								</para>
							</td>
							<!-- Hazard conclusion -->
							<td>
								<#if summary.WorkersHazardForTheEyes.EyesLocalEffects.Conclusion?has_content>
									<para>
										<@com.value summary.WorkersHazardForTheEyes.EyesLocalEffects.Conclusion/>
									</para>
								</#if>
							</td>
							<!-- Most sensitive endpoint -->
							<td>
								<para>
									<!-- empty -->
								</para>
							</td>
						</tr>
						</#if>
				</tbody>
			    </table>
				<@com.emptyLine/>
                <@toxInfoEffectsGeneralPopulation summary />
                <#if summary.AdditionalInformationGeneralPopulation.DiscussionGenPop?has_content >
                    <para><emphasis role="bold">Discussion:</emphasis></para>
                    <para><@com.richText summary.AdditionalInformationGeneralPopulation.DiscussionGenPop/></para>
                </#if>
</#macro>

<#macro AFJustification af justification label>
    <#if af?has_content>
        <#if af != 1 || (af == 1 && justification?has_content)>
        <para role="indent"><emphasis role="bold">${label}</emphasis> <@com.number af/> <#if justification?has_content>(<@com.text justification/>)</#if></para>
        </#if>
    </#if>
</#macro>

<#macro toxInfoEffectsWorkers summary>
    
	<#local valueForSystemicEffectsLongTermInhalation = summary.WorkersHazardViaInhalationRoute.SystemicEffects.LongTermStudy />	
		<#if valueForSystemicEffectsLongTermInhalation?has_content>
			<@com.emptyLine/><@toxInfoSystemicEffectsLongTerm summary "WorkersHazardViaInhalationRoute" "Inhalation Systemic effects - Long-term" />	
		</#if>
    <#local valueForSystemicEffectsAcuteInhalation = summary.WorkersHazardViaInhalationRoute.SystemicEffects.AcuteShortTermExposureStudy />	
		<#if valueForSystemicEffectsAcuteInhalation?has_content>
			<@com.emptyLine/><@toxInfoSystemicEffectsAcute summary "WorkersHazardViaInhalationRoute" "Inhalation Systemic effects - Acute" />
		</#if>
	<#local valueForLocalEffectsLongTermInhalation = summary.WorkersHazardViaInhalationRoute.LocalEffects.LongTermNoStudy />	
		<#if valueForLocalEffectsLongTermInhalation?has_content>	
			<@com.emptyLine/><@toxInfoLocalEffectsLongTerm summary "WorkersHazardViaInhalationRoute" "Inhalation Local effects - Long-term" />
		</#if>
	<#local valueForLocalEffectsAcuteInhalation = summary.WorkersHazardViaInhalationRoute.LocalEffects.AcuteShortTermExposureStudy />	
		<#if valueForLocalEffectsAcuteInhalation?has_content>	
			<@com.emptyLine/><@toxInfoLocalEffectsAcute summary "WorkersHazardViaInhalationRoute" "Inhalation Local effects - Acute" />
		</#if>
	
	<#local valueForSystemicEffectsLongTermDermal = summary.WorkersHazardViaDermalRoute.SystemicEffects.LongTermStudy />	
		<#if valueForSystemicEffectsLongTermDermal?has_content>
			<@com.emptyLine/><@toxInfoSystemicEffectsLongTerm summary "WorkersHazardViaDermalRoute" "Dermal Systemic effects - Long-term" />
		</#if>
	<#local valueForSystemicEffectsAcuteDermal = summary.WorkersHazardViaDermalRoute.SystemicEffects.AcuteShortTermExposureStudy />	
		<#if valueForSystemicEffectsAcuteDermal?has_content>
			<@com.emptyLine/><@toxInfoSystemicEffectsAcute summary "WorkersHazardViaDermalRoute" "Dermal Systemic effects - Acute" />
		</#if>
	<#local valueForLocalEffectsLongTermDermal = summary.WorkersHazardViaDermalRoute.LocalEffects.LongTermNoStudy />	
		<#if valueForLocalEffectsLongTermDermal?has_content>
			<@com.emptyLine/><@toxInfoLocalEffectsLongTerm summary "WorkersHazardViaDermalRoute" "Dermal Local effects - Long-term" />
		</#if>
	<#local valueForLocalEffectsAcuteDermal = summary.WorkersHazardViaDermalRoute.LocalEffects.AcuteShortTermExposureStudy />	
		<#if valueForLocalEffectsAcuteDermal?has_content>	
			<@com.emptyLine/><@toxInfoLocalEffectsAcute summary "WorkersHazardViaDermalRoute" "Dermal Local effects - Acute" false />
		</#if>
</#macro>

<#macro toxInfoEffectsGeneralPopulation summary>
    <#local valueForSystemicEffectsLongTermGeneralPopInhalation = summary.GeneralPopulationHazardViaInhalationRoute.SystemicEffects.LongTermStudy />	
		<#if valueForSystemicEffectsLongTermGeneralPopInhalation?has_content>
			<@com.emptyLine/><@toxInfoSystemicEffectsLongTerm summary "GeneralPopulationHazardViaInhalationRoute" "Inhalation Systemic effects - Long-term" />
		</#if>
    <#local valueForSystemicEffectsAcuteInhalation = summary.GeneralPopulationHazardViaInhalationRoute.SystemicEffects.AcuteShortTermExposureStudy />	
		<#if valueForSystemicEffectsAcuteInhalation?has_content>
			<@com.emptyLine/><@toxInfoSystemicEffectsAcute summary "GeneralPopulationHazardViaInhalationRoute" "Inhalation Systemic effects - Acute" />
		</#if>
    <#local valueForLocalEffectsLongTermGeneralPopInhalation = summary.GeneralPopulationHazardViaInhalationRoute.LocalEffects.LongTermNoStudy />	
		<#if valueForLocalEffectsLongTermGeneralPopInhalation?has_content>
			<@com.emptyLine/><@toxInfoLocalEffectsLongTerm summary "GeneralPopulationHazardViaInhalationRoute" "Inhalation Local effects - Long-term" />
		</#if>
    <#local valueForLocalEffectsAcuteInhalation = summary.GeneralPopulationHazardViaInhalationRoute.LocalEffects.AcuteShortTermExposureStudy />	
		<#if valueForLocalEffectsAcuteInhalation?has_content>
			<@com.emptyLine/><@toxInfoLocalEffectsAcute summary "GeneralPopulationHazardViaInhalationRoute" "Inhalation Local effects - Acute" />
		</#if>
		
	<#local valueForSystemicEffectsLongTermGeneralPopDermal = summary.GeneralPopulationHazardViaDermalRoute.SystemicEffects.LongTermStudy />	
		<#if valueForSystemicEffectsLongTermGeneralPopDermal?has_content>	
			<@com.emptyLine/><@toxInfoSystemicEffectsLongTerm summary "GeneralPopulationHazardViaDermalRoute" "Dermal Systemic effects - Long-term" />
		</#if>
	<#local valueForSystemicEffectsAcuteDermal = summary.GeneralPopulationHazardViaDermalRoute.SystemicEffects.AcuteShortTermExposureStudy />	
		<#if valueForSystemicEffectsAcuteDermal?has_content>	
			<@com.emptyLine/><@toxInfoSystemicEffectsAcute summary "GeneralPopulationHazardViaDermalRoute" "Dermal Systemic effects - Acute" />
		</#if>
	<#local valueForLocalEffectsLongTermGeneralPopDermal = summary.GeneralPopulationHazardViaDermalRoute.LocalEffects.LongTermNoStudy />	
		<#if valueForLocalEffectsLongTermGeneralPopDermal?has_content>
			<@com.emptyLine/><@toxInfoLocalEffectsLongTerm summary "GeneralPopulationHazardViaDermalRoute" "Dermal Local effects - Long-term" />
		</#if>
	<#local valueForLocalEffectsAcuteDermal = summary.GeneralPopulationHazardViaDermalRoute.LocalEffects.AcuteShortTermExposureStudy />	
		<#if valueForLocalEffectsAcuteDermal?has_content>
			<@com.emptyLine/><@toxInfoLocalEffectsAcute summary "GeneralPopulationHazardViaDermalRoute" "Dermal Local effects - Acute" false />
		</#if>

	<#local valueForSystemicEffectsLongTermGeneralPopOral = summary.GeneralPopulationHazardViaOralRoute.SystemicEffects.LongTermStudy />	
		<#if valueForSystemicEffectsLongTermGeneralPopOral?has_content>	
			<@com.emptyLine/><@toxInfoSystemicEffectsLongTerm summary "GeneralPopulationHazardViaOralRoute" "Oral Systemic effects - Long-term" />
		</#if>
	<#local valueForSystemicEffectsAcuteOral = summary.GeneralPopulationHazardViaOralRoute.SystemicEffects.AcuteShortTermExposureStudy />	
		<#if valueForSystemicEffectsAcuteOral?has_content>
			<@com.emptyLine/><@toxInfoSystemicEffectsAcute summary "GeneralPopulationHazardViaOralRoute" "Oral Systemic effects - Acute" />
		</#if>
</#macro>

<#macro toxInfoSystemicEffectsLongTerm summary subPath title>
			
	<#assign basePath = "summary."+subPath+".SystemicEffects.LongTermStudy" />
	<#assign basePathDNEL = basePath+".DNMELInfoWithRTR" />
	<#local HazardAssesment = (basePath + ".HazardAssessment")?eval />
	<#local HazardConclusion = (basePath + ".ExplanationForHazardConclusion.JustificationAndComments")?eval />

	<#if HazardAssesment?has_content || HazardConclusion?has_content>
	
		<para><emphasis role="HEAD-WoutNo">${title}</emphasis></para>
		
		<#local derivationValue = (basePathDNEL + ".DerivationMethod")?eval />	
		<#local doseDescriptorValue = (basePathDNEL + ".DoseDescriptorStartingPoint")?eval />	
		<#local modifiedDoseDescriptorValue = (basePathDNEL + ".DoseDescriptorStartRTR")?eval />	
		<#local OverallAssessmentFactorValue = (basePathDNEL + ".AssessmentFactor")?eval />
		<#if derivationValue?has_content || doseDescriptorValue?has_content || modifiedDoseDescriptorValue?has_content || OverallAssessmentFactorValue?has_content>
	
			<#if derivationValue?has_content>
				<para role="indent">DNEL derivation method: <@com.value derivationValue /></para>
			</#if>
							
			<#if doseDescriptorValue?has_content>
				<para role="indent"><emphasis role="bold">Dose descriptor starting point:</emphasis> <@com.value doseDescriptorValue /></para>
			</#if>
		
			<#if modifiedDoseDescriptorValue?has_content>
				<para role="indent"><emphasis role="bold">Modified dose descriptor starting point:</emphasis> <@com.value modifiedDoseDescriptorValue/></para><para role="indent"><#if (basePathDNEL+".JustificationRTR")?eval?has_content><@com.richText (basePathDNEL+".JustificationRTR")?eval /></#if></para>
			</#if>
		
			<#if OverallAssessmentFactorValue?has_content>
				<para role="indent"><emphasis role="bold">Overall Assessment Factor:</emphasis> <@com.number OverallAssessmentFactorValue /></para>
			</#if>
				
			<@AFJustification af=(basePathDNEL+".DoseResponseAF")?eval justification=(basePathDNEL+".DoseResponseJustif")?eval label="AF for dose response relationship:"/>
			<@AFJustification af=(basePathDNEL+".DiffInDurationAF")?eval justification=(basePathDNEL+".DiffInDurationJustif")?eval label="AF for difference in duration of exposure:"/>
			<@AFJustification af=(basePathDNEL+".InterspeciesAF")?eval justification=(basePathDNEL+".InterspeciesJustif")?eval label="AF for interspecies differences (allometric scaling):"/>
			<@AFJustification af=(basePathDNEL+".OthInterspeciesAF")?eval justification=(basePathDNEL+".OthInterspeciesJustif")?eval label="AF for other interspecies differences:"/>
			<@AFJustification af=(basePathDNEL+".IntraspeciesAF")?eval justification=(basePathDNEL+".IntraspeciesJustif")?eval label="AF for intraspecies differences:"/>
			<@AFJustification af=(basePathDNEL+".DatabaseQualityAF")?eval justification=(basePathDNEL+".DatabaseJustif")?eval label="AF for the quality of the whole database:"/>
			<@AFJustification af=(basePathDNEL+".OthUncertaintiesAF")?eval justification=(basePathDNEL+".OthUncertaintiesJustif")?eval label="AF for remaining uncertainties:"/>
		
		</#if>
			
			<#local comments>
				<#if ("summary."+subPath+".SystemicEffects.LongTermStudy.ExplanationForHazardConclusion.JustificationAndComments")?eval?has_content>
				<@com.richText ("summary."+subPath+".SystemicEffects.LongTermStudy.ExplanationForHazardConclusion.JustificationAndComments")?eval />
				</#if>
			</#local>	
				
			<#if comments?has_content>
				<para role="indent"><emphasis role="underline">Further explanation on hazard conclusions:</emphasis></para>
				<para role="indent">${comments}</para>
			</#if>
	</#if>
</#macro>


<#macro toxInfoSystemicEffectsAcute summary subPath title>
			
	<#assign basePath = "summary."+subPath+".SystemicEffects.AcuteShortTermExposureStudy" />
	<#assign basePathDNEL = basePath+".DNELInfoWithRouteToRouteWithExtrapolation" />
	<#local HazardAssesment = (basePath + ".HazardAssessment")?eval />
	<#local HazardConclusion = (basePath + ".ExplanationForHazardConclusion.JustificationAndComments")?eval />

	<#if HazardAssesment?has_content || HazardConclusion?has_content>
			
			<para><emphasis role="HEAD-WoutNo">${title}</emphasis></para>
			
		<#local derivationValue = (basePathDNEL + ".DerivationMethod")?eval />	
		<#local doseDescriptorValue = (basePathDNEL + ".DoseDescriptorStartingPoint")?eval />	
		<#local modifiedDoseDescriptorValue = (basePathDNEL + ".DoseDescriptorStartRTR")?eval />	
		<#local OverallAssessmentFactorValue = (basePathDNEL + ".OverallAssessmentFactor")?eval />
		<#if derivationValue?has_content || doseDescriptorValue?has_content || modifiedDoseDescriptorValue?has_content || OverallAssessmentFactorValue?has_content>
		
			<#if derivationValue?has_content>
				<para role="indent">DNEL derivation method: <@com.value derivationValue /></para>
			</#if>
							
			<#if doseDescriptorValue?has_content>
				<para role="indent"><emphasis role="bold">Dose descriptor starting point:</emphasis> <@com.value doseDescriptorValue /></para>
			</#if>
		
			<#if modifiedDoseDescriptorValue?has_content>
				<para role="indent"><emphasis role="bold">Modified dose descriptor starting point:</emphasis> <@com.value modifiedDoseDescriptorValue/></para><para role="indent"><#if (basePathDNEL+".DoseDescriptorJustificationRTR")?eval?has_content><@com.richText (basePathDNEL+".DoseDescriptorJustificationRTR")?eval /></#if></para>
			</#if>
		
			<#if OverallAssessmentFactorValue?has_content>
				<para role="indent"><emphasis role="bold">Overall Assessment Factor:</emphasis> <@com.number OverallAssessmentFactorValue /></para>
			</#if>
				
			<@AFJustification af=(basePathDNEL+".DoseResponseAF")?eval justification=(basePathDNEL+".DoseResponseJustif")?eval label="AF for dose response relationship:"/>
			<@AFJustification af=(basePathDNEL+".InterspeciesAF")?eval justification=(basePathDNEL+".InterspeciesJustif")?eval label="AF for interspecies differences (allometric scaling):"/>
			<@AFJustification af=(basePathDNEL+".OthInterspeciesAF")?eval justification=(basePathDNEL+".OthInterspeciesJustif")?eval label="AF for other interspecies differences:"/>
			<@AFJustification af=(basePathDNEL+".IntraspeciesAF")?eval justification=(basePathDNEL+".IntraspeciesJustifAF")?eval label="AF for intraspecies differences:"/>
			<@AFJustification af=(basePathDNEL+".DatabaseQualityDatabaseQualityAF")?eval justification=(basePathDNEL+".DatabaseQualityJustif")?eval label="AF for the quality of the whole database:"/>
			<@AFJustification af=(basePathDNEL+".OthUncertaintiesAF")?eval justification=(basePathDNEL+".UncertaintiesJustif")?eval label="AF for remaining uncertainties:"/>
		</#if>
		<#local comments>
			<#if ("summary."+subPath+".SystemicEffects.AcuteShortTermExposureStudy.ExplanationForHazardConclusion.JustificationAndComments")?eval?has_content>
			<@com.richText ("summary."+subPath+".SystemicEffects.AcuteShortTermExposureStudy.ExplanationForHazardConclusion.JustificationAndComments")?eval />
			</#if>
		</#local>
			<#if comments?has_content>
			<para role="indent"><emphasis role="underline">Further explanation on hazard conclusions:</emphasis></para>
			<para role="indent">${comments}</para>
		</#if>
	</#if>
</#macro>

<#macro toxInfoLocalEffectsLongTerm summary subPath title>
			
	<#assign basePath = "summary."+subPath+".LocalEffects.LongTermNoStudy" />
	<#assign basePathDNEL = basePath+".DNMELInfoWithoutRTR" />
	<#local HazardAssesment = (basePath + ".HazardAssessment")?eval />
	<#local HazardConclusion = (basePath + ".ExplanationForHazardConclusion.JustificationAndComments")?eval />

	<#if HazardAssesment?has_content || HazardConclusion?has_content>
	
		<para><emphasis role="HEAD-WoutNo">${title}</emphasis></para>
	
		<#local derivationValue = (basePathDNEL + ".DerivationMethod")?eval />	
		<#local doseDescriptorValue = (basePathDNEL + ".DoseDescriptorStart")?eval />	
		<#local OverallAssessmentFactorValue = (basePathDNEL + ".AssessmentFactor")?eval />
		<#if derivationValue?has_content || doseDescriptorValue?has_content || OverallAssessmentFactorValue?has_content>
						
			<#if derivationValue?has_content>
				<para role="indent">DNEL derivation method: <@com.value derivationValue /></para>
			</#if>
							
			<#if doseDescriptorValue?has_content>
				<para role="indent"><emphasis role="bold">Dose descriptor starting point:</emphasis> <@com.value doseDescriptorValue /></para>
			</#if>
	
			<#if OverallAssessmentFactorValue?has_content>
				<para role="indent"><emphasis role="bold">Overall Assessment Factor:</emphasis> <@com.number OverallAssessmentFactorValue /></para>
			</#if>
				
			<@AFJustification af=(basePathDNEL+".DoseResponseAF")?eval justification=(basePathDNEL+".DoseResponseJustif")?eval label="AF for dose response relationship:"/>
			<@AFJustification af=(basePathDNEL+".DiffInDurationAF")?eval justification=(basePathDNEL+".DiffInDurationJustif")?eval label="AF for difference in duration of exposure:"/>
			<@AFJustification af=(basePathDNEL+".InterspeciesAF")?eval justification=(basePathDNEL+".InterspeciesJustif")?eval label="AF for interspecies differences (allometric scaling):"/>
			<@AFJustification af=(basePathDNEL+".OthInterspeciesAF")?eval justification=(basePathDNEL+".OthInterspeciesJustif")?eval label="AF for other interspecies differences:"/>
			<@AFJustification af=(basePathDNEL+".IntraspeciesAF")?eval justification=(basePathDNEL+".IntraspeciesJustif")?eval label="AF for intraspecies differences:"/>
			<@AFJustification af=(basePathDNEL+".DatabaseQualityAF")?eval justification=(basePathDNEL+".DatabaseJustif")?eval label="AF for the quality of the whole database:"/>
			<@AFJustification af=(basePathDNEL+".OthUncertaintiesAF")?eval justification=(basePathDNEL+".OthUncertaintiesJustif")?eval label="AF for remaining uncertainties:"/>
		</#if>
		<#local comments>
			<#if ("summary."+subPath+".LocalEffects.LongTermNoStudy.ExplanationForHazardConclusion.JustificationAndComments")?eval?has_content>
			<@com.richText ("summary."+subPath+".LocalEffects.LongTermNoStudy.ExplanationForHazardConclusion.JustificationAndComments")?eval />
			</#if>
		</#local>
		<#if comments?has_content>
			<para role="indent"><emphasis role="underline">Further explanation on hazard conclusions:</emphasis></para>
			<para role="indent">${comments}</para>
		</#if>
	</#if>
</#macro>

<#macro toxInfoLocalEffectsAcute summary subPath title withExtrapolation = true>
	
	<#assign basePath = "summary."+subPath+".LocalEffects.AcuteShortTermExposureStudy" />
	<#local HazardAssesment = (basePath + ".HazardAssessment")?eval />
	<#local HazardConclusion = (basePath + ".ExplanationForHazardConclusion.JustificationAndComments")?eval />
	
	<#if withExtrapolation>
        <#assign basePathDNEL = basePath+".DNELInfoWithoutRouteToRouteWithExtrapolation" >
    <#else>
        <#assign basePathDNEL = basePath+".DNELInfoWithoutRouteToRouteWithoutExtrapolation" >
    </#if>
	
	<#if HazardAssesment?has_content || HazardConclusion?has_content>
	
	<para><emphasis role="HEAD-WoutNo">${title}</emphasis></para>
	
		<#local derivationValue = (basePathDNEL + ".DerivationMethod")?eval />	
		<#local doseDescriptorValue = (basePathDNEL + ".DoseDescriptorStart")?eval />	
		<#local OverallAssessmentFactorValue = (basePathDNEL + ".OverallAssessmentFactor")?eval />
		<#if derivationValue?has_content || doseDescriptorValue?has_content || OverallAssessmentFactorValue?has_content>
					
			<#if derivationValue?has_content>
				<para role="indent">DNEL derivation method: <@com.value derivationValue /></para>
			</#if>
							
			<#if doseDescriptorValue?has_content>
				<para role="indent"><emphasis role="bold">Dose descriptor starting point:</emphasis> <@com.value doseDescriptorValue /></para>
			</#if>
	
			<#if OverallAssessmentFactorValue?has_content>
				<para role="indent"><emphasis role="bold">Overall Assessment Factor:</emphasis> <@com.number OverallAssessmentFactorValue /></para>
			</#if>
				
			<@AFJustification af=(basePathDNEL+".DoseResponseAF")?eval justification=(basePathDNEL+".DoseResponseJustif")?eval label="AF for dose response relationship:"/>
			<@AFJustification af=(basePathDNEL+".InterspeciesAF")?eval justification=(basePathDNEL+".InterspeciesJustif")?eval label="AF for interspecies differences (allometric scaling):"/>
			<@AFJustification af=(basePathDNEL+".OthInterspeciesAF")?eval justification=(basePathDNEL+".OthInterspeciesJustif")?eval label="AF for other interspecies differences:"/>
			<@AFJustification af=(basePathDNEL+".IntraspeciesAF")?eval justification=(basePathDNEL+".IntraspeciesJustifAF")?eval label="AF for intraspecies differences:"/>
			<@AFJustification af=(basePathDNEL+".DatabaseQualityDatabaseQualityAF")?eval justification=(basePathDNEL+".DatabaseQualityJustif")?eval label="AF for the quality of the whole database:"/>
			<@AFJustification af=(basePathDNEL+".OthUncertaintiesAF")?eval justification=(basePathDNEL+".UncertaintiesJustif")?eval label="AF for remaining uncertainties:"/>
		</#if>
		<#local comments>
			<#if ("summary."+subPath+".LocalEffects.AcuteShortTermExposureStudy.ExplanationForHazardConclusion.JustificationAndComments")?eval?has_content>
			<@com.richText ("summary."+subPath+".LocalEffects.AcuteShortTermExposureStudy.ExplanationForHazardConclusion.JustificationAndComments")?eval />
			</#if>
		</#local>
		<#if comments?has_content>
			<para role="indent"><emphasis role="underline">Further explanation on hazard conclusions:</emphasis></para>
			<para role="indent">${comments}</para>
		</#if>
	</#if>
</#macro>

<#macro endpointConclusionOfDoseDescriptor summary path>
	<#assign endpointConclusion>
		<@com.picklist ("summary.KeyValueForChemicalSafetyAssessment."+path+"")?eval/>
	</#assign>
</#macro>

<#macro doseOfDoseDescriptor summary path>
	<#local unit>
		<@com.picklist ("summary.KeyValueForChemicalSafetyAssessment."+path+".EffectLevelUnit")?eval/>
	</#local>
	<#local value>
		<@com.range ("summary.KeyValueForChemicalSafetyAssessment."+path+".EffectLevelValue")?eval/>
	</#local>

	<#if unit?has_content || value?has_content>
		<#assign doseDescriptor>
			(${unit}): ${value}		
		</#assign>
	<#else>
		<#assign doseDescriptor></#assign>
	</#if>
</#macro>

<#macro studyDurationOfDoseDescriptor summary path>
	<#local species>
		<@com.picklist ("summary.KeyValueForChemicalSafetyAssessment."+path+".Species")?eval/>
	</#local>
	<#if species?has_content>
		<#assign studyDuration>
        (${species})
		</#assign>
	<#else>
		<#assign studyDuration></#assign>
	</#if>
</#macro>

<#macro targetSystemOrganOfDoseDescriptor summary path>
	<#local system>
		<@com.picklistMultiple ("summary.KeyValueForChemicalSafetyAssessment."+path+".System")?eval/>
	</#local>
	<#local organ>
		<@com.picklistMultiple ("summary.KeyValueForChemicalSafetyAssessment."+path+".Organ")?eval/>
	</#local>

	<#if system?has_content || organ?has_content>
		<#assign targetSystemOrgan>
        Target system/organs: ${system} ${organ}
		</#assign>
	<#elseif targetSystemOrgan?has_content>
		<#assign targetSystemOrgan></#assign>
	</#if>

</#macro>
<#macro hazardAssessmentMacro hazardPicklist dosePicklist>
	<#compress>
		<#assign hazardAssessment>
			<@com.value hazardPicklist/>
		</#assign>
		<para>
			${hazardAssessment}
		</para>

		<#if hazardAssessment?matches(".*DNEL.*") || hazardAssessment?matches(".*DMEL.*") || hazardAssessment?matches(".*other toxicological threshold.*")>
		<para>
			<@com.quantity dosePicklist/>
		</para>
		</#if>
	</#compress>
</#macro>