<!-- ENVIRONMENTAL HAZARD ASSESSMENT template file   -->

<!----------------------------------------------------------------------------------
------------------------------------------------------------------------------------
summary table that captures all related Ecotoxicological endpoint summaries
-----------------------------------------------------------------------------------
----------------------------------------------------------------------------------->

<!---------------------------------------------------------------------
-----------------------------------------------------------------------
_subject is root entity
docType is a hardcoded document type string
docSubType is a hardcoded document sub type string
titleText is a hardcoded text that for some summaries is required
discussionText is a hardcoded text that offers an additional sub-title
-----------------------------------------------------------------------
---------------------------------------------------------------------->

<#macro endpointSummary _subject docType docSubType>
<#compress>

	<#assign summaryList = iuclid.getSectionDocumentsForParentKey(_subject.documentKey, "${docType}", "${docSubType}") />	

	<#assign tocNodeTitle = com.tableOfContentsNodeTitle("${docType}", "${docSubType}")/>

	<#if summaryList?has_content>
	
    <!-- Only print name of doc if more than one Endpoint Summary -->
	<#assign printSummaryName = summaryList?size gt 1 />

		<#list summaryList as summary>

		<!-- Check if continue to iterate Summary document if KeyInformation is entered -->
		<#assign summaryValue = checkSummaryInfo(summary)/>

			<#if summaryValue?has_content>

				<!-- Add hardcoded Discussion text from user defined macro *discussionText -->
                <#assign discussionText>
				<#if summary?has_content && tocNodeTitle?has_content>
				<@CSAValueTextNew summary "${tocNodeTitle}" "${docSubType}" />
				</#if>
                </#assign>

				<#if summary?has_content>
                    <!-- basic endpoint summary info including assessment entity information -->
					<@studyandsummaryCom.endpointSummary summary "${discussionText}" "${docSubType}" printSummaryName/>
                    <!-- endpointSummaries with no csa values to tabularise -->
                    <#if docSubType!="AquaticToxicity">
                        <!-- endpointSummary tables with key values as well as linked studies -->
                        <@studyandsummaryCom.ecotoxSummary _subject "${docSubType}"/>
                    </#if>
                    <!-- endpoint summary discussion -->
                    <#if summary.hasElement("Discussion")>
                        <@studyandsummaryCom.summaryAdditionalInformation summary/>
                    </#if>		
				</#if>

			</#if>

		</#list>
    </#if>

</#compress>
</#macro>

<!----------------------------------------------------------------------------------
------------------------------------------------------------------------------------
study table that captures all related Ecotoxicological endpoint study records
-----------------------------------------------------------------------------------
----------------------------------------------------------------------------------->

<!-----------------------------------------------------------------------------
-------------------------------------------------------------------------------
_subject is root entity
docType is a hardcoded document type string
docSubType is a hardcoded document sub type string
columnHeaders is a list of strings that represent column headers
numberOfColumns is a calculation of the size.number of headers in columnHeaders
-------------------------------------------------------------------------------
------------------------------------------------------------------------------->

<#macro studyTable _subject docType docSubType columnHeaders numberOfColumns columnWidths>
<#compress>

	<!-- docType and docSubType dynamically fetched when getting section documents for root entity -->
	<#assign studyList = iuclid.getSectionDocumentsForParentKey(_subject.documentKey, "${docType}", "${docSubType}") />

	<!-- get the table of contents node name for the relevant document -->
	<#assign tocNodeTitle = com.tableOfContentsNodeTitle("${docType}", "${docSubType}")/>

	<#-- Populate resultStudyList, dataWaivingStudyList, testingProposalStudyList -->
	<@populateResultAndDataWaivingAndTestingProposalStudyLists studyList />

	<#-- Study results -->
	<#if resultStudyList?has_content>
		The studies on ${tocNodeTitle} are summarized in the following table:

		<@com.emptyLine/>
		<table border="1">
		<title>Studies on ${tocNodeTitle}</title>
			<#list columnWidths as width>
			<#assign columnIndexWidth = width?index>
				<col width="${columnWidths[columnIndexWidth]}">${width}</col>
			</#list>
			<tbody>
			<tr>
				<#list columnHeaders as header>
					<#assign columnIndexHeader = header?index>
					<?dbfo bgcolor="#FBDDA6" ?><th width="${columnWidths[columnIndexHeader]}"><emphasis role="bold">${header}</emphasis></th>
				</#list>
			</tr>
			<#list resultStudyList as study>
           		 <tr>
					<#list 0..numberOfColumns-1 as columnNum>
						<td>
						<#if columnNum == 0><!-- CSR Column 1 *Method -->

							<#-- QSAR related information in materials and methods -->
							<@studyandsummaryCom.qsarModel study/>

							<#-- CSR ShortTermToxicityToFish | LongTermToxToFish | ShortTermToxicityToAquaInv | LongTermToxicityToAquaInv | SedimentToxicity | EndocrineDisrupterTestingInAqua | ToxicityToOtherAqua | ToxicityToSoilArthropods | ToxicityToTerrestrialArthropodsOtherThanBees | ToxicityToBees | ToxicityToMicroorganisms | ToxicityToBirds | ToxicityToOtherAboveGroundOrganisms -->
							<#if study.hasElement("MaterialsAndMethods.TestOrganisms.TestOrganismsSpecies")>
								<para>
									<@com.picklist study.MaterialsAndMethods.TestOrganisms.TestOrganismsSpecies/>
								</para>
							</#if>

							<#-- ToxicityToTerrestrialPlants -->
							<#if docSubType=="ToxicityToTerrestrialPlants" && study.hasElement("MaterialsAndMethods.TestOrganisms")>
							<#list study.MaterialsAndMethods.TestOrganisms.TestOrganisms as testOrganisms>
								<para><#if testOrganisms.Species?has_content><@com.picklist testOrganisms.Species/></#if> <#if testOrganisms.PlantGroup?has_content>(<@com.picklist testOrganisms.PlantGroup/>)</#if></para>								
							</#list>
							</#if>

							<!-- CSR ToxicityToSoilMicroorganisms-->
							<#if study.hasElement("MaterialsAndMethods.TestOrganisms.TestOrganismsInoculum")>
							<para>
								Species/Inoculum: <@com.picklist study.MaterialsAndMethods.TestOrganisms.TestOrganismsInoculum/>
							</para>	
							</#if>

							<!-- CSR ToxicityToSoilArthropods | ToxicityToTerrestrialArthropodsOtherThanBees | ToxicityToBees -->
							<#if docSubType=="ToxicityToSoilArthropods" || docSubType=="ToxicityToTerrestrialArthropodsOtherThanBees" || docSubType=="ToxicityToBees" && study.hasElement("MaterialsAndMethods.TestOrganisms.AnimalGroup") && study.MaterialsAndMethods.TestOrganisms.AnimalGroup?has_content>
								(<@com.picklist study.MaterialsAndMethods.TestOrganisms.AnimalGroup/>)
							</#if>

							<!-- CSR ToxicityToTerrestrialArthropodsOtherThanBees | ToxicityToBees -->
							<#if docSubType=="ToxicityToTerrestrialArthropodsOtherThanBees" || docSubType=="ToxicityToBees" && study.hasElement("MaterialsAndMethods.TestSubstrate.ApplicationMethod") && study.MaterialsAndMethods.TestSubstrate.ApplicationMethod?has_content>
							<para>
								Application method: <@com.picklist study.MaterialsAndMethods.TestSubstrate.ApplicationMethod/>
							</para>
							</#if>
							
							<!-- CSR ShortTermToxicityToFish | LongTermToxToFish | ShortTermToxicityToAquaInv | LongTermToxicityToAquaInv | SedimentToxicity | EndocrineDisrupterTestingInAqua | ToxicityToOtherAqua | ToxicityToMicroorganisms -->
							<#if study.hasElement("MaterialsAndMethods.StudyDesign.WaterMediaType")>
								<para>
									<@com.picklist study.MaterialsAndMethods.StudyDesign.WaterMediaType/>
								</para>
							</#if>

							<!-- CSR ShortTermToxicityToFish | LongTermToxToFish | ShortTermToxicityToAquaInv | LongTermToxicityToAquaInv | SedimentToxicity | ToxicityToSoilArthropods | ToxicityToTerrestrialPlants | ToxicityToTerrestrialArthropodsOtherThanBees | ToxicityToBees | ToxicityToBirds -->
							<#if study.hasElement("AdministrativeData.Endpoint") && docSubType!="EndocrineDisrupterTestingInAqua" && docSubType!="ToxicityToOtherAqua">
								<para>
									<@com.picklist study.AdministrativeData.Endpoint/>
								</para>
							</#if>

							<!-- CSR ToxicityToBirds -->
							<#if study.hasElement("MaterialsAndMethods.TestMaterials.DoseMethod") && study.MaterialsAndMethods.TestMaterials.DoseMethod?has_content>
								(<@com.picklist study.MaterialsAndMethods.TestMaterials.DoseMethod/>)
							</#if>

							<!-- CSR ToxicityToBirds -->							
							<#if study.hasElement("MaterialsAndMethods.StudyDesign.NominalAndMeasuredDosesConcentrations") && study.MaterialsAndMethods.StudyDesign.NominalAndMeasuredDosesConcentrations?has_content>
								<para>Doses: <@com.text study.MaterialsAndMethods.StudyDesign.NominalAndMeasuredDosesConcentrations/></para>
							</#if>
							
							<!-- CSR SedimentToxicity | ToxicityToSoilArthropods | ToxicityToTerrestrialPlants | ToxicityToTerrestrialArthropodsOtherThanBees | ToxicityToOtherAboveGroundOrganisms -->
							<#if docSubType=="SedimentToxicity" || docSubType=="ToxicityToTerrestrialPlants" || docSubType=="ToxicityToSoilArthropods" || docSubType=="ToxicityToTerrestrialArthropodsOtherThanBees" ||  docSubType=="ToxicityToOtherAboveGroundOrganisms" && study.hasElement("MaterialsAndMethods.StudyDesign.StudyType") && study.MaterialsAndMethods.StudyDesign.StudyType?has_content>
								(<@com.picklist study.MaterialsAndMethods.StudyDesign.StudyType/>)
							</#if>

							<!-- ToxicityToSoilArthropods -->
							<#if docSubType=="ToxicityToSoilArthropods" && study.hasElement("MaterialsAndMethods.TestSubstrate") && study.MaterialsAndMethods.TestSubstrate?has_content>		
							Substrate:
							<para>
								<#list study.MaterialsAndMethods.TestSubstrate?children as child>
								<@com.value child/>
								<#if child_has_next><para></para></#if>
								</#list>
							</para>
							</#if>

							<!-- ToxicityToTerrestrialPlants -->
							<#if docSubType=="ToxicityToTerrestrialPlants" && study.hasElement("MaterialsAndMethods.StudyDesign.SubstrateType") && study.MaterialsAndMethods.StudyDesign.SubstrateType?has_content>		
							<para>
								Substrate: <@com.picklist study.MaterialsAndMethods.StudyDesign.SubstrateType/>
							</para>	
							</#if>					
							
							<!-- CSR ShortTermToxicityToFish | LongTermToxToFish | ShortTermToxicityToAquaInv | LongTermToxicityToAquaInv | SedimentToxicity | EndocrineDisrupterTestingInAqua | ToxicityToOtherAqua | ToxicityToSoilArthropods | ToxicityToSoilMicroorganisms | ToxicityToTerrestrialArthropodsOtherThanBees | ToxicityToBees | ToxicityToMicroorganisms | ToxicityToBirds | ToxicityToOtherAboveGroundOrganisms -->
							<#if study.hasElement("MaterialsAndMethods.Guideline")>
								<para>
									<@studyandsummaryCom.guidelineList study.MaterialsAndMethods.Guideline/>
								</para>							
							</#if>

							<!-- CSR ShortTermToxicityToFish | LongTermToxToFish | ShortTermToxicityToAquaInv | LongTermToxicityToAquaInv | SedimentToxicity | EndocrineDisrupterTestingInAqua | ToxicityToOtherAqua | ToxicityToSoilArthropods | ToxicityToSoilMicroorganisms | ToxicityToTerrestrialArthropodsOtherThanBees | ToxicityToBees | ToxicityToMicroorganisms | ToxicityToBirds | ToxicityToOtherAboveGroundOrganisms -->
							<#if study.hasElement("MaterialsAndMethods.MethodNoGuideline")>
								<para>
									<@com.text study.MaterialsAndMethods.MethodNoGuideline/>
								</para>
							</#if>
							
							<!-- ShortTermToxicityToAquaInv | SedimentToxicity | EndocrineDisrupterTestingInAqua | ToxicityToOtherAqua | ToxicityToTerrestrialPlants | ToxicityToMicroorganisms -->
							<!-- Note that this is repeated in Env. fate -->
							<#if study.hasElement("MaterialsAndMethods.StudyDesign.TestType")>
							<para>
								<@com.picklist study.MaterialsAndMethods.StudyDesign.TestType/>
							</para>
							</#if>

							<!-- SedimentToxicity -->
							<#if docSubType=="SedimentToxicity" && study.hasElement("MaterialsAndMethods.StudyDesign.TypeOfSediment")>
							<para>
								Sediment: <@com.picklist study.MaterialsAndMethods.StudyDesign.TypeOfSediment/>
							</para>
							</#if>		

                        <#elseif columnNum == 1><!-- CSR Column 1 *Results -->

							<#-- QSAR based results -->
							<@studyandsummaryCom.qsarResultsAndDiscussion study />

							<!-- ShortTermToxicityToFish -->
							<#if docSubType=="ShortTermToxicityToFish">
							<#assign sortedEffectList = iuclid.sortByField(study.ResultsAndDiscussion.EffectConcentrations, "Endpoint", ["LC50","LC0","LC100"]) />
							<@effectList studyandsummaryCom.orderByKeyResult(sortedEffectList) study/>
							</#if>

							<#if docSubType=="LongTermToxToFish" || docSubType=="LongTermToxicityToAquaInv" || docSubType=="ToxicityToMicroorganisms">
							<!-- LongTermToxToFish | LongTermToxicityToAquaInv | ToxicityToMicroorganisms -->
							<#assign sortedEffectList = iuclid.sortByField(study.ResultsAndDiscussion.EffectConcentrations, "Endpoint", ["NOEC","LOEC","EC10","LC10","IC10"]) />
							<@effectList studyandsummaryCom.orderByKeyResult(sortedEffectList) study/>
							</#if>

							<#if docSubType=="ShortTermToxicityToAquaInv">
							<!-- ShortTermToxicityToAquaInv -->
							<#assign sortedEffectList = iuclid.sortByField(study.ResultsAndDiscussion.EffectConcentrations, "Endpoint", ["EC50","IC50","LC50","EC0","IC0","LC0","EC100","LC100"]) />
							<@effectList studyandsummaryCom.orderByKeyResult(sortedEffectList) study/>
							</#if>

							<#if docSubType=="SedimentToxicity">
							<!-- SedimentToxicity -->
							<#assign sortedEffectList = iuclid.sortByField(study.ResultsAndDiscussion.EffectConcentrations, "Endpoint", ["NOEC","LOEC","EC10","LOEC","EC10","LC10","LD10","EC50","LC50","LD50","EC0","LC0","LD0"]) />
							<@effectList studyandsummaryCom.orderByKeyResult(sortedEffectList) study/>
							</#if>

							<#if docSubType=="EndocrineDisrupterTestingInAqua" || docSubType=="ToxicityToOtherAqua">
							<!-- EndocrineDisrupterTestingInAqua | ToxicityToOtherAqua -->
							<#assign sortedEffectList = iuclid.sortByField(study.ResultsAndDiscussion.EffectConcentrations, "Endpoint", ["NOEC","LOEC","EC10","IC10","LC10","EC50","IC50","LC50","EC0","IC0","LC0"]) />
							<@effectList studyandsummaryCom.orderByKeyResult(sortedEffectList) study/>
							</#if>

							<#if docSubType=="ToxicityToSoilArthropods" || docSubType=="ToxicityToTerrestrialArthropodsOtherThanBees" || docSubType=="ToxicityToBees" || docSubType=="ToxicityToTerrestrialArthropods" || docSubType=="ToxicityToSoilMacroorganismsExceptArthropods">
							<!-- ToxicityToSoilArthropods | ToxicityToTerrestrialArthropodsOtherThanBees | ToxicityToBees -->
							<#assign sortedEffectList = iuclid.sortByField(study.ResultsAndDiscussion.EffectConcentrations, "Endpoint", ["NOEC","LOEC","EC10","LC10","LD10","EC50","LC50","LD50"]) />
							<@effectList studyandsummaryCom.orderByKeyResult(sortedEffectList) study/>
							</#if>

							<#if docSubType=="ToxicityToTerrestrialPlants">
							<!-- ToxicityToTerrestrialPlants -->
							<@effectIncludingSpeciesList studyandsummaryCom.orderByKeyResult(study.ResultsAndDiscussion.EffectConcentrations)/>
							</#if>
							
							<#if docSubType=="ToxicityToSoilMicroorganisms">
							<!-- ToxicityToSoilMicroorganisms -->
							<#assign sortedEffectList = iuclid.sortByField(study.ResultsAndDiscussion.EffectConcentrations, "Endpoint", ["NOEC","EC10","EC25","EC50","EC100"]) />
							<@effectList studyandsummaryCom.orderByKeyResult(sortedEffectList) study/>
							</#if>

							<#if docSubType=="ToxicityToAquaticAlgae" || docSubType=="ToxicityToAquaticPlant">
							<#assign sortedEffectList = iuclid.sortByField(study.ResultsAndDiscussion.EffectConcentrations, "Endpoint", ["EC50","IC50","NOEC","LOEC","EC10","IC10","EC20","IC20","EC0","IC0","EC100","IC100"]) />
							<@effectList studyandsummaryCom.orderByKeyResult(sortedEffectList) study/>
							</#if>

                        <#elseif columnNum == 2><!-- CSR Column 1 *Remarks -->
                        	<@studyandsummaryCom.studyRemarksColumn study/>
                        </#if>
						</td>
					</#list>
				</tr>				
				<@studyandsummaryCom.tableRowForJustificationForTypeOfInformation study/>
			</#list>
			</tbody>
		</table>

		<#elseif !(dataWaivingStudyList?has_content || testingProposalStudyList?has_content)>
			No relevant information available.
		</#if>

		<#if dataWaivingStudyList?has_content || testingProposalStudyList?has_content>
	
			<#if csrRelevant??>
				<!-- Data waiving -->
				<#if dataWaivingStudyList?has_content>
				<para><@com.emptyLine/><emphasis role="HEAD-WoutNo">Data waiving</emphasis></para>
				<@studyandsummaryCom.dataWaiving dataWaivingStudyList "${tocNodeTitle}" false/>
				</#if>

				<!-- Testing proposal -->
				<#if testingProposalStudyList?has_content>
				<para><@com.emptyLine/><emphasis role="HEAD-WoutNo">Testing proposal</emphasis></para>
				<@studyandsummaryCom.testingProposal testingProposalStudyList "${tocNodeTitle}" false/>
				</#if>
			</#if>
		
		</#if>


</#compress>
</#macro>

<!-- macros and functions -->
		
<#macro effectList effectConcRepeatableBlock study>
<#compress>
	<#if effectConcRepeatableBlock?has_content>
		<#list effectConcRepeatableBlock as blockItem>
			<#if blockItem.Endpoint?has_content || blockItem.Duration?has_content 
			|| blockItem.EffectConc?has_content || blockItem.ConcBasedOn?has_content
			|| blockItem.NominalMeasured?has_content || blockItem.BasisForEffect?has_content
			|| blockItem.RemarksOnResults?has_content>
			<para>
				<#if blockItem.Endpoint?has_content> 
					<@com.picklist blockItem.Endpoint/>
				</#if>

				<#if blockItem.hasElement("LifeStage") && blockItem.LifeStage?has_content> <#-- for ToxicityToBees -->
					(<@com.value blockItem.LifeStage/>)
				</#if>
				
				<#if blockItem.Duration?has_content> 
					(<@com.quantity blockItem.Duration/>):
				</#if>
				
				<#if blockItem.EffectConc?has_content> 
					<@com.range blockItem.EffectConc/> 
				</#if>
				
				<#if blockItem.ConcBasedOn?has_content> 
					<@com.picklist blockItem.ConcBasedOn/>
				</#if>
				
				<#if blockItem.NominalMeasured?has_content>
					(<@com.picklist blockItem.NominalMeasured/>)
				</#if>

				<#if blockItem.hasElement("BasisForEffect") && blockItem.BasisForEffect?has_content> <#-- more general case -->
					based on: <@com.value blockItem.BasisForEffect/>
				<#elseif blockItem.hasElement("BasisForEffectMulti") && blockItem.BasisForEffectMulti?has_content> <#-- case of ENDPOINT_STUDY_RECORD.ToxicityToAquaticPlant -->
					based on: <@com.value blockItem.BasisForEffectMulti/>
				</#if>

				<#if blockItem.RemarksOnResults?has_content>
					(<@com.picklist blockItem.RemarksOnResults/>)
				</#if>

				<#-- note: two more fields exist in some OHTs
					- 95%CI (range): ConfInterval
					- slope of the curve (text, 2000): SlopeOfTheCurve
				-->
        </para>
      </#if>
</#list>
</#if>
    
</#compress>
</#macro>

<#macro effectIncludingSpeciesList effectConcIncludingSpeciesRepeatableBlock>
<#compress>
	<#if effectConcIncludingSpeciesRepeatableBlock?has_content>
		<#list effectConcIncludingSpeciesRepeatableBlock as blockItem>
			<#if blockItem.Species?has_content || blockItem.Endpoint?has_content 
			|| blockItem.Duration?has_content || blockItem.EffectConc?has_content
			|| blockItem.ConcBasedOn?has_content || blockItem.NominalMeasured?has_content
			|| blockItem.BasisForEffect?has_content || blockItem.RemarksOnResults?has_content>
				<para>
					<#if blockItem.Species?has_content>
						<@com.picklist blockItem.Species/>
					</#if>
					
					<#if blockItem.Endpoint?has_content>
						<@com.picklist blockItem.Endpoint/>
					</#if>
					
					<#if blockItem.Duration?has_content>
						(<@com.quantity blockItem.Duration/>):
					</#if>
					
					<#if blockItem.EffectConc?has_content>
						<@com.range blockItem.EffectConc/> 
					</#if>
					
					<#if blockItem.ConcBasedOn?has_content>
						<@com.picklist blockItem.ConcBasedOn/>
					</#if>
					
					<#if blockItem.NominalMeasured?has_content>
						(<@com.picklist blockItem.NominalMeasured/>)
					</#if>
										
					<#if blockItem.BasisForEffect?has_content>
						based on: <@com.picklist blockItem.BasisForEffect/>
					</#if>
					
					<#if blockItem.RemarksOnResults?has_content>
						(<@com.picklist blockItem.RemarksOnResults/>)
					</#if>
				</para>
			</#if>
		</#list>
  	</#if>
</#compress>
</#macro>

<#macro effectBirdsList effectConcBirdsRepeatableBlock>
<#compress>
	<#if effectConcBirdsRepeatableBlock?has_content>
		<#list effectConcBirdsRepeatableBlock as blockItem>
			<#if blockItem.Endpoint?has_content || blockItem.Duration?has_content 
			|| blockItem.EffectLevel?has_content || blockItem.ConcDoseBasedOn?has_content
			|| blockItem.BasisForEffect?has_content || blockItem.RemarksOnResults?has_content>
				<para>
					<#if blockItem.Endpoint?has_content>
						<@com.picklist blockItem.Endpoint/> 
					</#if>
					
					<#if blockItem.Duration?has_content>
						(<@com.quantity blockItem.Duration/>):
					</#if>
					
					<#if blockItem.EffectLevel?has_content>
						<@com.range blockItem.EffectLevel/>
						<#if blockItem.ConfInterval?has_content && pppRelevant??>
							[95% CI: <@com.range blockItem.ConfInterval/>]
						</#if>
					</#if>
					
					<#if blockItem.ConcDoseBasedOn?has_content>
						<@com.picklist blockItem.ConcDoseBasedOn/>
					</#if>
										
					<#if blockItem.BasisForEffect?has_content>
						based on: <@com.picklist blockItem.BasisForEffect/>
					</#if>
					
					<#if blockItem.RemarksOnResults?has_content>
						(<@com.picklist blockItem.RemarksOnResults/>)
					</#if>
				</para>
			</#if>
		</#list>
  	</#if>
</#compress>
</#macro>

<#macro TestOrgsForTerrestrialPlants TestOrgsRepeatableBlock>
<#compress>
	<#if TestOrgsRepeatableBlock?has_content>
		<#list TestOrgsRepeatableBlock as blockItem>
			<#if blockItem.Species?has_content || blockItem.PlantGroup?has_content>
				<para role="indent">
					<#if blockItem.Species?has_content>
						<@com.picklist blockItem.Species/>
					</#if>
					
					<#if blockItem.PlantGroup?has_content>
						(<@com.picklist blockItem.PlantGroup/>)	
					</#if>
				</para>
			</#if>
		</#list>
  	</#if>
</#compress>
</#macro>

<#macro hazardConclusion hazardConclusionBlock>
<#compress>
	<#if hazardConclusionBlock.HazAssessConcl?has_content || hazardConclusionBlock.HazAssessConclVal?has_content>
		<para>
			<#if hazardConclusionBlock.HazAssessConcl?has_content>
				<@com.picklist hazardConclusionBlock.HazAssessConcl/>: 
			</#if>
			
			<#if hazardConclusionBlock.HazAssessConclVal?has_content>
				<@com.quantity hazardConclusionBlock.HazAssessConclVal/>
			</#if>
		</para>
	</#if>
</#compress>
</#macro>

<#macro hazardRemarks hazardConclusionBlock>
<#compress>
	<#if hazardConclusionBlock.hasElement("AssessmentFactor")>		
		<#if com.picklistValueMatchesPhrases(hazardConclusionBlock.HazAssessConcl, [".*PNEC.*"])>
			<para>
				<#if hazardConclusionBlock.AssessmentFactor?has_content>
				Assessment factor: <@com.number hazardConclusionBlock.AssessmentFactor/>
				</#if>
			</para>
		</#if>
	</#if>
	<#if hazardConclusionBlock.hasElement("ExtrapolationMethod")>
		<#if com.picklistValueMatchesPhrases(hazardConclusionBlock.HazAssessConcl, [".*PNEC.*"])>
			<para>
				Extrapolation method: <@com.picklist hazardConclusionBlock.ExtrapolationMethod/>
			</para>
		</#if>
	</#if>
	<#if hazardConclusionBlock.hasElement("ExtrapolationMethod")>
		<#if com.picklistValueMatchesPhrases(hazardConclusionBlock.HazAssessConcl, [".*PNEC.*"])>
			<para>
				<@com.picklist hazardConclusionBlock.HazAssessConcl/>
			</para>
		</#if>
	</#if>
	
	
	<para>
		<@com.richText hazardConclusionBlock.Justification/>
	</para>
</#compress>
</#macro>

<#function isSoilMacroOrganismsInvolved study>
	<#if !(study?has_content)>
		<#return false>
	</#if>
	<#local AnimalGroup = study.MaterialsAndMethods.TestOrganisms.AnimalGroup />
	<#local TestOrganismsSpecies = study.MaterialsAndMethods.TestOrganisms.TestOrganismsSpecies />
	<#local ApplicationMethod = study.MaterialsAndMethods.ApplicationMethod />
	
	<#if com.picklistValueMatchesPhrases(AnimalGroup, [".*soil.*"])>
		<#return true>
	<#elseif com.isPicklistEmptyOrOther(AnimalGroup)/>
		<#if com.picklistValueMatchesPhrases(TestOrganismsSpecies, [".*soil.*"])>
			<#return true>
		<#elseif com.isPicklistEmptyOrOther(TestOrganismsSpecies)/>
			<#if com.picklistValueMatchesPhrases(ApplicationMethod, ["soil"])>
				<#return true>
			</#if>
		</#if>
	</#if>
	
	<#return false>
</#function>

<#function isGuidelineListEmptyOrOther GuidelineList>
	<#if !(GuidelineList?has_content)>
		<#return true>
	</#if>
	<#if GuidelineList?size gt 1 >
		<#return false>
	</#if>
	<#local Guideline = GuidelineList[0].Guideline />
	<#return com.isPicklistEmptyOrOther(Guideline) />
</#function>

<#function instructionNeededForAtmosphericCompartment>	
	<#local studyList = iuclid.getSectionDocumentsForParentKey(_subject.documentKey, "ENDPOINT_STUDY_RECORD", "ToxicityToTerrestrialPlants") />
	<#if studyList?has_content>
		<#list studyList as study>
			<#if com.picklistValueMatchesPhrases(study.MaterialsAndMethods.StudyDesign.StudyType, [".*field study"])>
				<#return true />
			</#if>
		</#list>
  	</#if>
	
	<#local studyList = iuclid.getSectionDocumentsForParentKey(_subject.documentKey, "ENDPOINT_STUDY_RECORD", "ToxicityToTerrestrialArthropods") />
	<#if studyList?has_content>
		<#list studyList as study>
			<#if com.picklistValueMatchesPhrases(study.MaterialsAndMethods.ApplicationMethod, ["spray"])>
				<#return true />
			</#if>
		</#list>
  	</#if>
	
	<#return false />
</#function>

<#function isContentForAquaticAlgae summaryList>
	
	<#if !(summaryList?has_content)>		
		<#return true />
	</#if>
	<#if summaryList?has_content>		
		<#return false />
	</#if>
	
	<#return false />
</#function>

<#function getValues summaryList>
	<#local valuesCSA = []/>
	
	<#if !(summaryList?has_content)>
		<#return [] />
	</#if>
	
	<#list summaryList as summary>
		<#if isCSA(summary)>
			<#local valuesCSA = valuesCSA + [summary]/>			
		</#if>				
	</#list>
	
	<#return valuesCSA />	
</#function>

<#function isCSA summary>
	<#return summary.KeyInformation.KeyInformation?has_content || summary.Discussion.Discussion?has_content />
</#function>

<#macro CSAValueText summaryCSAValue typeText="Discussion" typeText1="The following information is taken into account for any hazard / risk assessment:">
<#compress>
	<para><emphasis role="HEAD-WoutNo">${typeText}</emphasis></para>
	<para><emphasis role="underline">${typeText1}</emphasis></para>
</#compress>
</#macro>

<#function getValuesForToxicityToBirds summaryList>
	<#local valuesCSA = []/>
	
	<#if !(summaryList?has_content)>
		<#return [] />
	</#if>
	
	<#list summaryList as summary>
		<#if isCSAToxicityToBirds(summary)>
			<#local valuesCSA = valuesCSA + [summary]/>			
		</#if>				
	</#list>
	
	<#return valuesCSA />	
</#function>

<#function isCSAToxicityToBirds summary>
	<#return summary.KeyInformation.KeyInformation?has_content || summary.Discussion.Discussion?has_content 
	|| summary.KeyValueForChemicalSafetyAssessment.BirdsShortTerm.DoseDescriptor?has_content 
	|| summary.KeyValueForChemicalSafetyAssessment.BirdsLongTerm.DoseDescriptor?has_content />
</#function>

<#function getValuesForToxicityToOtherAboveGroundOrganisms summaryList>
	<#local valuesCSA = []/>
	
	<#if !(summaryList?has_content)>
		<#return [] />
	</#if>
	
	<#list summaryList as summary>
		<#if isCSAToxicityToOtherAboveGroundOrganisms(summary)>
			<#local valuesCSA = valuesCSA + [summary]/>			
		</#if>				
	</#list>
	
	<#return valuesCSA />	
</#function>

<#function isCSAToxicityToOtherAboveGroundOrganisms summary>
	<#return summary.KeyInformation.KeyInformation?has_content || summary.Discussion.Discussion?has_content 
	|| summary.KeyValueForChemicalSafetyAssessment.MammalsShortTerm.DoseDescriptor?has_content 
	|| summary.KeyValueForChemicalSafetyAssessment.MammalsLongTerm.DoseDescriptor?has_content />
</#function>

<#function getValuesForToxicityToSoilMicroorganisms summaryList>
	<#local valuesCSA = []/>
	
	<#if !(summaryList?has_content)>
		<#return [] />
	</#if>
	
	<#list summaryList as summary>
		<#if isCSAToxicityToSoilMicroorganisms(summary)>
			<#local valuesCSA = valuesCSA + [summary]/>			
		</#if>				
	</#list>
	
	<#return valuesCSA />	
</#function>
<#function isCSAToxicityToSoilMicroorganisms summary>
	<#return summary.KeyInformation.KeyInformation?has_content || summary.Discussion.Discussion?has_content 
	|| summary.KeyValueForChemicalSafetyAssessment.SoilMicroorganismsShortTerm.DoseDescriptor?has_content 
	|| summary.KeyValueForChemicalSafetyAssessment.SoilMicroorganismsLongTerm.DoseDescriptor?has_content />
</#function>

<#function getValuesForToxicityToTerrestrialPlants summaryList>
	<#local valuesCSA = []/>
	
	<#if !(summaryList?has_content)>
		<#return [] />
	</#if>
	
	<#list summaryList as summary>
		<#if isCSAToxicityToTerrestrialPlants(summary)>
			<#local valuesCSA = valuesCSA + [summary]/>			
		</#if>				
	</#list>
	
	<#return valuesCSA />	
</#function>
<#function isCSAToxicityToTerrestrialPlants summary>
	<#return summary.KeyInformation.KeyInformation?has_content || summary.Discussion.Discussion?has_content 
	|| summary.KeyValueForChemicalSafetyAssessment.TerrestrialPlantsShortTerm.DoseDescriptor?has_content 
	|| summary.KeyValueForChemicalSafetyAssessment.TerrestrialPlantsLongTerm.DoseDescriptor?has_content />
</#function>

<#function getValuesForLongTermToxicityToAquaticInvertebrates summaryList>
	<#local valuesCSA = []/>
	
	<#if !(summaryList?has_content)>
		<#return [] />
	</#if>
	
	<#list summaryList as summary>
		<#if isCSALongTermToxicityToAquaticInvertebrates(summary)>
			<#local valuesCSA = valuesCSA + [summary]/>			
		</#if>				
	</#list>
	
	<#return valuesCSA />	
</#function>
<#function isCSALongTermToxicityToAquaticInvertebrates summary>
	<#return summary.KeyInformation.KeyInformation?has_content || summary.Discussion.Discussion?has_content 
	|| summary.KeyValueForChemicalSafetyAssessment.FreshWaterInvertebrates.DoseDescriptor?has_content
	|| summary.KeyValueForChemicalSafetyAssessment.MarineWaterInvertebrates.DoseDescriptor?has_content/>
</#function>

<#function getValuesShortTermToxicityToAquaticInvertebrates summaryList>
	<#local valuesCSA = []/>
	
	<#if !(summaryList?has_content)>
		<#return [] />
	</#if>
	
	<#list summaryList as summary>
		<#if summary?has_content>
			<#if isCSAShortTermToxicityToAquaticInvertebratesFresh(summary)>
				<#local valuesCSA = valuesCSA + [summary]/>			
			</#if>
				
			<#if isCSAShortTermToxicityToAquaticInvertebratesMarine(summary)>
				<#local valuesCSA = valuesCSA + [summary]/>			
			</#if>
		</#if>
	</#list>
	
	<#return valuesCSA />	
</#function>

<#function isCSAShortTermToxicityToAquaticInvertebratesFresh summary>
	<#return summary.KeyInformation.KeyInformation?has_content || summary.Discussion.Discussion?has_content 
	|| summary.KeyValueForChemicalSafetyAssessment.FreshWaterInvertebrates.DoseDescriptor?has_content />
</#function>

<#function isCSAShortTermToxicityToAquaticInvertebratesMarine summary>
	<#return summary.KeyInformation.KeyInformation?has_content || summary.Discussion.Discussion?has_content 
	|| summary.KeyValueForChemicalSafetyAssessment.MarineWaterInvertebrates.DoseDescriptor?has_content />
</#function>

<#function getValuesLongTermToxicityToFish summaryList>
	<#local valuesCSA = []/>
	
	<#if !(summaryList?has_content)>
		<#return [] />
	</#if>
	
	<#list summaryList as summary>
		<#if isCSALongTermToxicityToFish(summary)>
			<#local valuesCSA = valuesCSA + [summary]/>			
		</#if>				
	</#list>
	
	<#return valuesCSA />	
</#function>
<#function isCSALongTermToxicityToFish summary>

	<#return summary.KeyInformation.KeyInformation?has_content || 
	summary.Discussion.Discussion?has_content || 
	summary.KeyValueForChemicalSafetyAssessment.FreshWaterFish.DoseDescriptor?has_content || 
	summary.KeyValueForChemicalSafetyAssessment.MarineWaterFish.DoseDescriptor?has_content/>

</#function>

<#function getValuesForToxicityToTerrestrialArthropods summaryList>
	<#local valuesCSA = []/>
	
	<#if !(summaryList?has_content)>
		<#return [] />
	</#if>
	
	<#list summaryList as summary>
		<#if isCSAToxicityToTerrestrialArthropods(summary)>
			<#local valuesCSA = valuesCSA + [summary]/>			
		</#if>				
	</#list>
	
	<#return valuesCSA />	
</#function>
<#function isCSAToxicityToTerrestrialArthropods summary>
	<#return summary.KeyInformation.KeyInformation?has_content || 
	summary.Discussion.Discussion?has_content />
</#function>
<#function getValuesForToxicityToAquaticAlgae summaryList>
	<#local valuesCSA = []/>
	
	<#if !(summaryList?has_content)>
		<#return [] />
	</#if>
	
	<#list summaryList as summary>
		<#if isCSAToxicityToAquaticAlgae(summary)>
			<#local valuesCSA = valuesCSA + [summary]/>			
		</#if>				
	</#list>
	
	<#return valuesCSA />	
</#function>
<#function isCSAToxicityToAquaticAlgae summary>

	<#return summary.KeyInformation.KeyInformation?has_content || 
	summary.Discussion.Discussion?has_content || 
	summary.KeyValueForChemicalSafetyAssessment.FreshwaterAlgaeShortTerm.DoseDescriptor?has_content || 
	summary.KeyValueForChemicalSafetyAssessment.FreshwaterAlgaeShortTerm.EffectConcentration?has_content ||
	summary.KeyValueForChemicalSafetyAssessment.FreshwaterAlgaeLongTerm.DoseDescriptor?has_content ||
	summary.KeyValueForChemicalSafetyAssessment.FreshwaterAlgaeLongTerm.EffectConcentration?has_content ||
	summary.KeyValueForChemicalSafetyAssessment.MarineWaterAlgaeShortTerm.DoseDescriptor?has_content ||
	summary.KeyValueForChemicalSafetyAssessment.MarineWaterAlgaeLongTerm.DoseDescriptor?has_content />
</#function>

<#function getValueShortTermToxicityToFish summaryList>
	<#local valuesCSA = []/>
	
	<#if !(summaryList?has_content)>
		<#return [] />
	</#if>
	
	<#list summaryList as summary>
	<#if summary.KeyValueForChemicalSafetyAssessment.FreshWaterFish.DoseDescriptor?has_content>
		<#if isCSAShortTermToxicityToFishfresh(summary)>
			<#local valuesCSA = valuesCSA + [summary]/>			
		</#if>			
	</#if>
		<#if summary.KeyValueForChemicalSafetyAssessment.MarineWaterFish.DoseDescriptor?has_content>
			<#if isCSAShortTermToxicityToFishmarine(summary)>
				<#local valuesCSA = valuesCSA + [summary]/>			
			</#if>	
		</#if>
	</#list>
	
	<#return valuesCSA />	
</#function>

<#function isCSAShortTermToxicityToFishfresh summary >
	<#return summary.KeyInformation.KeyInformation?has_content || summary.Discussion.Discussion?has_content 
	|| summary.KeyValueForChemicalSafetyAssessment.FreshWaterFish.DoseDescriptor?has_content
	|| summary.KeyValueForChemicalSafetyAssessment.FreshWaterFish.EffectConcentration />
</#function>

<#function isCSAShortTermToxicityToFishmarine summary >
	<#return summary.KeyInformation.KeyInformation?has_content || summary.Discussion.Discussion?has_content 
	|| summary.KeyValueForChemicalSafetyAssessment.MarineWaterFish.DoseDescriptor?has_content 
	|| summary.KeyValueForChemicalSafetyAssessment.MarineWaterFish.EffectConcentration />
</#function>

<#function getValuesForToxicityToSoilMacroorganismsExceptArthropods summaryList>
	<#local valuesCSA = []/>
	
	<#if !(summaryList?has_content)>
		<#return [] />
	</#if>
	
	<#list summaryList as summary>
		<#if isCSAToxicityToSoilMacroorganismsExceptArthropods(summary)>
			<#local valuesCSA = valuesCSA + [summary]/>			
		</#if>				
	</#list>
	
	<#return valuesCSA />	
</#function>
<#function isCSAToxicityToSoilMacroorganismsExceptArthropods summary>
	<#return summary.KeyInformation.KeyInformation?has_content || summary.Discussion.Discussion?has_content 
	|| summary.KeyValueForChemicalSafetyAssessment.SoilMacroorganismsExceptArthropodsShortTerm.DoseDescriptor?has_content 
	|| summary.KeyValueForChemicalSafetyAssessment.SoilMacroorganismsExceptArthropodsLongTerm.DoseDescriptor?has_content />
</#function>
<#function getValuesForToxicityPlants summaryList>
	<#local valuesCSA = []/>
	
	<#if !(summaryList?has_content)>
		<#return [] />
	</#if>
	
	<#list summaryList as summary>
		<#if isCSAToxicityPlants(summary)>
			<#local valuesCSA = valuesCSA + [summary]/>			
		</#if>				
	</#list>
	
	<#return valuesCSA />	
</#function>
<#function isCSAToxicityPlants summary>
	<#return summary.KeyValueForChemicalSafetyAssessment.FreshwaterPlantsShortTerm.DoseDescriptor?has_content || 
	summary.KeyValueForChemicalSafetyAssessment.FreshwaterPlantsLongTerm.DoseDescriptor?has_content || 
	summary.KeyValueForChemicalSafetyAssessment.MarineWaterPlantsShortTerm.DoseDescriptor?has_content || 
	summary.KeyValueForChemicalSafetyAssessment.MarineWaterPlantsLongTerm.DoseDescriptor?has_content />
</#function>


<#function getValuesForSedimentToxicity summaryList>
	<#local valuesCSA = []/>
	
	<#if !(summaryList?has_content)>
		<#return [] />
	</#if>
	
	<#list summaryList as summary>
		<#if isCSASedimentToxicity(summary)>
			<#local valuesCSA = valuesCSA + [summary]/>			
		</#if>				
	</#list>
	
	<#return valuesCSA />	
</#function>
<#function isCSASedimentToxicity summary>
	<#return summary.KeyInformation.KeyInformation?has_content || summary.Discussion.Discussion?has_content 
	|| summary.KeyValueForChemicalSafetyAssessment.FreshwaterSedimentShortTerm.DoseDescriptor?has_content 
	|| summary.KeyValueForChemicalSafetyAssessment.FreshwaterSedimentLongTerm.DoseDescriptor?has_content 
	|| summary.KeyValueForChemicalSafetyAssessment.MarineWaterSedimentShortTerm.DoseDescriptor?has_content 
	|| summary.KeyValueForChemicalSafetyAssessment.MarineWaterSedimentLongTerm.DoseDescriptor?has_content />
</#function>
<#function getValuesForToxicityMicroorganisms summaryList>
	<#local valuesCSA = []/>
	
	<#if !(summaryList?has_content)>
		<#return [] />
	</#if>
	
	<#list summaryList as summary>
		<#if isCSAToxicityMicroorganisms(summary)>
			<#local valuesCSA = valuesCSA + [summary]/>			
		</#if>				
	</#list>
	
	<#return valuesCSA />	
</#function>
<#function isCSAToxicityMicroorganisms summary>
	<#return summary.KeyInformation.KeyInformation?has_content || summary.Discussion.Discussion?has_content 
	|| summary.KeyValueForChemicalSafetyAssessment.MicroorganismsShortTerm.DoseDescriptor?has_content 
	|| summary.KeyValueForChemicalSafetyAssessment.MicroorganismsLongTerm.DoseDescriptor?has_content/>
</#function>

<#macro CSAValueTextToxicityMicroorganisms summaryCSAValue typeText="Discussion" typeText1="The following information is taken into account for effects on aquatic micro-organisms for the derivation of PNEC:">
<#compress>
	<@com.emptyLine/><para><emphasis role="HEAD-WoutNo">${typeText}</emphasis></para>
	<para><emphasis role="underline">${typeText1}</emphasis></para>
</#compress>
</#macro>

<#macro CSAValueTextToxicityToBirds summaryCSAValue typeText="Discussion" typeText1="The following information is taken into account for effects on birds for the derivation of PNEC:">
<#compress>
	<@com.emptyLine/><para><emphasis role="HEAD-WoutNo">${typeText}</emphasis></para>
	<para><emphasis role="underline">${typeText1}</emphasis></para>
</#compress>
</#macro>

<#macro CSAValueToxicityToOtherAboveGroundOrganisms summaryCSAValue typeText="Discussion" typeText1="The following information is taken into account for effects on mammals for the derivation of PNEC:">
<#compress>
	<@com.emptyLine/><para><emphasis role="HEAD-WoutNo">${typeText}</emphasis></para>
	<para><emphasis role="underline">${typeText1}</emphasis></para>
</#compress>
</#macro>
<#macro CSAValueTextToxicityToSoilMicroorganisms summaryCSAValue typeText="Discussion" typeText1="The following information is taken into account for toxicity on soil micro-organisms for the derivation of PNEC:">
<#compress>
	<@com.emptyLine/><para><emphasis role="HEAD-WoutNo">${typeText}</emphasis></para>
	<para><emphasis role="underline">${typeText1}</emphasis></para>
</#compress>
</#macro>
<#macro CSAValueTextToxicityToTerrestrialPlants summaryCSAValue typeText="Discussion" typeText1="The following information is taken into account for toxicity on terrestrial plants for the derivation of PNEC:">
<#compress>
	<@com.emptyLine/><para><emphasis role="HEAD-WoutNo">${typeText}</emphasis></para>
	<para><emphasis role="underline">${typeText1}</emphasis></para>
</#compress>
</#macro>
<#macro CSAValueTextLongTermToxicityToAquaticInvertebrates summaryCSAValue typeText="Discussion" typeText1="The following information is taken into account for long-term toxicity to aquatic invertebrates for the derivation of PNEC">
<#compress>
	<@com.emptyLine/><para><emphasis role="HEAD-WoutNo">${typeText}</emphasis></para>
	<para><emphasis role="underline">${typeText1}</emphasis></para>
</#compress>
</#macro>
<#macro CSAValueTextShortTermToxicityToAquaticInvertebrates summaryCSAValue typeText="Discussion" typeText1="The following information is taken into account for short-term toxicity to aquatic invertebrates for the derivation of PNEC:">
<#compress>
	<@com.emptyLine/><para><emphasis role="HEAD-WoutNo">${typeText}</emphasis></para>
	<para><emphasis role="underline">${typeText1}</emphasis></para>
</#compress>
</#macro>
<#macro CSAValueTextLongTermToxicityToFish summaryCSAValue typeText="Discussion" typeText1="The following information is taken into account for long-term fish toxicity for the derivation of PNEC:">
<#compress>
	<@com.emptyLine/><para><emphasis role="HEAD-WoutNo">${typeText}</emphasis></para>
	<para><emphasis role="underline">${typeText1}</emphasis></para>
</#compress>
</#macro>
<#macro CSAValueTextShortTermToxicityToFish summaryCSAValue typeText="Discussion" typeText1="The following information is taken into account for acute fish toxicity for the derivation of PNEC:">
<#compress>
	<para><@com.emptyLine/><emphasis role="HEAD-WoutNo">${typeText}</emphasis></para>
	<para><emphasis role="underline">${typeText1}</emphasis></para>
</#compress>
</#macro>
<#macro CSAValueTextToxicityToAquaticAlgae summaryCSAValue typeText="Discussion" typeText1="Effects on algae / cyanobacteria" typeText2="The following information is taken into account for effects on algae / cyanobacteria for the derivation of PNEC:">
<#compress>
	<@com.emptyLine/><para><emphasis role="HEAD-WoutNo">${typeText}</emphasis></para>
	<para><emphasis role="HEAD-WoutNo">${typeText1}</emphasis></para>
	<para><emphasis role="underline">${typeText2}</emphasis></para>
</#compress>
</#macro>
<#macro CSAValueTextToxicityPlants summaryCSAValue typeText="Discussion" typeText1="Effects on aquatic plants other than algae" typeText2="The following information is taken into account for effects on aquatic plants other than algae for the derivation of PNEC:">
<#compress>
	<@com.emptyLine/><para><emphasis role="HEAD-WoutNo">${typeText}</emphasis></para>
	<para><emphasis role="HEAD-WoutNo">${typeText1}</emphasis></para>
	<para><emphasis role="underline">${typeText2}</emphasis></para>
</#compress>
</#macro>
<#macro CSAValueTextSedimentToxicity summaryCSAValue typeText="Discussion" typeText1="The following information is taken into account for sediment toxicity for the derivation of PNEC:">
<#compress>
	<@com.emptyLine/><para><emphasis role="HEAD-WoutNo">${typeText}</emphasis></para>
	<para><emphasis role="underline">${typeText1}</emphasis></para>
</#compress>
</#macro>
<#macro CSAValueTextToxicityToSoilMacroorganismsExceptArthropods summaryCSAValue typeText="Discussion of effects on soil macro-organisms except arthropods" typeText1="The following information is taken into account for effects on soil macro-organisms except arthropods for the derivation of PNEC:">
<#compress>
	<@com.emptyLine/><para><emphasis role="HEAD-WoutNo">${typeText}</emphasis></para>
	<para><emphasis role="underline">${typeText1}</emphasis></para>
</#compress>
</#macro>
<#macro CSAValueTextToxicityToTerrestrialArthropods summaryCSAValue typeText="Discussion of effects on soil dwelling arthropods" typeText1="The following information is taken into account for effects on soil dwelling arthropods for the derivation of PNEC:">
<#compress>
	<@com.emptyLine/><para><emphasis role="HEAD-WoutNo">${typeText}</emphasis></para>
	<para><emphasis role="underline">${typeText1}</emphasis></para>
</#compress>
</#macro>
<#macro CSAValueTextToxicityToSoilArthropods summaryCSAValue typeText="Discussion of effects on soil arthropods" typeText1="The following information is taken into account for effects on soil arthropods for the derivation of PNEC:">
<#compress>
	<@com.emptyLine/><para><emphasis role="HEAD-WoutNo">${typeText}</emphasis></para>
	<para><emphasis role="underline">${typeText1}</emphasis></para>
</#compress>
</#macro>

<#macro CSAValueTextNew summary summaryTitle="" docSubType="">
<#compress>
	<para><emphasis role="HEAD-WoutNo">
		<#assign docUrl=iuclid.webUrl.documentView(summary.documentKey) />
		<ulink url="${docUrl}">Discussion on ${summaryTitle}</ulink>
	</emphasis></para>
	<#if docSubType!="AquaticToxicity">
	<para><emphasis role="underline">The following information is taken into account for ${summaryTitle} for the derivation of PNEC:</emphasis></para>
	</#if>
</#compress>
</#macro>

<#function checkSummaryInfo summary>
	<#local valuesCSA = []/>
	
	<#if !(summary?has_content)>
		<#return [] />
	</#if>
	
	<#if summary.hasElement("KeyInformation")>
		<#local valuesCSA = valuesCSA + [summary]/>			
	</#if>		
	
	<#return valuesCSA />	
</#function>

<#-- Macros to separate documents into three lists: 'study results', 'data waiving', 'testing proposal' -->

<#macro populateResultAndDataWaivingAndTestingProposalStudyLists studyList>
	<#assign resultStudyList = [] />
	<#assign dataWaivingStudyList = [] />
	<#assign testingProposalStudyList = [] />
	<#if studyList?has_content>
		<#list studyList as study>
			<#if isTestingProposalStudy(study)>
				<#assign testingProposalStudyList = testingProposalStudyList + [study] />
			<#elseif isDataWaivingStudy(study)>
				<#assign dataWaivingStudyList = dataWaivingStudyList + [study] />
			<#elseif isRelevantAdequacyOfStudy(study)>
				<#assign resultStudyList = resultStudyList + [study] />
			</#if>
		</#list>
	</#if>
	<#-- sort resultStudyList according to PurposeFlag -->
	<#assign resultStudyList = iuclid.sortByField(resultStudyList, "AdministrativeData.PurposeFlag", ["key study","supporting study","weight of evidence","(Q)SAR","disregarded due to major methodological deficiencies","other information"]) />
</#macro>

<#function isRelevantAdequacyOfStudy study>
	<#if !(study?has_content)>
		<#return false>
	</#if>
	<#local PurposeFlag = study.AdministrativeData.PurposeFlag />
    <#return PurposeFlag?has_content && !com.picklistValueMatchesPhrases(PurposeFlag, ["other information"]) />
</#function>

<#function isDataWaivingStudy study>
	<#if !(study?has_content)>
		<#return false>
	</#if>
	<#local PurposeFlag = study.AdministrativeData.PurposeFlag />
	<#local DataWaiving = study.AdministrativeData.DataWaiving />
    <#return !(PurposeFlag?has_content) && DataWaiving?has_content />
</#function>

<#function isTestingProposalStudy study>
	<#if !(study?has_content)>
		<#return false>
	</#if>
    <#return com.picklistValueMatchesPhrases(study.AdministrativeData.StudyResultType, ["experimental study planned.*"]) />
</#function>


<#---------------------------------------------PPP additions------------------------------------------------->

<#--1. Results-->

<#--Toxicity to birds
	NOTE: could be merged with the general macro-->
<#macro results_toxicityToBirds study>
	<#compress>

		<#if study.ResultsAndDiscussion.EffectLevels?has_content>
			<para>Effect levels:</para>
			<para role="indent"><@effectBirdsList studyandsummaryCom.orderByKeyResult(study.ResultsAndDiscussion.EffectLevels)/></para>
		</#if>

		<@com.children study.ResultsAndDiscussion/>
	</#compress>
</#macro>

<#--Macro for general toxicity results, applicable to different document sub types-->
<#macro results_envToxicity study>
	<#compress>
		<#if study.ResultsAndDiscussion.EffectConcentrations?has_content>
			<para>Effect concentrations:</para>
			<para role="indent"><@effectList studyandsummaryCom.orderByKeyResult(study.ResultsAndDiscussion.EffectConcentrations) study/></para>
		</#if>

		<@com.children study.ResultsAndDiscussion/>

	</#compress>
</#macro>

<#--Bioaccumulation-->
<#macro results_bioaccumulation study>
	<#compress>

		<#-- blocks -->
		<#if study.ResultsAndDiscussion.LipidContent?has_content>
			<para>Lipid content:</para>
			<para role="indent"><@lipidContentList study.ResultsAndDiscussion.LipidContent/></para>
		</#if>

		<#if study.ResultsAndDiscussion.BioaccumulationFactor?has_content>
			<para>Bioconcentration factor:</para>
			<para role="indent"><@bioConcFactorList studyandsummaryCom.orderByKeyResult(study.ResultsAndDiscussion.BioaccumulationFactor)/></para>
		</#if>

		<#if study.ResultsAndDiscussion.Depuration?has_content>
			<para>Depuration:</para>
			<para role="indent"><@depurationList studyandsummaryCom.orderByKeyResult(study.ResultsAndDiscussion.Depuration)/></para>
		</#if>

		<#if study.ResultsAndDiscussion.hasElement("RateConstants") && study.ResultsAndDiscussion.RateConstants?has_content>
			<para>Rate constants:</para>
			<para role="indent"><@rateConstantsList studyandsummaryCom.orderByKeyResult(study.ResultsAndDiscussion.RateConstants)/></para>
		</#if>
		
		<#if study.ResultsAndDiscussion.KineticParameters?has_content> <#-- kinetic parameters right after RateConstants block -->
			<para>Details on kinetic parameters: <@com.value study.ResultsAndDiscussion.KineticParameters/></para>
		</#if>

		<#-- metabolites fields -->
		<#if study.ResultsAndDiscussion.Metabolites?has_content || study.ResultsAndDiscussion.MetabolitesDetails?has_content || study.ResultsAndDiscussion.IdentityOfMetabolites?has_content>
			<para>Metabolites: <@com.value study.ResultsAndDiscussion.Metabolites/></para>
			<para role="indent"><@com.value study.ResultsAndDiscussion.MetabolitesDetails/></para>
			<para role="indent"><@metabolitesIdentityTable studyandsummaryCom.orderByKeyResult(study.ResultsAndDiscussion.IdentityOfMetabolites)/></para>
		</#if>

		<#-- rest of fields -->
		<@com.children path=study.ResultsAndDiscussion exclude=['KineticParameters', 'Metabolites', 'MetabolitesDetails']/>

	</#compress>
</#macro>


<#macro lipidContentList lipidContentRepeatableBlock>
	<#compress>
		<#if lipidContentRepeatableBlock?has_content>
			<#list lipidContentRepeatableBlock as blockItem>
				<#if blockItem.LipidContent?has_content || blockItem.TimePoint?has_content || blockItem.RemarksOnResults?has_content>
					<para role="indent">
						<#if blockItem.TimePoint?has_content>
							<@com.picklist blockItem.TimePoint/>:
						</#if>

						<#if blockItem.LipidContent?has_content>
							<@com.range blockItem.LipidContent/>
						</#if>

						<#if blockItem.RemarksOnResults?has_content>
							(<@com.picklist blockItem.RemarksOnResults/>)
						</#if>
					</para>
				</#if>
			</#list>
		</#if>
	</#compress>
</#macro>

<#macro bioConcFactorList bioConcFactorRepeatableBlock>
	<#compress>
		<#if bioConcFactorRepeatableBlock?has_content>
			<#list bioConcFactorRepeatableBlock as blockItem>
				<#if blockItem.Type?has_content || blockItem.Value?has_content || blockItem.Basis?has_content ||
				blockItem.TimeOfPlateau?has_content || blockItem.CalculationBasis?has_content || blockItem.RemarksOnResults?has_content >
					<para role="indent">
						<#if blockItem.Type?has_content>
							<@com.picklist blockItem.Type/>:
						</#if>

						<#if blockItem.Value?has_content>
							<@com.range blockItem.Value/>
						</#if>

						<#if blockItem.Basis?has_content>
							on <@com.picklist blockItem.Basis/>
						</#if>

						<#if blockItem.TimeOfPlateau?has_content>
							. Time of plateau: <@com.quantity blockItem.TimeOfPlateau/>
						</#if>

						<#if blockItem.CalculationBasis?has_content>
							. Calculation basis: <@com.picklist blockItem.CalculationBasis/>
						</#if>

						<#if blockItem.RemarksOnResults?has_content>
							(<@com.picklist blockItem.RemarksOnResults/>)
						</#if>
					</para>
				</#if>
			</#list>
		</#if>
	</#compress>
</#macro>

<#macro depurationList depurationRepeatableBlock>
	<#compress>
		<#if depurationRepeatableBlock?has_content>
			<#list depurationRepeatableBlock as blockItem>
				<#if blockItem.Elimination?has_content || blockItem.Endpoint?has_content || blockItem.DepurationTime?has_content ||
				blockItem.RemarksOnResults?has_content >
					<para role="indent">
						<#if blockItem.Elimination?has_content>
							elimination: <@com.picklist blockItem.Elimination/>
						</#if>

						<#if blockItem.Endpoint?has_content>
							<@com.picklist blockItem.Endpoint/>:
						</#if>

						<#if blockItem.DepurationTime?has_content>
							<@com.quantity blockItem.DepurationTime/>
						</#if>

						<#if blockItem.RemarksOnResults?has_content>
							(<@com.picklist blockItem.RemarksOnResults/>)
						</#if>
					</para>
				</#if>
			</#list>
		</#if>
	</#compress>
</#macro>

<#macro rateConstantsList repeatableBlock>
	<#compress>
		<#if repeatableBlock?has_content>
			<#list repeatableBlock as blockItem>
				<para role="indent">
					<#if blockItem.RateConstant?has_content>
						<@com.value blockItem.RateConstant/>:
					</#if>

					<#if blockItem.Value?has_content>
						<@com.value blockItem.Value/>
					</#if>

					<#if blockItem.RemarksOnResults?has_content>
						(<@com.value blockItem.RemarksOnResults/>)
					</#if>
				</para>
			</#list>
		</#if>
	</#compress>
</#macro>

<#macro metabolitesIdentityTable repeatableBlock>
	<#compress>
		<#if repeatableBlock?has_content>
			<table border="1">
				<tbody valign="middle">

					<tr align="center">
						<th><?dbfo bgcolor="#d3d3d3" ?><emphasis role="bold">Identity of compound</emphasis></th>
						<th><?dbfo bgcolor="#d3d3d3" ?><emphasis role="bold">Parent compound(s)</emphasis></th>
						<th><?dbfo bgcolor="#d3d3d3" ?><emphasis role="bold">Max. occurrence</emphasis></th>
					</tr>

				<#list repeatableBlock as blockItem>
					<tr>
						<td>
							<#if blockItem.IdentityOfCompound?has_content>
								<#local refSubstance=iuclid.getDocumentForKey(blockItem.IdentityOfCompound)/>
								<@com.text refSubstance.ReferenceSubstanceName/>
							</#if>
						</td>

						<td>
							<#if blockItem.ParentCompoundS?has_content>
								<#list blockItem.ParentCompoundS as parent>
									<#local refSubstance=iuclid.getDocumentForKey(parent)/>
									<#if (blockItem.ParentCompoundS?size>1)><para></#if><@com.text refSubstance.ReferenceSubstanceName/><#if (blockItem.ParentCompoundS?size>1)></para></#if>
								</#list>
							</#if>
						</td>

						<td>
							<@com.value blockItem.MaximumOccurrence/>
						</td>
					</tr>
				</#list>

				</tbody>
			</table>
		</#if>
	</#compress>
</#macro>

<#--2. methods-->

<#macro ecotoxMethod study>
	<#compress>

		<#--Test organisms-->
		<#--NOTE: sometimes (e.g. ToxicityToTerrestrialPlants) is a repeatable block-->
		<#if study.MaterialsAndMethods.hasElement("TestOrganisms") && study.MaterialsAndMethods.TestOrganisms?has_content>
			<#local to=study.MaterialsAndMethods.TestOrganisms/>
			<para><emphasis role='bold'>Test organisms:</emphasis>
				<#if study.documentSubType=="ToxicityToTerrestrialPlants">
					<@TestOrgsForTerrestrialPlants to.TestOrganisms/>
				<#else>
					<#if to.hasElement("TestOrganismsSpecies") && to.TestOrganismsSpecies?has_content>
						<@com.picklist to.TestOrganismsSpecies/>

					<#elseif to.hasElement("TestOrganismsInoculum") && to.TestOrganismsInoculum?has_content>
						<@com.picklist to.TestOrganismsInoculum/>
					</#if>

					<#if to.hasElement("AnimalGroup") && to.AnimalGroup?has_content>
						(<@com.value to.AnimalGroup/>)
					</#if>

					<#if to.hasElement("DetailsOnTestOrganisms") && to.DetailsOnTestOrganisms?has_content>
						<para role="indent">
							(<@com.text to.DetailsOnTestOrganisms/>)
						</para>
					</#if>
				</#if>
			</para>
		</#if>

		<#--Sampling and analysis-->
		<#if study.MaterialsAndMethods.hasElement("SamplingAndAnalysis") && study.MaterialsAndMethods.SamplingAndAnalysis?has_content>
			<para><emphasis role='bold'>Sampling and analysis:</emphasis>
				<@com.children study.MaterialsAndMethods.SamplingAndAnalysis/>
			</para>
		</#if>

		<#--Test solutions-->
		<#if study.MaterialsAndMethods.hasElement("TestSolutions") && study.MaterialsAndMethods.TestSolutions?has_content>
			<para><emphasis role='bold'>Test solutions:</emphasis>
				<@com.children study.MaterialsAndMethods.TestSolutions/>
			</para>
		</#if>

		<#--Test substrate-->
		<#if study.MaterialsAndMethods.hasElement("TestSubstrate") && study.MaterialsAndMethods.TestSubstrate?has_content>
			<para><emphasis role='bold'>Test substrate:</emphasis>
				<@com.children study.MaterialsAndMethods.TestSubstrate/>
			</para>
		</#if>

		<#--Study design-->
		<#if study.MaterialsAndMethods.hasElement("StudyDesign") && study.MaterialsAndMethods.StudyDesign?has_content>
			<para><emphasis role='bold'>Study design:</emphasis>
				<@com.children study.MaterialsAndMethods.StudyDesign/>
			</para>
		</#if>

		<#--Examinations-->
		<#if study.MaterialsAndMethods.hasElement("Examinations") && study.MaterialsAndMethods.Examinations?has_content>
			<para><emphasis role='bold'>Examinations:</emphasis>
				<@com.children study.MaterialsAndMethods.Examinations/>
			</para>
		</#if>

		<#--Test conditions-->
		<#if study.MaterialsAndMethods.hasElement("TestConditions") && study.MaterialsAndMethods.TestConditions?has_content>
			<para><emphasis role='bold'>Test conditions:</emphasis>
				<@com.children path=study.MaterialsAndMethods.TestConditions exclude=["IdentityOfTheReferenceSubstancePositiveControl"]/>

				<#if study.MaterialsAndMethods.TestConditions.hasElement("IdentityOfTheReferenceSubstancePositiveControl") && study.MaterialsAndMethods.TestConditions.IdentityOfTheReferenceSubstancePositiveControl?has_content>
					<para role='indent'>Ref. substance:</para>
					<#list study.MaterialsAndMethods.TestConditions.IdentityOfTheReferenceSubstancePositiveControl as refSubLink>
						<#local refSubstance=iuclid.getDocumentForKey(refSubLink)/>
						<para role='indent2'><@com.text refSubstance.ReferenceSubstanceName/></para>
					</#list>
				</#if>
			</para>
		</#if>

	</#compress>
</#macro>

<#--3. summaries-->

<#-- ecotoxCSA prints the information under the section Key Value for Chemical Safety Assessment of 
	ecotox summaries, based on the document sub type.
	- For harmonised summaries, it uses the ecotoxCSAtable macro in macros_common_studies_and_summaries.
	- For old EU_PPP summaries (obsolete since April 2023), it uses the macro ecotoxCSAtable_EU_PPP in this module.
	- For AquaticToxicityRacReporting, it uses a specific macro for the RAC values
	Summaries from these 3 different types cannot be combined together.
	
	Inputs:
	- summaryList: single or list of summary document objects (ENDPOINT_SUMMARY or FLEXIBLE_SUMMARY) 
-->
<#macro ecotoxCSA summaryList>

	<#-- make list if it's single object -->
	<#if !summaryList?is_sequence>
		<#local summaryList=[summaryList]/>
	</#if>

	<#-- case for Aquatic RAC (print tables sequentially) -->
	<#if summaryList[0].documentSubType=="AquaticToxicityRacReporting">
		<#list summaryList as summary>
			<#if summary.KeyInformation.RACValues?has_content>
			<para role="small"><@RACvaluesTable summary.KeyInformation.RACValues/></para>
			</#if>
		</#list>

	<#-- case of old EU_PPP summaries -->
	<#elseif summaryList[0].documentSubType?contains("_EU_PPP")>
		<@ecotoxCSAtable_EU_PPP summaryList/>

	<#-- case of harmonised summaries: use the generic macro in studies and summaries common module -->
	<#else>
		<@studyandsummaryCom.ecotoxCSAtable summaryList/>
	</#if>

</#macro>

<#-- ecotoxCSAtable_EU_PPP prints the information under the section Key Value for Chemical Safety Assessment of 
	ecotox summaries of EU_PPP type (OBSOLETE since april 2023)
	
	Inputs:
	- summaryList: single or list of summary document objects (ENDPOINT_SUMMARY or FLEXIBLE_SUMMARY)
-->
<#macro ecotoxCSAtable_EU_PPP summaryList>

	<#-- make list if it's single object -->
	<#if !summaryList?is_sequence>
		<#local summaryList=[summaryList]/>
	</#if>

	<#-- create a hash containing information from all summaries -->
	<#local endpointsHash = {}/>
	<#list summaryList as summary>
		<#local summaryCSAseq = getEcotoxSummarySeq_EU_PPP(summary)/>
		<#list summaryCSAseq as seqEntry>
			<#if endpointsHash[seqEntry["name"]]??>
				<#local newSeqEntry = endpointsHash[seqEntry["name"]] + [seqEntry]/>
				<#local endpointsHash = endpointsHash + {seqEntry["name"]:newSeqEntry}/>
			<#else>
				<#local endpointsHash = endpointsHash + {seqEntry["name"]:[seqEntry]}/>
			</#if>
		</#list>
	</#list>

	<@getEcotoxSummaryFromHash_EU_PPP endpointsHash/>

</#macro>

<#--Function to create a hashmap with CSA info from ecotox summaries
	(OBSOLETE since april 2023) -->
<#function getEcotoxSummarySeq_EU_PPP summary csaPath="">

	<#-- initialise -->
	<#local mySeq=[]/>

	<#-- consider different path names, if not provided (missing RAC, and bioterrestrial)-->
	<#if !csaPath?has_content>
		<#if summary.hasElement("KeyValueForCsa")>
			<#local csaPath=summary["KeyValueForCsa"]>
		<#elseif summary.hasElement("KeyValueForChemicalSafetyAssessment")>
			<#local csaPath=summary["KeyValueForChemicalSafetyAssessment"]>
		<#elseif summary.hasElement("KeyValueCsa")>
			<#local csaPath=summary["KeyValueCsa"]>
		</#if>
	</#if>

	<#-- iterate CSA blocks-->
	<#if csaPath?has_content>

		<#-- consider case where links are outside of the table-->
		<#local generalLinks=""/>
		<#if summary.hasElement("LinkToRelevantStudyRecord.Link") && summary.LinkToRelevantStudyRecord.Link?has_content>
			<#local generalLinks><#compress>
				<#list summary.LinkToRelevantStudyRecord.Link as link>
					<#if link?has_content>
						<#local studyReference = iuclid.getDocumentForKey(link) />
						<command  linkend="${studyReference.documentKey.uuid!}">
							<@com.text studyReference.name/>
						</command>
						<#if link_has_next><?linebreak?></#if>
					</#if>
				</#list>
			</#compress></#local>
		</#if>

		<#list csaPath?children as block>
			<#if block?node_type=="repeatable" && block?has_content>
				<#--  <#local testType=block?node_name?replace("([A-Z]{1})", " $1", "r")?replace("_list", "")?lower_case?cap_first/>  -->
				<@iuclid.label for=block var="testType"/>

				<#list block as item>
					<#--Test type-->
					<#local testType><#compress>
						${testType}
						<#if item.hasElement("TypeOfStudy") && item.TypeOfStudy?has_content>
							<?linebreak?>(<@com.picklist item.TypeOfStudy/>)
						</#if>
					</#compress></#local>

					<#--Links-->
					<#local links><#compress>
						<#if item.hasElement("Link")>
							<#if item.Link?has_content>
								<#local studyReference = iuclid.getDocumentForKey(item.Link) />
								<command  linkend="${studyReference.documentKey.uuid!}">
									<@com.text studyReference.name/>
								</command>
							</#if>
						<#elseif generalLinks?has_content>
							${generalLinks}
						</#if>
					</#compress></#local>

					<#-- Organisms-->
					<#local orgs><#compress>
						<#if item.hasElement("AnimalGroup") && item.AnimalGroup?has_content>
							<#if item.AnimalGroup?node_type=="picklist_multi">
								<@com.picklistMultiple item.AnimalGroup/>
							<#else>
								<@com.text item.AnimalGroup/>
							</#if>
							<#if item.TestOrganismsSpecies?has_content>: </#if>
						</#if>
						<#if item.hasElement("TestOrganismsSpecies") && item.TestOrganismsSpecies?has_content>
							<@com.picklistMultiple item.TestOrganismsSpecies/>
						</#if>
						<#-- special case for bioaccummulation -->
						<#if summary.documentSubType=="BioaccumulationAquaticSediment_EU_PPP">
							fish
						</#if>

					</#compress></#local>

					<#-- Substance-->
					<#local substance><#compress>
						<#if item.Substance?has_content>
							<#local refSubstance=iuclid.getDocumentForKey(item.Substance)/>
							<@com.text refSubstance.ChemicalName/>
						</#if>
						<#if item.ParentMetabolite?has_content>
							<?linebreak?>(<@com.picklist item.ParentMetabolite/>)
						</#if>
					<#--PreparationApplicationTestSubstance (richText) details preparation/application substance-->
					</#compress></#local>

					<#-- Endpoint -->
					<#local endpoint><#compress>
						<#if item.hasElement("DoseDescriptor") && item.DoseDescriptor?has_content>
							<@com.picklist item.DoseDescriptor/>:
							<#if item.hasElement("EffectConcentration")><@com.range item.EffectConcentration/>
							<#elseif item.hasElement("EffectConc")><@com.range item.EffectConc/>
							<#elseif item.hasElement("EffectValue")><@com.range item.EffectValue/>
							</#if>
						</#if>
						<#if item.hasElement("NominalMeasured") && item.NominalMeasured?has_content>
							<?linebreak?>(<@com.picklist item.NominalMeasured/>)
						</#if>
						<#if item.hasElement("BasisForEffect") && item.BasisForEffect?has_content>
							<?linebreak?>(basis: <@com.picklistMultiple item.BasisForEffect/>)
						</#if>

						<#-- special case for bioaccummulation in fish -->
						<#if summary.documentSubType=="BioaccumulationAquaticSediment_EU_PPP">
							<#if item.LogPow?has_content>
								logPo/w = <@com.text item.LogPow/><?linebreak?>
							</#if>
							<#if item.BcfAquaticSpecies?has_content>
								BCF (aquatic species) = <@com.quantity item.BcfAquaticSpecies/><?linebreak?>
							</#if>
							<#if item.CtFiftyClearaceTime?has_content>
								CT50 = <@com.quantity item.CtFiftyClearaceTime/><?linebreak?>
							</#if>
							<#if item.CtNinetyClearaceTime?has_content>
								CT90 = <@com.quantity item.CtNinetyClearaceTime/><?linebreak?>
							</#if>
						</#if>
					</#compress></#local>

					<#--append-->
					<#if links?has_content || endpoint?has_content || orgs?has_content || substance?has_content>
						<#local mySeq = mySeq + [{'name': testType!, "links" : links!, "endpoint":endpoint!, "substance":substance!, "organisms":orgs!}]/>
					</#if>

				</#list>
			</#if>
		</#list>

		<#--special cases-->
		<#if csaPath.hasElement("EcTenLcTenNoecMarineWaterFish") && csaPath.EcTenLcTenNoecMarineWaterFish?has_content>
			<#local endpoint>EC10 / LC10 / NOEC: <@com.range csaPath.EcTenLcTenNoecMarineWaterFish/></#local>
			<#local mySeq = mySeq + [{'name': "Long-term toxicity to marine fish", "links" : generalLinks!, "endpoint":endpoint, "substance":"",
			"organisms":"Marine fish"}]/>
		</#if>

		<#if csaPath.hasElement("FishBmf") && csaPath.FishBmf?has_content>
				<#local endpoint>BMF (fish) =  <@com.number summary.KeyValueCsa.FishBmf/></#local>
				<#local mySeq = mySeq + [{'name': "Bioconcentration in fish", "links" : generalLinks!, "endpoint":endpoint, "substance":"",
					"organisms":"Fish"}]/>
		</#if>		

	</#if>

	<#return mySeq/>

</#function>


<#-- getEcotoxSummaryFromHash_EU_PPP creates a table for the section of the Key Value for Chemical Safety Assessment
	 of ecotox summaries of EU_PPP type stored in a hashmap (OBSOLETE since april 2023) 
	
	Inputs:
	- hash: hashmap from macro ecotoxCSAtable_EU_PPP
-->
<#macro getEcotoxSummaryFromHash_EU_PPP hash>
	<#compress>
		<table border="1">
			<tbody valign="middle">
			<tr align="center">
				<th><?dbfo bgcolor="#FBDDA6" ?><emphasis role="bold">Test type</emphasis></th>
				<th><?dbfo bgcolor="#FBDDA6" ?><emphasis role="bold">Study</emphasis></th>
				<th><?dbfo bgcolor="#FBDDA6" ?><emphasis role="bold">Organism</emphasis></th>
				<th><?dbfo bgcolor="#FBDDA6" ?><emphasis role="bold">Substance</emphasis></th>
				<th><?dbfo bgcolor="#FBDDA6" ?><emphasis role="bold">Endpoint</emphasis></th>
			</tr>

			<#--			<#list hash?keys?sort as key>-->
			<#list hash?keys as key>
				<#local seq = hash[key]/>
				<#local usespan = true />
				<#list seq as item>
					<tr>
						<#if usespan>
							<td rowspan="${seq?size}">${key}</td>
							<#local usespan = false />
						</#if>
						<td>${item.links}</td>
						<td>${item.organisms}</td>
						<td>${item.substance}</td>
						<td>${item.endpoint}</td>
					</tr>
				</#list>
			</#list>
			</tbody></table>
	</#compress>
</#macro>

<#-- ecotoxPPPsummary prints a summary of the ecotox section for PPP (DEPRECATED)

	Inputs:
	- subject: entity
	- docSubTypes: list of str defining the document subtypes
	- merge: if True, merge each subsections of all documents found

	NOTE: if _metabolites exist, the corresponding summaries are also shown.
-->
<#macro ecotoxPPPsummary subject docSubTypes merge=false>
	<#compress>

		<#--Get all documents, from same or different type-->
		<#if !docSubTypes?is_sequence>
			<#local docSubTypes=[docSubTypes]/>
		</#if>

		<#--Ensure merge=false for non compatible summary types-->
		<#if docSubTypes?seq_contains("AquaticToxicityRacReporting") ||
			docSubTypes?seq_contains("BioaccumulationTerrestrial") ||
			docSubTypes?seq_contains("BioaccumulationAquaticSediment_EU_PPP")>
			<#local merge=false>
		</#if>

		<#-- Get all entities (subject and metabolites, if they exist)-->
		<#local entities=[subject]/>
		<#if _metabolites?? && _metabolites?has_content>
			<#local entities = entities + _metabolites/>
		</#if>

		<#-- Get all summaries for each entity-->
		<#local entity2summaryHash = {}/>
		<#list entities as entity>
			<#local entitySummaryList=[]/>
			<#list docSubTypes as docSubType>
				<#if docSubType=="AquaticToxicityRacReporting">
					<#local summaryList = iuclid.getSectionDocumentsForParentKey(entity.documentKey, "FLEXIBLE_SUMMARY", docSubType) />
				<#else>
					<#local summaryList = iuclid.getSectionDocumentsForParentKey(entity.documentKey, "ENDPOINT_SUMMARY", docSubType) />
				</#if>
				<#local entitySummaryList = entitySummaryList + summaryList/>
			</#list>
			<#if entitySummaryList?has_content>
				<#if entity.documentType=="MIXTURE">
					<#local entityName=entity.MixtureName/>
				<#elseif entity.documentType=="SUBSTANCE">
					<#local entityName=entity.ChemicalName/>
				</#if>
				<#local entity2summaryHash = entity2summaryHash + { entityName : entitySummaryList}/>
			</#if>
		</#list>

		<#--Iterate through summaries and create section lists for each entity-->
		<#if !entity2summaryHash?has_content>
			<@com.emptyLine/>
			<para>No summary information available for this section.</para>
			<@com.emptyLine/>
		<#else>
			<#list entity2summaryHash as entityName, allSummaryList>

				<#local keyInfo=[]/>
				<#local endpointsHash={}/>
				<#local higherTier=[]/>
				<#local discussion=[]/>

				<#local printSummaryName = allSummaryList?size gt 1 />

				<#if allSummaryList?has_content>

					<#if entity2summaryHash?keys?seq_index_of(entityName)==0>
						<para><@com.emptyLine/><emphasis role="HEAD-WoutNo">Summary</emphasis></para>
					</#if>

					<#if _metabolites?? && _metabolites?has_content && entityName!=subject.ChemicalName>
						<@com.emptyLine/>
						<para><emphasis role="underline">----- Metabolite <emphasis role="bold">${entityName}</emphasis> -----</emphasis></para>
						<@com.emptyLine/>
					</#if>

					<#list allSummaryList as summary>

						<#if (!merge) && printSummaryName>
							<para><emphasis role="bold">#${summary_index+1}: <@com.text summary.name/></emphasis></para>
						</#if>

						<#-- consider different path names (missing RAC, and bioterrestrial)-->
						<#if summary.hasElement("KeyValueForCsa")>
							<#local csaPath=summary["KeyValueForCsa"]>
						<#elseif summary.hasElement("KeyValueForChemicalSafetyAssessment")>
							<#local csaPath=summary["KeyValueForChemicalSafetyAssessment"]>
						<#elseif summary.hasElement("KeyValueCsa")>
							<#local csaPath=summary["KeyValueCsa"]>
						<#else>
							<#local csaPath="">
						</#if>

						<#-- Key information-->
						<#if summary.KeyInformation.KeyInformation?has_content>
							<#local summaryKeyInfo><para role="indent"><@com.richText summary.KeyInformation.KeyInformation/></para></#local>
							<#if merge>
								<#local keyInfo = keyInfo + [summaryKeyInfo]/>
							<#else>
								<para><emphasis role="bold">Key information: </emphasis></para>${summaryKeyInfo}
							</#if>
						</#if>

						<#--Links (only for cases with no standard table)-->
						<#if (!(csaPath?has_content) || summary.documentSubType=="BioaccumulationAquaticSediment_EU_PPP")
							&& (!merge)
							&& summary.hasElement("LinkToRelevantStudyRecord.Link") && summary.LinkToRelevantStudyRecord.Link?has_content>
							<para><emphasis role="bold">Link to relevant study records: </emphasis></para>
							<para role="indent">
								<#list summary.LinkToRelevantStudyRecord.Link as link>
									<#if link?has_content>
										<#local studyReference = iuclid.getDocumentForKey(link) />
										<para>
											<command  linkend="${studyReference.documentKey.uuid!}">
												<@com.text studyReference.name/>
											</command>
										</para>
									</#if>
								</#list>
							</para>
						</#if>

						<#--CSA-->
						<#if csaPath?? && csaPath?has_content>
							<@ecotoxCSA summary/>
						</#if>

						<#--Hier tier testing-->
						<#if summary.hasElement("HigherTierTesting.field1350") && summary.HigherTierTesting.field1350?has_content>
							<#local summaryHigherTier><para role="indent"><@com.richText summary.HigherTierTesting.field1350/></para></#local>
							<#if merge>
								<#local higherTier = higherTier + [summaryHigherTier]/>
							<#else>
								<para><emphasis role="bold">Higher tier testing for safety assessment: </emphasis></para>${summaryHigherTier}
							</#if>
						</#if>

						<#--Discussion-->
						<#if summary.hasElement("Discussion.Discussion") && summary.Discussion.Discussion?has_content>
							<#local summaryDiscussion><para role="indent"><@com.richText summary.Discussion.Discussion/></para></#local>
							<#if merge>
								<#local discussion =  discussion + [summaryDiscussion]/>
							<#else>
								<para><emphasis role="bold">Discussion: </emphasis></para>${summaryDiscussion}
							</#if>
						</#if>
					</#list>

					<#if merge>
						<#if keyInfo?has_content>
							<para><emphasis role="bold">Key information: </emphasis></para>
							${keyInfo?join("")}
						</#if>

						<#if endpointsHash?has_content>
							<para><emphasis role="bold">Key values for chemical safety assessment: </emphasis></para>
							<@ecotoxCSA allSummaryList/>
						</#if>

						<#if higherTier?has_content>
							<para><emphasis role="bold">Higher tier testing for safety assessment:</emphasis></para>
							${higherTier?join("")}
						</#if>

						<#if discussion?has_content>
							<para><emphasis role="bold">Discussion:</emphasis></para>
							${discussion?join("")}
						</#if>
					</#if>
				</#if>
			</#list>
		</#if>
	</#compress>
</#macro>

<#--Table for bioconcentration in fish EU_PPP (DEPRECATED) -->
<#macro bioconcentrationFishTable csa>
	<#compress>

		<table border="1">
			<tbody valign="middle">

			<tr align="center">
				<th><?dbfo bgcolor="#FBDDA6" ?><emphasis role="bold">Substance</emphasis></th>
				<th><?dbfo bgcolor="#FBDDA6" ?><emphasis role="bold">Assessment</emphasis></th>
				<th><?dbfo bgcolor="#FBDDA6" ?><emphasis role="bold">Nature/level residues</emphasis></th>
				<th><?dbfo bgcolor="#FBDDA6" ?><emphasis role="bold">Remarks</emphasis></th>
			</tr>

			<#list csa.BioconcentrationFish as item>
				<tr>
					<td>
						<#if item.Substance?has_content>
							<#local refSubstance=iuclid.getDocumentForKey(item.Substance)/>
							<@com.text refSubstance.ChemicalName/>
						</#if>
						<#if item.ParentMetabolite?has_content>
							<?linebreak?>(<@com.picklist item.ParentMetabolite/>)
						</#if>
					</td>
					<td>
						<#if item.LogPow?has_content>
							logPo/w = <@com.text item.LogPow/><?linebreak?>
						</#if>
						<#if item.BcfAquaticSpecies?has_content>
							BCF (aquatic species) = <@com.quantity item.BcfAquaticSpecies/><?linebreak?>
						</#if>
						<#if item.CtFiftyClearaceTime?has_content>
							CT50 = <@com.quantity item.CtFiftyClearaceTime/><?linebreak?>
						</#if>
						<#if item.CtNinetyClearaceTime?has_content>
							CT90 = <@com.quantity item.CtNinetyClearaceTime/><?linebreak?>
						</#if>
					</td>
					<td>
						<#if item.NatureAndLevelOfResidues?has_content>
							<@com.richText item.NatureAndLevelOfResidues/>
						</#if>
					</td>
					<td>
						<#if item.Remarks?has_content>
							<@com.richText item.Remarks/>
						</#if>
					</td>
				</tr>
			</#list>

			</tbody>
		</table>
	</#compress>
</#macro>

<#--Table for RAC-->
<#macro RACvaluesTable rac>
	<#compress>

		<table border="1">
			<tbody valign="middle">

			<tr align="center">
				<th><?dbfo bgcolor="#FBDDA6" ?><emphasis role="bold">Test type</emphasis></th>
				<th><?dbfo bgcolor="#FBDDA6" ?><emphasis role="bold">Organism</emphasis></th>
				<th><?dbfo bgcolor="#FBDDA6" ?><emphasis role="bold">Substance</emphasis></th>
				<th><?dbfo bgcolor="#FBDDA6" ?><emphasis role="bold">Endpoint</emphasis></th>
			</tr>

			<#list rac as item>
				<tr>
					<td>
						<@com.picklist item.TimeScale/> <@com.picklist item.Tier/>
					</td>
					<td>
						<@com.picklistMultiple item.TestOrganisms/>
					</td>
					<td>
						<#if item.Substance?has_content>
							<#local refSubstance=iuclid.getDocumentForKey(item.Substance)/>

							<#if refSubstance.documentType == "SUBSTANCE">
								<@com.text refSubstance.ChemicalName />
							<#elseif refSubstance.documentType == "REFERENCE_SUBSTANCE">
								<@com.text refSubstance.ReferenceSubstanceName />
							</#if>
						</#if>
						<#if item.ParentMetabolite?has_content>
							<?linebreak?>(<@com.picklist item.ParentMetabolite/>)
						</#if>
					</td>
					<td>
						<#if item.RacValueType?has_content && item.RacValue?has_content>
							<@com.picklist item.RacValueType/>: <@com.quantity item.RacValue/>
						</#if>
						<#if item.AssessmentFactor?has_content>
							<?linebreak?>(assessment factor: <@com.picklistMultiple item.AssessmentFactor/>)
						</#if>
					</td>
				</tr>
			</#list>

			</tbody>
		</table>
	</#compress>
</#macro>

<#--Summary of ecotox risk assessment-->
<#macro ecotoxRiskAssessmentPPP>
	<#compress>

		<#local summaryList = iuclid.getSectionDocumentsForParentKey(_subject.documentKey, "FLEXIBLE_SUMMARY", "EcotoxRiskAssessmentPesticides") />

		<#if summaryList?has_content>
			<@com.emptyLine/>
			<para><emphasis role="HEAD-WoutNo">Summary</emphasis></para>

			<#assign printSummaryName = summaryList?size gt 1 />

			<#list summaryList as summary>
				<@com.emptyLine/>

				<#if printSummaryName><para><emphasis role="bold">#${summary_index+1}: <@com.text summary.name/></emphasis></para></#if>

				<#--Assessment(table)-->
				<#if summary.EcotoxRiskAssessmentPesticides?has_content>

					<para><emphasis role="bold">Ecotoxicological risk assessment of pesticides:</emphasis></para>
					<para>

						<table border="1">
<#--							<title>Ecotoxicological risk assessment of pesticides</title>-->

							<col width="25%" />
							<col width="75%" />

							<tbody valign="middle">

							<#if summary.EcotoxRiskAssessmentPesticides.RiskAssessmentBirds.field9187?has_content>
								<tr>
									<th><?dbfo bgcolor="#FBDDA6" ?><emphasis role="bold">Birds</emphasis></th>
									<td><@com.richText summary.EcotoxRiskAssessmentPesticides.RiskAssessmentBirds.field9187/></td>
								</tr>
							</#if>
							<#if summary.EcotoxRiskAssessmentPesticides.RiskAssessmentWildMammals.field8618?has_content>
								<tr>
									<th><?dbfo bgcolor="#FBDDA6" ?><emphasis role="bold">Wild mammals</emphasis></th>
									<td><@com.richText summary.EcotoxRiskAssessmentPesticides.RiskAssessmentWildMammals.field8618/></td>
								</tr>
							</#if>
							<#if summary.EcotoxRiskAssessmentPesticides.RiskAssessmentOtherTerrestrialVertebrates.field593?has_content>
								<tr>
									<th><?dbfo bgcolor="#FBDDA6" ?><emphasis role="bold">Other terrestrial vertebrates</emphasis></th>
									<td><@com.richText summary.EcotoxRiskAssessmentPesticides.RiskAssessmentOtherTerrestrialVertebrates.field593/></td>
								</tr>
							</#if>
							<#if summary.EcotoxRiskAssessmentPesticides.RiskAssessmentAquaticOrganisms.field4291?has_content>
								<tr>
									<th><?dbfo bgcolor="#FBDDA6" ?><emphasis role="bold">Aquatic organisms</emphasis></th>
									<td><@com.richText summary.EcotoxRiskAssessmentPesticides.RiskAssessmentAquaticOrganisms.field4291/></td>
								</tr>
							</#if>
							<#if summary.EcotoxRiskAssessmentPesticides.RiskAssessmentBees.field9185?has_content>
								<tr>
									<th><?dbfo bgcolor="#FBDDA6" ?><emphasis role="bold">Bees</emphasis></th>
									<td><@com.richText summary.EcotoxRiskAssessmentPesticides.RiskAssessmentBees.field9185/></td>
								</tr>
							</#if>
							<#if summary.EcotoxRiskAssessmentPesticides.RiskAssessmentNonBees.field5875?has_content>
								<tr>
									<th><?dbfo bgcolor="#FBDDA6" ?><emphasis role="bold">Non-target arthropods other than bees</emphasis></th>
									<td><@com.richText summary.EcotoxRiskAssessmentPesticides.RiskAssessmentNonBees.field5875/></td>
								</tr>
							</#if>
							<#if summary.EcotoxRiskAssessmentPesticides.RiskAssessmentSoilMesoMacrofauna.field9216?has_content>
								<tr>
									<th><?dbfo bgcolor="#FBDDA6" ?><emphasis role="bold">Non-target soil meso- and macrofauna</emphasis></th>
									<td><@com.richText summary.EcotoxRiskAssessmentPesticides.RiskAssessmentSoilMesoMacrofauna.field9216/></td>
								</tr>
							</#if>
							<#if summary.EcotoxRiskAssessmentPesticides.RiskAssessmentSoilTransformation.field9651?has_content>
								<tr>
									<th><?dbfo bgcolor="#FBDDA6" ?><emphasis role="bold">Soil nitrogen transformation</emphasis></th>
									<td><@com.richText summary.EcotoxRiskAssessmentPesticides.RiskAssessmentSoilTransformation.field9651/></td>
								</tr>
							</#if>
							<#if summary.EcotoxRiskAssessmentPesticides.RiskAssessmentHigherPlants.field4576?has_content>
								<tr>
									<th><?dbfo bgcolor="#FBDDA6" ?><emphasis role="bold">Terrestrial non-target higher plants</emphasis></th>
									<td><@com.richText summary.EcotoxRiskAssessmentPesticides.RiskAssessmentHigherPlants.field4576/></td>
								</tr>
							</#if>
							<#if summary.EcotoxRiskAssessmentPesticides.RiskAssessmentSewageTreatmentMethods.field6508?has_content>
								<tr>
									<th><?dbfo bgcolor="#FBDDA6" ?><emphasis role="bold">Biological methods for sewage treatment</emphasis></th>
									<td><@com.richText summary.EcotoxRiskAssessmentPesticides.RiskAssessmentSewageTreatmentMethods.field6508/></td>
								</tr>
							</#if>
							<#if summary.EcotoxRiskAssessmentPesticides.RiskAssessmentToOtherTerrestrialOrganismsFloraAndFauna.field2441?has_content>
								<tr>
									<th><?dbfo bgcolor="#FBDDA6" ?><emphasis role="bold">Other terrestrial organisms (flora and fauna)</emphasis></th>
									<td><@com.richText summary.EcotoxRiskAssessmentPesticides.RiskAssessmentToOtherTerrestrialOrganismsFloraAndFauna.field2441/></td>
								</tr>
							</#if>

							</tbody>
						</table>
					</para>
				</#if>

			<#--Add Information-->
				<#if summary.AdditionalInformation.field9160?has_content>
					<para><emphasis role="bold">Additional information: </emphasis></para>
					<para role="indent"><@com.richText summary.AdditionalInformation.field9160/></para>
				</#if>
			</#list>
		</#if>
	</#compress>
</#macro>

<#-- summary for ecotoxicological information -->
<#macro ecotoxicologicalInformationSummary>
	<#compress>
		<#local summaryList = iuclid.getSectionDocumentsForParentKey(_subject.documentKey, "ENDPOINT_SUMMARY", "EcotoxicologicalInformation") />

		<#if summaryList?has_content>
			<@com.emptyLine/>
			<para><emphasis role="HEAD-WoutNo">Summary of ecotoxicological information</emphasis></para>

			<#assign printSummaryName = summaryList?size gt 1 />

			<#list summaryList as summary>
				<@com.emptyLine/>

				<#if printSummaryName><para><emphasis role="bold">#${summary_index+1}: <@com.text summary.name/></emphasis></para></#if>

			<#-- iterate over blocks-->
			<#--				<para><emphasis role="bold">Hazard assessment: </emphasis></para>-->

				<table border="1">
					<title>Hazard assessment</title>
					<col width="20%" />
					<col width="40%" />
					<col width="40%" />

					<tbody valign="middle">

					<tr align="center">
						<th><?dbfo bgcolor="#FBDDA6" ?><emphasis role="bold">Hazard</emphasis></th>
						<th><?dbfo bgcolor="#FBDDA6" ?><emphasis role="bold">Assessment conclusion</emphasis></th>
						<th><?dbfo bgcolor="#FBDDA6" ?><emphasis role="bold">Explanation</emphasis></th>
					</tr>

					<#local hazardBlocks=["HazardForAquaticOrganisms","HazardForAir","HazardForTerrestrialOrganisms","HazardForPredators"]/>
					<#list summary?children as section>
						<#if hazardBlocks?seq_contains(section?node_name)>
							<#local sectionName=section?node_name?replace("HazardFor", "")?replace("([A-Z]{1})", " $1", "r")?lower_case?cap_first/>
							<#list section?children as block>
								<#local blockName=block?node_name?replace("([A-Z]{1})", " $1", "r")?lower_case?cap_first/>
								<#if block?has_content>
									<tr>
										<td>${sectionName}: ${blockName}</td>
										<td>
											<@com.picklist block.HazAssessConcl/>
											<#if block.HazAssessConclVal?has_content>
												: <@com.quantity block.HazAssessConclVal/>
											</#if>

											<#if block.hasElement("PNECFreshwaterIntermittentReleases") && block.PNECFreshwaterIntermittentReleases?has_content>
												<?linebreak?>(PNEC (intermittent releases) = <@com.quantity block.PNECFreshwaterIntermittentReleases/>)
											<#elseif block.hasElement("PNECMarineWaterIntermittentReleases") && block.PNECMarineWaterIntermittentReleases?has_content>
												<?linebreak?>(PNEC (intermittent releases) = <@com.quantity block.PNECMarineWaterIntermittentReleases/>)
											</#if>

											<#if block.hasElement("AssessmentFactor") && block.AssessmentFactor?has_content>
												<@com.emptyLine/>
												<?linebreak?>assessment factor = <@com.number block.AssessmentFactor/>
											</#if>
											<#if block.hasElement("ExtrapolationMethod") && block.ExtrapolationMethod?has_content>
												<@com.emptyLine/>
												<?linebreak?>extrapolation method: <@com.picklist block.ExtrapolationMethod/>
											</#if>

										</td>
										<td><@com.richText block.Justification/></td>
									</tr>
								</#if>
							</#list>
						</#if>
					</#list>
					</tbody>
				</table>

			<#--Add Information-->
				<#if summary.Discussion.Discussion?has_content>
					<para><emphasis role="bold">Additional information: </emphasis></para>
					<para role="indent"><@com.richText summary.Discussion.Discussion/></para>
				</#if>

			<#--Conclusion-->
				<#if summary.ConclusionOnClassification.JustificationEnv?has_content>
					<para><emphasis role="bold">Conclusion on classification: </emphasis></para>
					<para role="indent"><@com.richText summary.ConclusionOnClassification.JustificationEnv/></para>
				</#if>

			</#list>

		</#if>
	</#compress>
</#macro>